@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -36,8 +36,8 @@ $fields = array(
 	'profileIdx2' =>	array(T_ZBX_STR, O_OPT, null,		null,		null),
 	'updateProfile' =>	array(T_ZBX_STR, O_OPT, null,		null,		null),
 	'border' =>			array(T_ZBX_INT, O_OPT, P_NZERO,	IN('0,1'),	null),
-	'width' =>			array(T_ZBX_INT, O_OPT, P_NZERO,	'{}>0',		null),
-	'height' =>			array(T_ZBX_INT, O_OPT, P_NZERO,	'{}>0',		null),
+	'width' =>			array(T_ZBX_INT, O_OPT, P_NZERO,	'{} > 0',	null),
+	'height' =>			array(T_ZBX_INT, O_OPT, P_NZERO,	'{} > 0',	null),
 	'graph3d' =>		array(T_ZBX_INT, O_OPT, P_NZERO,	IN('0,1'),	null),
 	'legend' =>			array(T_ZBX_INT, O_OPT, P_NZERO,	IN('0,1'),	null)
 );
@@ -47,10 +47,12 @@ check_fields($fields);
  * Permissions
  */
 $dbGraph = API::Graph()->get(array(
-	'graphids' => $_REQUEST['graphid'],
-	'selectHosts' => API_OUTPUT_EXTEND,
-	'output' => API_OUTPUT_EXTEND
+	'output' => API_OUTPUT_EXTEND,
+	'selectGraphItems' => array('itemid', 'calc_fnc', 'color', 'type'),
+	'selectHosts' => array('name'),
+	'graphids' => $_REQUEST['graphid']
 ));
+
 if (!$dbGraph) {
 	access_deny();
 }
@@ -58,17 +60,15 @@ else {
 	$dbGraph = reset($dbGraph);
 }
 
-$host = reset($dbGraph['hosts']);
-
 /*
  * Display
  */
 $timeline = CScreenBase::calculateTime(array(
-	'profileIdx' => get_request('profileIdx', 'web.screens'),
-	'profileIdx2' => get_request('profileIdx2'),
-	'updateProfile' => get_request('updateProfile', true),
-	'period' => get_request('period'),
-	'stime' => get_request('stime')
+	'profileIdx' => getRequest('profileIdx', 'web.screens'),
+	'profileIdx2' => getRequest('profileIdx2'),
+	'updateProfile' => getRequest('updateProfile', true),
+	'period' => getRequest('period'),
+	'stime' => getRequest('stime')
 ));
 
 $graph = new CPieGraphDraw($dbGraph['graphtype']);
@@ -79,39 +79,53 @@ if (isset($_REQUEST['border'])) {
 	$graph->setBorder(0);
 }
 
-$width = get_request('width', 0);
+$width = getRequest('width', 0);
 if ($width <= 0) {
 	$width = $dbGraph['width'];
 }
 
-$height = get_request('height', 0);
+$height = getRequest('height', 0);
 if ($height <= 0) {
 	$height = $dbGraph['height'];
 }
 
 $graph->setWidth($width);
 $graph->setHeight($height);
-$graph->setHeader($host['host'].NAME_DELIMITER.$dbGraph['name']);
+
+// array sorting
+CArrayHelper::sort($dbGraph['gitems'], array(
+	array('field' => 'sortorder', 'order' => ZBX_SORT_UP),
+	array('field' => 'itemid', 'order' => ZBX_SORT_DOWN)
+));
+
+// get graph items
+foreach ($dbGraph['gitems'] as $gItem) {
+	$graph->addItem(
+		$gItem['itemid'],
+		$gItem['calc_fnc'],
+		$gItem['color'],
+		$gItem['type']
+	);
+}
+
+$hostName = '';
+
+foreach ($dbGraph['hosts'] as $gItemHost) {
+	if ($hostName === '') {
+		$hostName = $gItemHost['name'];
+	}
+	elseif ($hostName !== $gItemHost['name']) {
+		$hostName = '';
+		break;
+	}
+}
+
+$graph->setHeader(($hostName === '') ? $dbGraph['name'] : $hostName.NAME_DELIMITER.$dbGraph['name']);
 
 if ($dbGraph['show_3d']) {
 	$graph->switchPie3D();
 }
 $graph->showLegend($dbGraph['show_legend']);
-
-$result = DBselect(
-	'SELECT gi.*'.
-	' FROM graphs_items gi'.
-	' WHERE gi.graphid='.zbx_dbstr($dbGraph['graphid']).
-	' ORDER BY gi.sortorder,gi.itemid DESC'
-);
-while ($dbGraph = DBfetch($result)) {
-	$graph->addItem(
-		$dbGraph['itemid'],
-		$dbGraph['calc_fnc'],
-		$dbGraph['color'],
-		$dbGraph['type']
-	);
-}
 $graph->draw();
 
 require_once dirname(__FILE__).'/include/page_footer.php';
