@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -35,21 +35,21 @@ $fields = array(
 	'parent_discoveryid' =>	array(T_ZBX_INT, O_OPT, P_SYS,		DB_ID,			null),
 	'groupid' =>			array(T_ZBX_INT, O_OPT, P_SYS,		DB_ID,			null),
 	'hostid' =>				array(T_ZBX_INT, O_OPT, P_SYS,		DB_ID,			null),
-	'copy_type' =>			array(T_ZBX_INT, O_OPT, P_SYS,		IN('0,1'),		'isset({copy})'),
+	'copy_type' => array(T_ZBX_INT, O_OPT, P_SYS, IN(array(COPY_TYPE_TO_HOST, COPY_TYPE_TO_HOST_GROUP, COPY_TYPE_TO_TEMPLATE)), 'isset({copy})'),
 	'copy_mode' =>			array(T_ZBX_INT, O_OPT, P_SYS,		IN('0'),		null),
-	'graphid' =>			array(T_ZBX_INT, O_OPT, P_SYS,		DB_ID,			'(isset({form})&&({form}=="update"))'),
-	'name' =>				array(T_ZBX_STR, O_OPT, null,		NOT_EMPTY,		'isset({save})', _('Name')),
-	'width' =>				array(T_ZBX_INT, O_OPT, null,		BETWEEN(20, 65535), 'isset({save})', _('Width').' (min:20, max:65535)'),
-	'height' =>				array(T_ZBX_INT, O_OPT, null,		BETWEEN(20, 65535), 'isset({save})', _('Height').' (min:20, max:65535)'),
-	'ymin_type' =>			array(T_ZBX_INT, O_OPT, null,		IN('0,1,2'),	null),
-	'ymax_type' =>			array(T_ZBX_INT, O_OPT, null,		IN('0,1,2'),	null),
-	'graphtype' =>			array(T_ZBX_INT, O_OPT, null,		IN('0,1,2,3'),	'isset({save})'),
-	'yaxismin' =>			array(T_ZBX_DBL, O_OPT, null,		null,			'isset({save})&&(({graphtype}==0)||({graphtype}==1))'),
-	'yaxismax' =>			array(T_ZBX_DBL, O_OPT, null,		null,			'isset({save})&&(({graphtype}==0)||({graphtype}==1))'),
+	'graphid' =>			array(T_ZBX_INT, O_OPT, P_SYS,		DB_ID,			'isset({form}) && {form} == "update"'),
+	'name' =>				array(T_ZBX_STR, O_OPT, null,		NOT_EMPTY,		'isset({add}) || isset({update})', _('Name')),
+	'width' =>				array(T_ZBX_INT, O_OPT, null,		BETWEEN(20, 65535), 'isset({add}) || isset({update})', _('Width')),
+	'height' =>				array(T_ZBX_INT, O_OPT, null,		BETWEEN(20, 65535), 'isset({add}) || isset({update})', _('Height')),
+	'graphtype' =>			array(T_ZBX_INT, O_OPT, null,		IN('0,1,2,3'),	'isset({add}) || isset({update})'),
 	'show_3d' =>			array(T_ZBX_INT, O_OPT, P_NZERO,	IN('0,1'),		null),
 	'show_legend' =>		array(T_ZBX_INT, O_OPT, P_NZERO,	IN('0,1'),		null),
-	'ymin_itemid' =>		array(T_ZBX_INT, O_OPT, null,		DB_ID,			'isset({save})&&isset({ymin_type})&&({ymin_type}==3)'),
-	'ymax_itemid' =>		array(T_ZBX_INT, O_OPT, null,		DB_ID,			'isset({save})&&isset({ymax_type})&&({ymax_type}==3)'),
+	'ymin_type' =>			array(T_ZBX_INT, O_OPT, null,		IN('0,1,2'),	null),
+	'ymax_type' =>			array(T_ZBX_INT, O_OPT, null,		IN('0,1,2'),	null),
+	'yaxismin' =>			array(T_ZBX_DBL, O_OPT, null,		null,			'(isset({add}) || isset({update})) && ({graphtype} == 0 || {graphtype} == 1)'),
+	'yaxismax' =>			array(T_ZBX_DBL, O_OPT, null,		null,			'(isset({add}) || isset({update})) && ({graphtype} == 0 || {graphtype} == 1)'),
+	'ymin_itemid' =>		array(T_ZBX_INT, O_OPT, null,		DB_ID,			'(isset({add}) || isset({update})) && isset({ymin_type}) && {ymin_type} == 3'),
+	'ymax_itemid' =>		array(T_ZBX_INT, O_OPT, null,		DB_ID,			'(isset({add}) || isset({update})) && isset({ymax_type}) && {ymax_type} == 3'),
 	'percent_left' =>		array(T_ZBX_DBL, O_OPT, null,		BETWEEN(0, 100), null, _('Percentile line (left)')),
 	'percent_right' =>		array(T_ZBX_DBL, O_OPT, null,		BETWEEN(0, 100), null, _('Percentile line (right)')),
 	'visible' =>			array(T_ZBX_INT, O_OPT, null,		BETWEEN(0, 1),	null),
@@ -58,18 +58,22 @@ $fields = array(
 	'show_triggers' =>		array(T_ZBX_INT, O_OPT, null,		IN('1'),		null),
 	'group_graphid' =>		array(T_ZBX_INT, O_OPT, null,		DB_ID,			null),
 	'copy_targetid' =>		array(T_ZBX_INT, O_OPT, null,		DB_ID,			null),
-	'filter_groupid' =>		array(T_ZBX_INT, O_OPT, P_SYS,		DB_ID,			'isset({copy})&&(isset({copy_type})&&({copy_type}==0))'),
+	'copy_groupid' =>		array(T_ZBX_INT, O_OPT, P_SYS,		DB_ID,			'isset({copy}) && isset({copy_type}) && {copy_type} == 0'),
 	// actions
-	'go' =>					array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null),
-	'save' =>				array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null),
+	'action' =>				array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, IN('"graph.masscopyto","graph.massdelete"'),	null),
+	'add' =>				array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null),
+	'update' =>				array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null),
 	'clone' =>				array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null),
 	'copy' =>				array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null),
 	'delete' =>				array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,			null),
 	'cancel' =>				array(T_ZBX_STR, O_OPT, P_SYS,		null,			null),
 	'form' =>				array(T_ZBX_STR, O_OPT, P_SYS,		null,			null),
-	'form_refresh' =>		array(T_ZBX_INT, O_OPT, null,		null,			null)
+	'form_refresh' =>		array(T_ZBX_INT, O_OPT, null,		null,			null),
+	// sort and sortorder
+	'sort' =>				array(T_ZBX_STR, O_OPT, P_SYS, IN('"graphtype","name"'),					null),
+	'sortorder' =>			array(T_ZBX_STR, O_OPT, P_SYS, IN('"'.ZBX_SORT_DOWN.'","'.ZBX_SORT_UP.'"'),	null)
 );
-$percentVisible = get_request('visible');
+$percentVisible = getRequest('visible');
 if (!isset($percentVisible['percent_left'])) {
 	unset($_REQUEST['percent_left']);
 }
@@ -83,12 +87,10 @@ if (isset($_REQUEST['yaxismax']) && zbx_empty($_REQUEST['yaxismax'])) {
 	unset($_REQUEST['yaxismax']);
 }
 check_fields($fields);
-validate_sort_and_sortorder('name', ZBX_SORT_UP);
 
-$_REQUEST['go'] = get_request('go', 'none');
-$_REQUEST['items'] = get_request('items', array());
-$_REQUEST['show_3d'] = get_request('show_3d', 0);
-$_REQUEST['show_legend'] = get_request('show_legend', 0);
+$_REQUEST['items'] = getRequest('items', array());
+$_REQUEST['show_3d'] = getRequest('show_3d', 0);
+$_REQUEST['show_legend'] = getRequest('show_legend', 0);
 
 /*
  * Permissions
@@ -97,7 +99,6 @@ if (CUser::$userData['type'] !== USER_TYPE_SUPER_ADMIN) {
 	if (!empty($_REQUEST['parent_discoveryid'])) {
 		// check whether discovery rule is editable by user
 		$discovery_rule = API::DiscoveryRule()->get(array(
-			'nodeids' => get_current_nodeid(true),
 			'itemids' => array($_REQUEST['parent_discoveryid']),
 			'output' => API_OUTPUT_EXTEND,
 			'editable' => true,
@@ -108,7 +109,7 @@ if (CUser::$userData['type'] !== USER_TYPE_SUPER_ADMIN) {
 			access_deny();
 		}
 
-		// sets coresponding hostid for later usage
+		// sets corresponding hostid for later usage
 		if (empty($_REQUEST['hostid'])) {
 			$_REQUEST['hostid'] = $discovery_rule['hostid'];
 		}
@@ -129,7 +130,7 @@ if (CUser::$userData['type'] !== USER_TYPE_SUPER_ADMIN) {
 	elseif (!empty($_REQUEST['graphid'])) {
 		// check whether graph is normal and editable by user
 		$graphs = API::Graph()->get(array(
-			'nodeids' => get_current_nodeid(true),
+			'output' => array('graphid'),
 			'filter' => array('flags' => ZBX_FLAG_DISCOVERY_NORMAL),
 			'graphids' => array($_REQUEST['graphid']),
 			'editable' => true,
@@ -142,7 +143,7 @@ if (CUser::$userData['type'] !== USER_TYPE_SUPER_ADMIN) {
 	elseif (!empty($_REQUEST['hostid'])) {
 		// check whether host is editable by user
 		$hosts = API::Host()->get(array(
-			'nodeids' => get_current_nodeid(true),
+			'output' => array('hostid'),
 			'hostids' => array($_REQUEST['hostid']),
 			'templated_hosts' => true,
 			'editable' => true,
@@ -168,21 +169,24 @@ if (isset($_REQUEST['clone']) && isset($_REQUEST['graphid'])) {
 		: API::GraphPrototype()->get($options);
 	$graph = reset($graph);
 
-	$_REQUEST = array_merge($_REQUEST, $graph);
-
-	// graph items
-	$_REQUEST['items'] = API::GraphItem()->get(array(
+	$graph['items'] = API::GraphItem()->get(array(
 		'graphids' => $_REQUEST['graphid'],
 		'sortfield' => 'gitemid',
-		'output' => API_OUTPUT_EXTEND,
-		'expandData' => true
+		'output' => API_OUTPUT_EXTEND
 	));
 
+	if($graph['templateid']) {
+		$_REQUEST = array_merge($_REQUEST, $graph);
+	}
+	else {
+		$graph = array_merge($graph, $_REQUEST);
+	}
+
 	unset($_REQUEST['graphid']);
 
 	$_REQUEST['form'] = 'clone';
 }
-elseif (hasRequest('save')) {
+elseif (hasRequest('add') || hasRequest('update')) {
 	$items = getRequest('items', array());
 
 	// remove passing "gitemid" to API if new items added via pop-up
@@ -194,25 +198,27 @@ elseif (hasRequest('save')) {
 	unset($item);
 
 	$graph = array(
-		'name' => $_REQUEST['name'],
-		'width' => $_REQUEST['width'],
-		'height' => $_REQUEST['height'],
-		'ymin_type' => get_request('ymin_type', 0),
-		'ymax_type' => get_request('ymax_type', 0),
-		'yaxismin' => get_request('yaxismin', 0),
-		'yaxismax' => get_request('yaxismax', 0),
-		'ymin_itemid' => $_REQUEST['ymin_itemid'],
-		'ymax_itemid' => $_REQUEST['ymax_itemid'],
-		'show_work_period' => get_request('show_work_period', 0),
-		'show_triggers' => get_request('show_triggers', 0),
-		'graphtype' => $_REQUEST['graphtype'],
-		'show_legend' => get_request('show_legend', 1),
-		'show_3d' => get_request('show_3d', 0),
-		'percent_left' => get_request('percent_left', 0),
-		'percent_right' => get_request('percent_right', 0),
+		'name' => getRequest('name'),
+		'width' => getRequest('width'),
+		'height' => getRequest('height'),
+		'ymin_type' => getRequest('ymin_type', 0),
+		'ymax_type' => getRequest('ymax_type', 0),
+		'yaxismin' => getRequest('yaxismin', 0),
+		'yaxismax' => getRequest('yaxismax', 0),
+		'ymin_itemid' => getRequest('ymin_itemid'),
+		'ymax_itemid' => getRequest('ymax_itemid'),
+		'show_work_period' => getRequest('show_work_period', 0),
+		'show_triggers' => getRequest('show_triggers', 0),
+		'graphtype' => getRequest('graphtype'),
+		'show_legend' => getRequest('show_legend', 1),
+		'show_3d' => getRequest('show_3d', 0),
+		'percent_left' => getRequest('percent_left', 0),
+		'percent_right' => getRequest('percent_right', 0),
 		'gitems' => $items
 	);
 
+	DBstart();
+
 	// create and update graph prototypes
 	if (hasRequest('parent_discoveryid')) {
 		$graph['flags'] = ZBX_FLAG_DISCOVERY_PROTOTYPE;
@@ -221,16 +227,17 @@ elseif (hasRequest('save')) {
 			$graph['graphid'] = getRequest('graphid');
 			$result = API::GraphPrototype()->update($graph);
 
-			show_messages($result, _('Graph prototype updated'), _('Cannot update graph prototype'));
-
+			$messageSuccess = _('Graph prototype updated');
+			$messageFailed = _('Cannot update graph prototype');
 		}
 		else {
 			$result = API::GraphPrototype()->create($graph);
 
-			show_messages($result, _('Graph prototype added'), _('Cannot add graph prototype'));
+			$messageSuccess = _('Graph prototype added');
+			$messageFailed = _('Cannot add graph prototype');
 		}
 
-		clearCookies($result, getRequest('parent_discoveryid'));
+		$cookieId = getRequest('parent_discoveryid');
 	}
 	// create and update graphs
 	else {
@@ -238,22 +245,22 @@ elseif (hasRequest('save')) {
 			$graph['graphid'] = getRequest('graphid');
 			$result = API::Graph()->update($graph);
 
-			show_messages($result, _('Graph updated'), _('Cannot update graph'));
+			$messageSuccess = _('Graph updated');
+			$messageFailed = _('Cannot update graph');
 		}
 		else {
 			$result = API::Graph()->create($graph);
 
-			show_messages($result, _('Graph added'), _('Cannot add graph'));
+			$messageSuccess = _('Graph added');
+			$messageFailed = _('Cannot add graph');
 		}
 
-		clearCookies($result, getRequest('hostid'));
+		$cookieId = getRequest('hostid');
 	}
 
 	if ($result) {
 		if (hasRequest('graphid')) {
-			add_audit(
-				AUDIT_ACTION_UPDATE,
-				AUDIT_RESOURCE_GRAPH,
+			add_audit(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_GRAPH,
 				'Graph ID ['.$graph['graphid'].'] Graph ['.getRequest('name').']'
 			);
 		}
@@ -263,93 +270,108 @@ elseif (hasRequest('save')) {
 
 		unset($_REQUEST['form']);
 	}
+
+	$result = DBend($result);
+
+	if ($result) {
+		uncheckTableRows($cookieId);
+	}
+	show_messages($result, $messageSuccess, $messageFailed);
 }
 elseif (hasRequest('delete') && hasRequest('graphid')) {
 	$graphId = getRequest('graphid');
 
 	if (hasRequest('parent_discoveryid')) {
-		$result = API::GraphPrototype()->delete($graphId);
+		$result = API::GraphPrototype()->delete(array($graphId));
 
+		if ($result) {
+			uncheckTableRows(getRequest('parent_discoveryid'));
+		}
 		show_messages($result, _('Graph prototype deleted'), _('Cannot delete graph prototype'));
-		clearCookies($result, getRequest('parent_discoveryid'));
 	}
 	else {
-		$result = API::Graph()->delete($graphId);
+		$result = API::Graph()->delete(array($graphId));
 
+		if ($result) {
+			uncheckTableRows(getRequest('hostid'));
+		}
 		show_messages($result, _('Graph deleted'), _('Cannot delete graph'));
-		clearCookies($result, getRequest('hostid'));
 	}
 
 	if ($result) {
 		unset($_REQUEST['form']);
 	}
 }
-elseif (getRequest('go') == 'delete' && hasRequest('group_graphid')) {
+elseif (hasRequest('action') && getRequest('action') == 'graph.massdelete' && hasRequest('group_graphid')) {
 	$graphIds = getRequest('group_graphid');
 
 	if (hasRequest('parent_discoveryid')) {
 		$result = API::GraphPrototype()->delete($graphIds);
 
+		if ($result) {
+			uncheckTableRows(getRequest('parent_discoveryid'));
+		}
 		show_messages($result, _('Graph prototypes deleted'), _('Cannot delete graph prototypes'));
-		clearCookies($result, getRequest('parent_discoveryid'));
 	}
 	else {
 		$result = API::Graph()->delete($graphIds);
 
+		if ($result) {
+			uncheckTableRows(getRequest('hostid'));
+		}
 		show_messages($result, _('Graphs deleted'), _('Cannot delete graphs'));
-		clearCookies($result, getRequest('hostid'));
 	}
-}
-elseif ($_REQUEST['go'] == 'copy_to' && isset($_REQUEST['copy']) && isset($_REQUEST['group_graphid'])) {
-	if (!empty($_REQUEST['copy_targetid']) && isset($_REQUEST['copy_type'])) {
-		$goResult = true;
+} elseif (hasRequest('action') && getRequest('action') == 'graph.masscopyto' && hasRequest('copy') && hasRequest('group_graphid')) {
+	if (getRequest('copy_targetid') != 0 && hasRequest('copy_type')) {
+		$result = true;
 
 		$options = array(
+			'output' => array('hostid'),
 			'editable' => true,
-			'nodes' => get_current_nodeid(true),
 			'templated_hosts' => true
 		);
 
-		// hosts
-		if ($_REQUEST['copy_type'] == 0) {
-			$options['hostids'] = $_REQUEST['copy_targetid'];
+		// hosts or templates
+		if (getRequest('copy_type') == COPY_TYPE_TO_HOST || getRequest('copy_type') == COPY_TYPE_TO_TEMPLATE) {
+			$options['hostids'] = getRequest('copy_targetid');
 		}
-		// groups
+		// host groups
 		else {
-			zbx_value2array($_REQUEST['copy_targetid']);
+			zbx_value2array(getRequest('copy_targetid'));
 
 			$dbGroups = API::HostGroup()->get(array(
-				'groupids' => $_REQUEST['copy_targetid'],
-				'nodes' => get_current_nodeid(true),
+				'output' => array('groupid'),
+				'groupids' => getRequest('copy_targetid'),
 				'editable' => true
 			));
 			$dbGroups = zbx_toHash($dbGroups, 'groupid');
 
-			foreach ($_REQUEST['copy_targetid'] as $groupid) {
+			foreach (getRequest('copy_targetid') as $groupid) {
 				if (!isset($dbGroups[$groupid])) {
 					access_deny();
 				}
 			}
 
-			$options['groupids'] = $_REQUEST['copy_targetid'];
+			$options['groupids'] = getRequest('copy_targetid');
 		}
 
 		$dbHosts = API::Host()->get($options);
 
 		DBstart();
-		foreach ($_REQUEST['group_graphid'] as $graphid) {
+		foreach (getRequest('group_graphid') as $graphid) {
 			foreach ($dbHosts as $host) {
-				$goResult &= (bool) copyGraphToHost($graphid, $host['hostid']);
+				$result &= (bool) copyGraphToHost($graphid, $host['hostid']);
 			}
 		}
-		$goResult = DBend($goResult);
+		$result = DBend($result);
 
-		show_messages($goResult, _('Graphs copied'), _('Cannot copy graphs'));
-		clearCookies($goResult,
-			empty($_REQUEST['parent_discoveryid']) ? $_REQUEST['hostid'] : $_REQUEST['parent_discoveryid']
-		);
-
-		$_REQUEST['go'] = 'none2';
+		if ($result) {
+			uncheckTableRows(
+				getRequest('parent_discoveryid') == 0 ? getRequest('hostid') : getRequest('parent_discoveryid')
+			);
+			unset($_REQUEST['group_graphid']);
+		}
+		show_messages($result, _('Graphs copied'), _('Cannot copy graphs'));
 	}
 	else {
 		error(_('No target selected.'));
@@ -362,15 +384,15 @@ elseif ($_REQUEST['go'] == 'copy_to' && isset($_REQUEST['copy']) && isset($_REQU
  */
 $pageFilter = new CPageFilter(array(
 	'groups' => array(
-		'not_proxy_hosts' => true,
+		'with_hosts_and_templates' => true,
 		'editable' => true
 	),
 	'hosts' => array(
 		'editable' => true,
 		'templated_hosts' => true
 	),
-	'groupid' => get_request('groupid', null),
-	'hostid' => get_request('hostid', null)
+	'groupid' => getRequest('groupid'),
+	'hostid' => getRequest('hostid')
 ));
 
 if (empty($_REQUEST['parent_discoveryid'])) {
@@ -382,21 +404,23 @@ if (empty($_REQUEST['parent_discoveryid'])) {
 	}
 }
 
-if ($_REQUEST['go'] == 'copy_to' && isset($_REQUEST['group_graphid'])) {
+if (hasRequest('action') && getRequest('action') == 'graph.masscopyto' && hasRequest('group_graphid')) {
 	// render view
-	$graphView = new CView('configuration.copy.elements', getCopyElementsFormData('group_graphid'));
+	$data = getCopyElementsFormData('group_graphid');
+	$data['action'] = 'graph.masscopyto';
+	$graphView = new CView('configuration.copy.elements', $data);
 	$graphView->render();
 	$graphView->show();
 }
 elseif (isset($_REQUEST['form'])) {
 	$data = array(
-		'form' => get_request('form'),
-		'form_refresh' => get_request('form_refresh', 0),
-		'graphid' => get_request('graphid', 0),
-		'parent_discoveryid' => get_request('parent_discoveryid'),
-		'group_gid' => get_request('group_gid', array()),
-		'hostid' => get_request('hostid', 0),
-		'normal_only' => get_request('normal_only')
+		'form' => getRequest('form'),
+		'form_refresh' => getRequest('form_refresh', 0),
+		'graphid' => getRequest('graphid', 0),
+		'parent_discoveryid' => getRequest('parent_discoveryid'),
+		'group_gid' => getRequest('group_gid', array()),
+		'hostid' => getRequest('hostid', 0),
+		'normal_only' => getRequest('normal_only')
 	);
 
 	if (!empty($data['graphid']) && !isset($_REQUEST['form_refresh'])) {
@@ -437,11 +461,12 @@ elseif (isset($_REQUEST['form'])) {
 		if (!empty($data['templateid'])) {
 			$parentGraphid = $data['templateid'];
 			do {
-				$parentGraph = get_graph_by_graphid($parentGraphid);
+				$parentGraph = getGraphByGraphId($parentGraphid);
 
 				// parent graph prototype link
-				if (get_request('parent_discoveryid')) {
+				if (getRequest('parent_discoveryid')) {
 					$parentGraphPrototype = API::GraphPrototype()->get(array(
+						'output' => array('graphid'),
 						'graphids' => $parentGraph['graphid'],
 						'selectTemplates' => API_OUTPUT_EXTEND,
 						'selectDiscoveryRule' => array('itemid')
@@ -466,7 +491,7 @@ elseif (isset($_REQUEST['form'])) {
 				}
 				if (isset($link)) {
 					$data['templates'][] = $link;
-					$data['templates'][] = SPACE.RARR.SPACE;
+					$data['templates'][] = SPACE.'&rArr;'.SPACE;
 				}
 				$parentGraphid = $parentGraph['templateid'];
 			} while ($parentGraphid != 0);
@@ -476,46 +501,47 @@ elseif (isset($_REQUEST['form'])) {
 
 		// items
 		$data['items'] = API::GraphItem()->get(array(
+			'output' => array(
+				'gitemid', 'graphid', 'itemid', 'type', 'drawtype', 'yaxisside', 'calc_fnc', 'color', 'sortorder'
+			),
 			'graphids' => $data['graphid'],
-			'sortfield' => 'gitemid',
-			'output' => API_OUTPUT_EXTEND,
-			'expandData' => true
+			'sortfield' => 'gitemid'
 		));
 	}
 	else {
-		$data['name'] = get_request('name', '');
-		$data['graphtype'] = get_request('graphtype', GRAPH_TYPE_NORMAL);
+		$data['name'] = getRequest('name', '');
+		$data['graphtype'] = getRequest('graphtype', GRAPH_TYPE_NORMAL);
 
 		if ($data['graphtype'] == GRAPH_TYPE_PIE || $data['graphtype'] == GRAPH_TYPE_EXPLODED) {
-			$data['width'] = get_request('width', 400);
-			$data['height'] = get_request('height', 300);
+			$data['width'] = getRequest('width', 400);
+			$data['height'] = getRequest('height', 300);
 		}
 		else {
-			$data['width'] = get_request('width', 900);
-			$data['height'] = get_request('height', 200);
+			$data['width'] = getRequest('width', 900);
+			$data['height'] = getRequest('height', 200);
 		}
 
-		$data['ymin_type'] = get_request('ymin_type', GRAPH_YAXIS_TYPE_CALCULATED);
-		$data['ymax_type'] = get_request('ymax_type', GRAPH_YAXIS_TYPE_CALCULATED);
-		$data['yaxismin'] = get_request('yaxismin', '0.00');
-		$data['yaxismax'] = get_request('yaxismax', '100.00');
-		$data['ymin_itemid'] = get_request('ymin_itemid', 0);
-		$data['ymax_itemid'] = get_request('ymax_itemid', 0);
-		$data['show_work_period'] = get_request('show_work_period', 0);
-		$data['show_triggers'] = get_request('show_triggers', 0);
-		$data['show_legend'] = get_request('show_legend', 0);
-		$data['show_3d'] = get_request('show_3d', 0);
-		$data['visible'] = get_request('visible');
+		$data['ymin_type'] = getRequest('ymin_type', GRAPH_YAXIS_TYPE_CALCULATED);
+		$data['ymax_type'] = getRequest('ymax_type', GRAPH_YAXIS_TYPE_CALCULATED);
+		$data['yaxismin'] = getRequest('yaxismin', 0);
+		$data['yaxismax'] = getRequest('yaxismax', 100);
+		$data['ymin_itemid'] = getRequest('ymin_itemid', 0);
+		$data['ymax_itemid'] = getRequest('ymax_itemid', 0);
+		$data['show_work_period'] = getRequest('show_work_period', 0);
+		$data['show_triggers'] = getRequest('show_triggers', 0);
+		$data['show_legend'] = getRequest('show_legend', 0);
+		$data['show_3d'] = getRequest('show_3d', 0);
+		$data['visible'] = getRequest('visible');
 		$data['percent_left'] = 0;
 		$data['percent_right'] = 0;
-		$data['visible'] = get_request('visible');
-		$data['items'] = get_request('items', array());
+		$data['visible'] = getRequest('visible');
+		$data['items'] = getRequest('items', array());
 
 		if (isset($data['visible']['percent_left'])) {
-			$data['percent_left'] = get_request('percent_left', 0);
+			$data['percent_left'] = getRequest('percent_left', 0);
 		}
 		if (isset($data['visible']['percent_right'])) {
-			$data['percent_right'] = get_request('percent_right', 0);
+			$data['percent_right'] = getRequest('percent_right', 0);
 		}
 	}
 
@@ -525,23 +551,32 @@ elseif (isset($_REQUEST['form'])) {
 		$data['show_triggers'] = $_REQUEST['show_triggers'] = 1;
 	}
 
-	$_REQUEST['items'] = $data['items'];
-	$_REQUEST['name'] = $data['name'];
-	$_REQUEST['width'] = $data['width'];
-	$_REQUEST['height'] = $data['height'];
-	$_REQUEST['ymin_type'] = $data['ymin_type'];
-	$_REQUEST['ymax_type'] = $data['ymax_type'];
-	$_REQUEST['yaxismin'] = $data['yaxismin'];
-	$_REQUEST['yaxismax'] = $data['yaxismax'];
-	$_REQUEST['ymin_itemid'] = $data['ymin_itemid'];
-	$_REQUEST['ymax_itemid'] = $data['ymax_itemid'];
-	$_REQUEST['show_work_period'] = $data['show_work_period'];
-	$_REQUEST['show_triggers'] = $data['show_triggers'];
-	$_REQUEST['graphtype'] = $data['graphtype'];
-	$_REQUEST['show_legend'] = $data['show_legend'];
-	$_REQUEST['show_3d'] = $data['show_3d'];
-	$_REQUEST['percent_left'] = $data['percent_left'];
-	$_REQUEST['percent_right'] = $data['percent_right'];
+	// items
+	if ($data['items']) {
+		$items = API::Item()->get(array(
+			'output' => array('itemid', 'hostid', 'name', 'key_', 'flags'),
+			'selectHosts' => array('hostid', 'name'),
+			'itemids' => zbx_objectValues($data['items'], 'itemid'),
+			'filter' => array(
+				'flags' => array(ZBX_FLAG_DISCOVERY_NORMAL, ZBX_FLAG_DISCOVERY_PROTOTYPE, ZBX_FLAG_DISCOVERY_CREATED)
+			),
+			'webitems' => true,
+			'preservekeys' => true
+		));
+
+		foreach ($data['items'] as &$item) {
+			$host = reset($items[$item['itemid']]['hosts']);
+
+			$item['host'] = $host['name'];
+			$item['hostid'] = $items[$item['itemid']]['hostid'];
+			$item['name'] = $items[$item['itemid']]['name'];
+			$item['key_'] = $items[$item['itemid']]['key_'];
+			$item['flags'] = $items[$item['itemid']]['flags'];
+		}
+		unset($item);
+
+		$data['items'] = CMacrosResolverHelper::resolveItemNames($data['items']);
+	}
 
 	$data['items'] = array_values($data['items']);
 	$itemCount = count($data['items']);
@@ -574,23 +609,27 @@ elseif (isset($_REQUEST['form'])) {
 	$graphView->show();
 }
 else {
+	$sortField = getRequest('sort', CProfile::get('web.'.$page['file'].'.sort', 'name'));
+	$sortOrder = getRequest('sortorder', CProfile::get('web.'.$page['file'].'.sortorder', ZBX_SORT_UP));
+
+	CProfile::update('web.'.$page['file'].'.sort', $sortField, PROFILE_TYPE_STR);
+	CProfile::update('web.'.$page['file'].'.sortorder', $sortOrder, PROFILE_TYPE_STR);
+
 	$data = array(
 		'pageFilter' => $pageFilter,
-		'hostid' => ($pageFilter->hostid > 0) ? $pageFilter->hostid : get_request('hostid'),
-		'parent_discoveryid' => get_request('parent_discoveryid'),
+		'hostid' => ($pageFilter->hostid > 0) ? $pageFilter->hostid : getRequest('hostid'),
+		'parent_discoveryid' => getRequest('parent_discoveryid'),
 		'graphs' => array(),
 		'discovery_rule' => empty($_REQUEST['parent_discoveryid']) ? null : $discovery_rule,
-		'displayNodes' => (is_array(get_current_nodeid()) && $pageFilter->groupid == 0 && $pageFilter->hostid == 0)
+		'sort' => $sortField,
+		'sortorder' => $sortOrder
 	);
 
-	$sortfield = getPageSortField('name');
-	$sortorder = getPageSortOrder();
-
 	// get graphs
 	$options = array(
 		'hostids' => $data['hostid'] ? $data['hostid'] : null,
 		'groupids' => (!$data['hostid'] && $pageFilter->groupid > 0) ? $pageFilter->groupid : null,
-		'discoveryids' => empty($_REQUEST['parent_discoveryid']) ? null : get_request('parent_discoveryid'),
+		'discoveryids' => empty($_REQUEST['parent_discoveryid']) ? null : getRequest('parent_discoveryid'),
 		'editable' => true,
 		'output' => array('graphid', 'name', 'graphtype'),
 		'limit' => $config['search_limit'] + 1
@@ -600,22 +639,15 @@ else {
 		? API::Graph()->get($options)
 		: API::GraphPrototype()->get($options);
 
-	if ($sortfield == 'graphtype') {
+	if ($sortField == 'graphtype') {
 		foreach ($data['graphs'] as $gnum => $graph) {
 			$data['graphs'][$gnum]['graphtype'] = graphType($graph['graphtype']);
 		}
 	}
 
-	order_result($data['graphs'], $sortfield, $sortorder);
+	order_result($data['graphs'], $sortField, $sortOrder);
 
-	$data['paging'] = getPagingLine(
-		$data['graphs'],
-		array('graphid'),
-		array(
-			'hostid' => get_request('hostid'),
-			'parent_discoveryid' => get_request('parent_discoveryid')
-		)
-	);
+	$data['paging'] = getPagingLine($data['graphs']);
 
 	// get graphs after paging
 	$options = array(
@@ -634,14 +666,7 @@ else {
 		$data['graphs'][$gnum]['graphtype'] = graphType($graph['graphtype']);
 	}
 
-	// nodes
-	if ($data['displayNodes']) {
-		foreach ($data['graphs'] as $key => $graph) {
-			$data['graphs'][$key]['nodename'] = get_node_name_by_elid($graph['graphid'], true);
-		}
-	}
-
-	order_result($data['graphs'], $sortfield, $sortorder);
+	order_result($data['graphs'], $sortField, $sortOrder);
 
 	// render view
 	$graphView = new CView('configuration.graph.list', $data);
