@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2000-2011 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -17,8 +17,8 @@
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
-?>
-<?php
+
+
 require_once dirname(__FILE__).'/include/config.inc.php';
 require_once dirname(__FILE__).'/include/hosts.inc.php';
 require_once dirname(__FILE__).'/include/items.inc.php';
@@ -35,11 +35,11 @@ require_once dirname(__FILE__).'/include/page_header.php';
 
 // VAR	TYPE	OPTIONAL	FLAGS	VALIDATION	EXCEPTION
 $fields = array(
-	'hostid' =>					array(T_ZBX_INT, O_NO,	P_SYS,	DB_ID,		'(isset({form})&&({form}=="update"))'),
+	'hostid' =>					array(T_ZBX_INT, O_NO,	P_SYS,	DB_ID,		'(isset({form}) && ({form} == "update"))'),
 	'parent_discoveryid' =>		array(T_ZBX_INT, O_MAND, P_SYS,	DB_ID, null),
-	'host' =>		        	array(T_ZBX_STR, O_OPT, null,		NOT_EMPTY,	'isset({save})', _('Host name')),
-	'name' =>	            	array(T_ZBX_STR, O_OPT, null,		null,		'isset({save})'),
-	'status' =>		        	array(T_ZBX_INT, O_OPT, null,		        IN(array(HOST_STATUS_NOT_MONITORED, HOST_STATUS_MONITORED)), 'isset({save})'),
+	'host' =>		        	array(T_ZBX_STR, O_OPT, null,		NOT_EMPTY,	'isset({add}) || isset({update})', _('Host name')),
+	'name' =>	            	array(T_ZBX_STR, O_OPT, null,		null,		'isset({add}) || isset({update})'),
+	'status' =>		        	array(T_ZBX_INT, O_OPT, null,		IN(array(HOST_STATUS_NOT_MONITORED, HOST_STATUS_MONITORED)), null),
 	'inventory_mode' =>			array(T_ZBX_INT, O_OPT, null, IN(array(HOST_INVENTORY_DISABLED, HOST_INVENTORY_MANUAL, HOST_INVENTORY_AUTOMATIC)), null),
 	'templates' =>		    	array(T_ZBX_STR, O_OPT, null, NOT_EMPTY,	null),
 	'add_template' =>			array(T_ZBX_STR, O_OPT, null,		null,	null),
@@ -48,22 +48,29 @@ $fields = array(
 	'group_prototypes' =>		array(T_ZBX_STR, O_OPT, null, NOT_EMPTY,	null),
 	'unlink' =>					array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,		null),
 	'group_hostid' =>			array(T_ZBX_INT, O_OPT, null,	DB_ID,		null),
-	'go' =>						array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null),
-	'save' =>					array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null),
+	// actions
+	'action' =>					array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,
+									IN('"hostprototype.massdelete","hostprototype.massdisable",'.
+										'"hostprototype.massenable"'
+									),
+									null
+								),
+	'add' =>					array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null),
+	'update' =>					array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null),
 	'clone' =>					array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null),
 	'update' =>					array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null),
 	'delete' =>					array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null),
 	'cancel' =>					array(T_ZBX_STR, O_OPT, P_SYS,	null,		null),
 	'form' =>					array(T_ZBX_STR, O_OPT, P_SYS,	null,		null),
 	'form_refresh' =>			array(T_ZBX_INT, O_OPT, null,	null,		null),
+	// sort and sortorder
+	'sort' =>					array(T_ZBX_STR, O_OPT, P_SYS, IN('"name","status"'),						null),
+	'sortorder' =>				array(T_ZBX_STR, O_OPT, P_SYS, IN('"'.ZBX_SORT_DOWN.'","'.ZBX_SORT_UP.'"'),	null)
 );
 check_fields($fields);
-validate_sort_and_sortorder('name', ZBX_SORT_UP);
-
-$_REQUEST['go'] = get_request('go', 'none');
 
 // permissions
-if (get_request('parent_discoveryid')) {
+if (getRequest('parent_discoveryid')) {
 	$discoveryRule = API::DiscoveryRule()->get(array(
 		'itemids' => $_REQUEST['parent_discoveryid'],
 		'output' => API_OUTPUT_EXTEND,
@@ -75,9 +82,9 @@ if (get_request('parent_discoveryid')) {
 		access_deny();
 	}
 
-	if (get_request('hostid')) {
+	if (getRequest('hostid')) {
 		$hostPrototype = API::HostPrototype()->get(array(
-			'hostids' => get_request('hostid'),
+			'hostids' => getRequest('hostid'),
 			'output' => API_OUTPUT_EXTEND,
 			'selectGroupLinks' => API_OUTPUT_EXTEND,
 			'selectGroupPrototypes' => API_OUTPUT_EXTEND,
@@ -100,27 +107,28 @@ else {
  * Actions
  */
 // add templates to the list
-if (get_request('add_template')) {
-	foreach (get_request('add_templates', array()) as $templateId) {
+if (getRequest('add_template')) {
+	foreach (getRequest('add_templates', array()) as $templateId) {
 		$_REQUEST['templates'][$templateId] = $templateId;
 	}
 }
 // unlink templates
-elseif (get_request('unlink')) {
-	foreach (get_request('unlink') as $templateId => $value) {
+elseif (getRequest('unlink')) {
+	foreach (getRequest('unlink') as $templateId => $value) {
 		unset($_REQUEST['templates'][$templateId]);
 	}
 }
 elseif (isset($_REQUEST['delete']) && isset($_REQUEST['hostid'])) {
-
 	DBstart();
-	$result = API::HostPrototype()->delete(get_request('hostid'));
+	$result = API::HostPrototype()->delete(array(getRequest('hostid')));
+	$result = DBend($result);
 
+	if ($result) {
+		uncheckTableRows($discoveryRule['itemid']);
+	}
 	show_messages($result, _('Host prototype deleted'), _('Cannot delete host prototypes'));
 
 	unset($_REQUEST['hostid'], $_REQUEST['form']);
-	DBend($result);
-	clearCookies($result, $discoveryRule['itemid']);
 }
 elseif (isset($_REQUEST['clone']) && isset($_REQUEST['hostid'])) {
 	unset($_REQUEST['hostid']);
@@ -130,24 +138,23 @@ elseif (isset($_REQUEST['clone']) && isset($_REQUEST['hostid'])) {
 	unset($groupPrototype);
 	$_REQUEST['form'] = 'clone';
 }
-elseif (isset($_REQUEST['save'])) {
+elseif (hasRequest('add') || hasRequest('update')) {
 	DBstart();
 
 	$newHostPrototype = array(
-		'host' => get_request('host'),
-		'name' => get_request('name'),
-		'status' => get_request('status'),
+		'host' => getRequest('host'),
+		'name' => getRequest('name'),
+		'status' => getRequest('status', HOST_STATUS_NOT_MONITORED),
 		'groupLinks' => array(),
 		'groupPrototypes' => array(),
-		'templates' => get_request('templates', array()),
-		'status' => get_request('status'),
+		'templates' => getRequest('templates', array()),
 		'inventory' => array(
-			'inventory_mode' => get_request('inventory_mode')
+			'inventory_mode' => getRequest('inventory_mode')
 		)
 	);
 
 	// add custom group prototypes
-	foreach (get_request('group_prototypes', array()) as $groupPrototype) {
+	foreach (getRequest('group_prototypes', array()) as $groupPrototype) {
 		if (!$groupPrototype['group_prototypeid']) {
 			unset($groupPrototype['group_prototypeid']);
 		}
@@ -157,14 +164,14 @@ elseif (isset($_REQUEST['save'])) {
 		}
 	}
 
-	if (get_request('hostid')) {
-		$newHostPrototype['hostid'] = get_request('hostid');
+	if (getRequest('hostid')) {
+		$newHostPrototype['hostid'] = getRequest('hostid');
 
 		if (!$hostPrototype['templateid']) {
 			// add group prototypes based on existing host groups
 			$groupPrototypesByGroupId = zbx_toHash($hostPrototype['groupLinks'], 'groupid');
 			unset($groupPrototypesByGroupId[0]);
-			foreach (get_request('group_links', array()) as $groupId) {
+			foreach (getRequest('group_links', array()) as $groupId) {
 				if (isset($groupPrototypesByGroupId[$groupId])) {
 					$newHostPrototype['groupLinks'][] = array(
 						'groupid' => $groupPrototypesByGroupId[$groupId]['groupid'],
@@ -188,10 +195,10 @@ elseif (isset($_REQUEST['save'])) {
 		show_messages($result, _('Host prototype updated'), _('Cannot update host prototype'));
 	}
 	else {
-		$newHostPrototype['ruleid'] = get_request('parent_discoveryid');
+		$newHostPrototype['ruleid'] = getRequest('parent_discoveryid');
 
 		// add group prototypes based on existing host groups
-		foreach (get_request('group_links', array()) as $groupId) {
+		foreach (getRequest('group_links', array()) as $groupId) {
 			$newHostPrototype['groupLinks'][] = array(
 				'groupid' => $groupId
 			);
@@ -202,36 +209,53 @@ elseif (isset($_REQUEST['save'])) {
 		show_messages($result, _('Host prototype added'), _('Cannot add host prototype'));
 	}
 
+	$result = DBend($result);
+
 	if ($result) {
+		uncheckTableRows($discoveryRule['itemid']);
 		unset($_REQUEST['itemid'], $_REQUEST['form']);
 	}
-
-	DBend($result);
-	clearCookies($result, $discoveryRule['itemid']);
 }
 // GO
-elseif (($_REQUEST['go'] == 'activate' || $_REQUEST['go'] == 'disable') && isset($_REQUEST['group_hostid'])) {
-	DBstart();
+elseif (hasRequest('action') && str_in_array(getRequest('action'), array('hostprototype.massenable', 'hostprototype.massdisable')) && hasRequest('group_hostid')) {
+	$enable = (getRequest('action') == 'hostprototype.massenable');
+	$status = $enable ? HOST_STATUS_MONITORED : HOST_STATUS_NOT_MONITORED;
 	$update = array();
-	foreach ((array) get_request('group_hostid') as $hostPrototypeId) {
+
+	DBstart();
+	foreach ((array) getRequest('group_hostid') as $hostPrototypeId) {
 		$update[] = array(
 			'hostid' => $hostPrototypeId,
-			'status' => (get_request('go') == 'activate') ? HOST_STATUS_MONITORED : HOST_STATUS_NOT_MONITORED
+			'status' => $status
 		);
 	}
 
-	$go_result = API::HostPrototype()->update($update);
+	$result = API::HostPrototype()->update($update);
+	$result = DBend($result);
 
-	show_messages($go_result, ($_REQUEST['go'] == 'activate') ? _('Host prototypes activated') : _('Host prototypes disabled'), null);
-	DBend($go_result);
-	clearCookies($go_result, $discoveryRule['itemid']);
+	$updated = count($update);
+
+	$messageSuccess = $enable
+		? _n('Host prototype enabled', 'Host prototypes enabled', $updated)
+		: _n('Host prototype disabled', 'Host prototypes disabled', $updated);
+	$messageFailed = $enable
+		? _n('Cannot enable host prototype', 'Cannot enable host prototypes', $updated)
+		: _n('Cannot disable host prototype', 'Cannot disable host prototypes', $updated);
+
+	if ($result) {
+		uncheckTableRows($discoveryRule['itemid']);
+	}
+	show_messages($result, $messageSuccess, $messageFailed);
 }
-elseif ($_REQUEST['go'] == 'delete' && isset($_REQUEST['group_hostid'])) {
+elseif (hasRequest('action') && getRequest('action') == 'hostprototype.massdelete' && getRequest('group_hostid')) {
 	DBstart();
-	$go_result = API::HostPrototype()->delete($_REQUEST['group_hostid']);
-	show_messages($go_result, _('Host prototypes deleted'), _('Cannot delete host prototypes'));
-	DBend($go_result);
-	clearCookies($go_result, $discoveryRule['itemid']);
+	$result = API::HostPrototype()->delete(getRequest('group_hostid'));
+	$result = DBend($result);
+
+	if ($result) {
+		uncheckTableRows($discoveryRule['itemid']);
+	}
+	show_messages($result, _('Host prototypes deleted'), _('Cannot delete host prototypes'));
 }
 
 /*
@@ -241,16 +265,16 @@ if (isset($_REQUEST['form'])) {
 	$data = array(
 		'discovery_rule' => $discoveryRule,
 		'host_prototype' => array(
-			'hostid' => get_request('hostid'),
-			'templateid' => get_request('templateid'),
-			'host' => get_request('host'),
-			'name' => get_request('name'),
-			'status' => get_request('status', HOST_STATUS_MONITORED),
+			'hostid' => getRequest('hostid'),
+			'templateid' => getRequest('templateid'),
+			'host' => getRequest('host'),
+			'name' => getRequest('name'),
+			'status' => getRequest('status', HOST_STATUS_MONITORED),
 			'templates' => array(),
 			'inventory' => array(
-				'inventory_mode' => get_request('inventory_mode', HOST_INVENTORY_DISABLED)
+				'inventory_mode' => getRequest('inventory_mode', HOST_INVENTORY_DISABLED)
 			),
-			'groupPrototypes' => get_request('group_prototypes', array())
+			'groupPrototypes' => getRequest('group_prototypes', array())
 		),
 		'groups' => array()
 	);
@@ -258,7 +282,7 @@ if (isset($_REQUEST['form'])) {
 	// add already linked and new templates
 	$data['host_prototype']['templates'] = API::Template()->get(array(
 		'output' => array('templateid', 'name'),
-		'templateids' => get_request('templates', array())
+		'templateids' => getRequest('templates', array())
 	));
 
 	// add parent host
@@ -273,10 +297,10 @@ if (isset($_REQUEST['form'])) {
 	$parentHost = reset($parentHost);
 	$data['parent_host'] = $parentHost;
 
-	if (get_request('group_links')) {
+	if (getRequest('group_links')) {
 		$data['groups'] = API::HostGroup()->get(array(
 			'output' => API_OUTPUT_EXTEND,
-			'groupids' => get_request('group_links'),
+			'groupids' => getRequest('group_links'),
 			'editable' => true,
 			'preservekeys' => true
 		));
@@ -292,7 +316,7 @@ if (isset($_REQUEST['form'])) {
 	}
 
 	// host prototype edit form
-	if (get_request('hostid') && !get_request('form_refresh')) {
+	if (getRequest('hostid') && !getRequest('form_refresh')) {
 		$data['host_prototype'] = array_merge($data['host_prototype'], $hostPrototype);
 
 		$data['groups'] = API::HostGroup()->get(array(
@@ -333,32 +357,35 @@ if (isset($_REQUEST['form'])) {
 	$itemView->show();
 }
 else {
+	$sortField = getRequest('sort', CProfile::get('web.'.$page['file'].'.sort', 'name'));
+	$sortOrder = getRequest('sortorder', CProfile::get('web.'.$page['file'].'.sortorder', ZBX_SORT_UP));
+
+	CProfile::update('web.'.$page['file'].'.sort', $sortField, PROFILE_TYPE_STR);
+	CProfile::update('web.'.$page['file'].'.sortorder', $sortOrder, PROFILE_TYPE_STR);
+
 	$data = array(
-		'form' => get_request('form', null),
-		'parent_discoveryid' => get_request('parent_discoveryid', null),
-		'discovery_rule' => $discoveryRule
+		'form' => getRequest('form'),
+		'parent_discoveryid' => getRequest('parent_discoveryid'),
+		'discovery_rule' => $discoveryRule,
+		'sort' => $sortField,
+		'sortorder' => $sortOrder
 	);
 
 	// get items
-	$sortfield = getPageSortField('name');
 	$data['hostPrototypes'] = API::HostPrototype()->get(array(
 		'discoveryids' => $data['parent_discoveryid'],
 		'output' => API_OUTPUT_EXTEND,
 		'selectTemplates' => array('templateid', 'name'),
 		'editable' => true,
-		'sortfield' => $sortfield,
+		'sortfield' => $sortField,
 		'limit' => $config['search_limit'] + 1
 	));
 
 	if ($data['hostPrototypes']) {
-		order_result($data['hostPrototypes'], $sortfield, getPageSortOrder());
+		order_result($data['hostPrototypes'], $sortField, $sortOrder);
 	}
 
-	$data['paging'] = getPagingLine(
-		$data['hostPrototypes'],
-		array('hostid'),
-		array('parent_discoveryid' => get_request('parent_discoveryid'))
-	);
+	$data['paging'] = getPagingLine($data['hostPrototypes']);
 
 	// fetch templates linked to the prototypes
 	$templateIds = array();
@@ -368,6 +395,7 @@ else {
 	$templateIds = array_unique($templateIds);
 
 	$linkedTemplates = API::Template()->get(array(
+		'output' => array('templateid', 'name'),
 		'templateids' => $templateIds,
 		'selectParentTemplates' => array('hostid', 'name')
 	));
@@ -405,4 +433,3 @@ else {
 }
 
 require_once dirname(__FILE__).'/include/page_footer.php';
-?>
