@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -22,30 +22,51 @@
 /**
  * A class for creating a storing instances of DB objects managers.
  */
-class Manager extends CFactoryRegistry {
+class Manager extends CRegistryFactory {
 
-	public static function getInstance($class = __CLASS__) {
-		return parent::getInstance($class);
+	/**
+	 * An instance of the manager factory.
+	 *
+	 * @var Manager
+	 */
+	protected static $instance;
+
+	/**
+	 * Returns an instance of the manager factory object.
+	 *
+	 * @return Manager
+	 */
+	public static function getInstance() {
+		if (!self::$instance) {
+			$class = __CLASS__;
+			self::$instance = new $class(array(
+				'application' => 'CApplicationManager',
+				'history' => 'CHistoryManager',
+				'httptest' => 'CHttpTestManager'
+			));
+		}
+
+		return self::$instance;
 	}
 
 	/**
 	 * @return CApplicationManager
 	 */
 	public static function Application() {
-		return self::getInstance()->getObject('CApplicationManager');
+		return self::getInstance()->getObject('application');
 	}
 
 	/**
 	 * @return CHistoryManager
 	 */
 	public static function History() {
-		return self::getInstance()->getObject('CHistoryManager');
+		return self::getInstance()->getObject('history');
 	}
 
 	/**
 	 * @return CHttpTestManager
 	 */
 	public static function HttpTest() {
-		return self::getInstance()->getObject('CHttpTestManager');
+		return self::getInstance()->getObject('httptest');
 	}
 }
