@@ -1,7 +1,7 @@
 <?php
 /*
  ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -144,4 +144,83 @@ class CArrayHelper {
 		}
 		return 0;
 	}
+
+	/**
+	 * Unset values that are contained in $a2 from $a1. Skip arrays and keys given in $skipKeys.
+	 *
+	 * @param array $a1         array to modify
+	 * @param array $a2         array to compare with
+	 * @param array $skipKeys   fields to ignore
+	 *
+	 * @return array
+	 */
+	public static function unsetEqualValues(array $a1, array $a2, array $skipKeys = array()) {
+		// ignore given fields
+		foreach ($skipKeys as $key) {
+			unset($a2[$key]);
+		}
+
+		foreach ($a1 as $key => $value) {
+			// check if the values under $key are equal, skip arrays
+			if (isset($a2[$key]) && !is_array($value) && (string) $a1[$key] === (string) $a2[$key]) {
+				unset($a1[$key]);
+			}
+		}
+
+		return $a1;
+	}
+
+	/**
+	 * Checks if array $arrays contains arrays with duplicate values under the $uniqueField key. If a duplicate exists,
+	 * returns the first duplicate, otherwise returns null.
+	 *
+	 * Example 1:
+	 * $data = array(
+	 *     array('name' => 'CPU load'),
+	 * 	   array('name' => 'CPU load'),
+	 * 	   array('name' => 'Free memory')
+	 * );
+	 * var_dump(CArrayHelper::findDuplicate($data, 'name')); // returns array with index 1
+	 *
+	 * Example 2:
+	 * $data = array(
+	 *     array('host' => 'Zabbix server', 'name' => 'CPU load'),
+	 * 	   array('host' => 'Zabbix server', 'name' => 'Free memory'),
+	 * 	   array('host' => 'Linux server', 'name' => 'CPU load'),
+	 * 	   array('host' => 'Zabbix server', 'name' => 'CPU load')
+	 * );
+	 * var_dump(CArrayHelper::findDuplicate($data, 'name', 'host')); // returns array with index 3
+	 *
+	 * @param array $arrays         an array of arrays
+	 * @param string $uniqueField   key to be used as unique criteria
+	 * @param string $uniqueField2	second key to be used as unique criteria
+	 *
+	 * @return null|array           the first duplicate found or null if there are no duplicates
+	 */
+	public static function findDuplicate(array $arrays, $uniqueField, $uniqueField2 = null) {
+		$uniqueValues = array();
+
+		foreach ($arrays as $array) {
+			$value = $array[$uniqueField];
+
+			if ($uniqueField2 !== null) {
+				$uniqueByValue = $array[$uniqueField2];
+
+				if (isset($uniqueValues[$uniqueByValue]) && isset($uniqueValues[$uniqueByValue][$value])) {
+					return $array;
+				}
+				else {
+					$uniqueValues[$uniqueByValue][$value] = $value;
+				}
+			}
+			else {
+				if (isset($uniqueValues[$value])) {
+					return $array;
+				}
+				else {
+					$uniqueValues[$value] = $value;
+				}
+			}
+		}
+	}
 }
