@@ -50,6 +50,13 @@ class CScreenBase {
 	 */
 	public $resourcetype;
 
+	/**
+	 * Is templated screen
+	 *
+	 * @var bool
+	 */
+	public $isTemplatedScreen;
+
 	/**
 	 * Screen id
 	 *
@@ -123,6 +130,7 @@ class CScreenBase {
 	 * @param int		$options['mode']
 	 * @param int		$options['timestamp']
 	 * @param int		$options['resourcetype']
+	 * @param bool		$options['isTemplatedScreen']
 	 * @param int		$options['screenid']
 	 * @param array		$options['screenitem']
 	 * @param string	$options['action']
@@ -141,10 +149,11 @@ class CScreenBase {
 		$this->mode = isset($options['mode']) ? $options['mode'] : SCREEN_MODE_SLIDESHOW;
 		$this->timestamp = !empty($options['timestamp']) ? $options['timestamp'] : time();
 		$this->resourcetype = isset($options['resourcetype']) ? $options['resourcetype'] : null;
+		$this->isTemplatedScreen = isset($options['isTemplatedScreen']) ? $options['isTemplatedScreen'] : false;
 		$this->screenid = !empty($options['screenid']) ? $options['screenid'] : null;
 		$this->action = !empty($options['action']) ? $options['action'] : null;
 		$this->groupid = !empty($options['groupid']) ? $options['groupid'] : null;
-		$this->hostid = !empty($options['hostid']) ? $options['hostid'] : null;
+		$this->hostid = isset($options['hostid']) ? $options['hostid'] : 0;
 		$this->dataId = !empty($options['dataId']) ? $options['dataId'] : null;
 
 		// get page file
@@ -176,7 +185,7 @@ class CScreenBase {
 			$this->screenitem = $options['screenitem'];
 		}
 		elseif (!empty($options['screenitemid'])) {
-			if (!empty($this->hostid)) {
+			if ($this->hostid != 0) {
 				$this->screenitem = API::TemplateScreenItem()->get(array(
 					'screenitemids' => $options['screenitemid'],
 					'hostids' => $this->hostid,
