@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -28,17 +28,19 @@ class CScreenGraph extends CScreenBase {
 	 */
 	public function get() {
 		$this->dataId = 'graph_'.$this->screenitem['screenitemid'].'_'.$this->screenitem['screenid'];
-		$resourceid = !empty($this->screenitem['real_resourceid']) ? $this->screenitem['real_resourceid'] : $this->screenitem['resourceid'];
-		$containerid = 'graph_container_'.$this->screenitem['screenitemid'].'_'.$this->screenitem['screenid'];
-		$graphDims = getGraphDims($resourceid);
+		$resourceId = isset($this->screenitem['real_resourceid'])
+			? $this->screenitem['real_resourceid']
+			: $this->screenitem['resourceid'];
+		$containerId = 'graph_container_'.$this->screenitem['screenitemid'].'_'.$this->screenitem['screenid'];
+		$graphDims = getGraphDims($resourceId);
 		$graphDims['graphHeight'] = $this->screenitem['height'];
 		$graphDims['width'] = $this->screenitem['width'];
-		$graph = get_graph_by_graphid($resourceid);
-		$graphid = $graph['graphid'];
+		$graph = getGraphByGraphId($resourceId);
+		$graphId = $graph['graphid'];
 		$legend = $graph['show_legend'];
 		$graph3d = $graph['show_3d'];
 
-		if ($this->screenitem['dynamic'] == SCREEN_DYNAMIC_ITEM && !empty($this->hostid)) {
+		if ($this->screenitem['dynamic'] == SCREEN_DYNAMIC_ITEM && $this->hostid) {
 			// get host
 			$hosts = API::Host()->get(array(
 				'hostids' => $this->hostid,
@@ -48,9 +50,9 @@ class CScreenGraph extends CScreenBase {
 
 			// get graph
 			$graph = API::Graph()->get(array(
-				'graphids' => $resourceid,
+				'graphids' => $resourceId,
 				'output' => API_OUTPUT_EXTEND,
-				'selectHosts' => API_OUTPUT_REFER,
+				'selectHosts' => array('hostid'),
 				'selectGraphItems' => API_OUTPUT_EXTEND
 			));
 			$graph = reset($graph);
@@ -58,15 +60,15 @@ class CScreenGraph extends CScreenBase {
 			// if items from one host we change them, or set calculated if not exist on that host
 			if (count($graph['hosts']) == 1) {
 				if ($graph['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE && $graph['ymax_itemid']) {
-					$newDinamic = getSameGraphItemsForHost(
+					$newDynamic = getSameGraphItemsForHost(
 						array(array('itemid' => $graph['ymax_itemid'])),
 						$this->hostid,
 						false
 					);
-					$newDinamic = reset($newDinamic);
+					$newDynamic = reset($newDynamic);
 
-					if (isset($newDinamic['itemid']) && $newDinamic['itemid'] > 0) {
-						$graph['ymax_itemid'] = $newDinamic['itemid'];
+					if (isset($newDynamic['itemid']) && $newDynamic['itemid'] > 0) {
+						$graph['ymax_itemid'] = $newDynamic['itemid'];
 					}
 					else {
 						$graph['ymax_type'] = GRAPH_YAXIS_TYPE_CALCULATED;
@@ -74,15 +76,15 @@ class CScreenGraph extends CScreenBase {
 				}
 
 				if ($graph['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE && $graph['ymin_itemid']) {
-					$newDinamic = getSameGraphItemsForHost(
+					$newDynamic = getSameGraphItemsForHost(
 						array(array('itemid' => $graph['ymin_itemid'])),
 						$this->hostid,
 						false
 					);
-					$newDinamic = reset($newDinamic);
+					$newDynamic = reset($newDynamic);
 
-					if (isset($newDinamic['itemid']) && $newDinamic['itemid'] > 0) {
-						$graph['ymin_itemid'] = $newDinamic['itemid'];
+					if (isset($newDynamic['itemid']) && $newDynamic['itemid'] > 0) {
+						$graph['ymin_itemid'] = $newDynamic['itemid'];
 					}
 					else {
 						$graph['ymin_type'] = GRAPH_YAXIS_TYPE_CALCULATED;
@@ -119,7 +121,7 @@ class CScreenGraph extends CScreenBase {
 		// get time control
 		$timeControlData = array(
 			'id' => $this->getDataId(),
-			'containerid' => $containerid,
+			'containerid' => $containerId,
 			'objDims' => $graphDims,
 			'loadSBox' => 0,
 			'loadImage' => 1,
@@ -129,33 +131,34 @@ class CScreenGraph extends CScreenBase {
 
 		$isDefault = false;
 		if ($graphDims['graphtype'] == GRAPH_TYPE_PIE || $graphDims['graphtype'] == GRAPH_TYPE_EXPLODED) {
-			if ($this->screenitem['dynamic'] == SCREEN_SIMPLE_ITEM || empty($this->screenitem['url'])) {
-				$this->screenitem['url'] = 'chart6.php?graphid='.$resourceid.'&screenid='.$this->screenitem['screenid'];
+			if ($this->screenitem['dynamic'] == SCREEN_SIMPLE_ITEM || !$this->screenitem['url']) {
+				$this->screenitem['url'] = 'chart6.php?graphid='.$resourceId.'&screenid='.$this->screenitem['screenid'];
 				$isDefault = true;
 			}
 
-			$this->timeline['starttime'] = date(TIMESTAMP_FORMAT, get_min_itemclock_by_graphid($resourceid));
+			$this->timeline['starttime'] = date(TIMESTAMP_FORMAT, get_min_itemclock_by_graphid($resourceId));
 
-			$timeControlData['src'] = $this->screenitem['url'].'&width='.$this->screenitem['width'].'&height='.$this->screenitem['height']
-				.'&legend='.$legend.'&graph3d='.$graph3d.$this->getProfileUrlParams();
+			$timeControlData['src'] = $this->screenitem['url'].'&width='.$this->screenitem['width']
+				.'&height='.$this->screenitem['height'].'&legend='.$legend
+				.'&graph3d='.$graph3d.$this->getProfileUrlParams();
 			$timeControlData['src'] .= ($this->mode == SCREEN_MODE_EDIT)
 				? '&period=3600&stime='.date(TIMESTAMP_FORMAT, time())
 				: '&period='.$this->timeline['period'].'&stime='.$this->timeline['stimeNow'];
 		}
 		else {
-			if ($this->screenitem['dynamic'] == SCREEN_SIMPLE_ITEM || empty($this->screenitem['url'])) {
-				$this->screenitem['url'] = 'chart2.php?graphid='.$resourceid.'&screenid='.$this->screenitem['screenid'];
+			if ($this->screenitem['dynamic'] == SCREEN_SIMPLE_ITEM || !$this->screenitem['url']) {
+				$this->screenitem['url'] = 'chart2.php?graphid='.$resourceId.'&screenid='.$this->screenitem['screenid'];
 				$isDefault = true;
 			}
 
-			if ($this->mode != SCREEN_MODE_EDIT && !empty($graphid)) {
+			if ($this->mode != SCREEN_MODE_EDIT && $graphId) {
 				if ($this->mode == SCREEN_MODE_PREVIEW) {
 					$timeControlData['loadSBox'] = 1;
 				}
 			}
 
-			$timeControlData['src'] = $this->screenitem['url'].'&width='.$this->screenitem['width'].'&height='.$this->screenitem['height']
-				.$this->getProfileUrlParams();
+			$timeControlData['src'] = $this->screenitem['url'].'&width='.$this->screenitem['width']
+				.'&height='.$this->screenitem['height'].'&legend='.$legend.$this->getProfileUrlParams();
 			$timeControlData['src'] .= ($this->mode == SCREEN_MODE_EDIT)
 				? '&period=3600&stime='.date(TIMESTAMP_FORMAT, time())
 				: '&period='.$this->timeline['period'].'&stime='.$this->timeline['stimeNow'];
@@ -163,24 +166,29 @@ class CScreenGraph extends CScreenBase {
 
 		// output
 		if ($this->mode == SCREEN_MODE_JS) {
-			return 'timeControl.addObject("'.$this->getDataId().'", '.zbx_jsvalue($this->timeline).', '.zbx_jsvalue($timeControlData).')';
+			return 'timeControl.addObject("'.$this->getDataId().'", '.CJs::encodeJson($this->timeline).', '
+				.CJs::encodeJson($timeControlData).')';
 		}
 		else {
 			if ($this->mode == SCREEN_MODE_SLIDESHOW) {
-				insert_js('timeControl.addObject("'.$this->getDataId().'", '.zbx_jsvalue($this->timeline).', '.zbx_jsvalue($timeControlData).');');
+				insert_js('timeControl.addObject("'.$this->getDataId().'", '.CJs::encodeJson($this->timeline).', '
+					.CJs::encodeJson($timeControlData).');'
+				);
 			}
 			else {
-				zbx_add_post_js('timeControl.addObject("'.$this->getDataId().'", '.zbx_jsvalue($this->timeline).', '.zbx_jsvalue($timeControlData).');');
+				zbx_add_post_js('timeControl.addObject("'.$this->getDataId().'", '.CJs::encodeJson($this->timeline).', '
+					.CJs::encodeJson($timeControlData).');'
+				);
 			}
 
 			if (($this->mode == SCREEN_MODE_EDIT || $this->mode == SCREEN_MODE_SLIDESHOW) || !$isDefault) {
 				$item = new CDiv();
 			}
 			elseif ($this->mode == SCREEN_MODE_PREVIEW) {
-				$item = new CLink(null, 'charts.php?graphid='.$resourceid.'&period='.$this->timeline['period'].
+				$item = new CLink(null, 'charts.php?graphid='.$resourceId.'&period='.$this->timeline['period'].
 						'&stime='.$this->timeline['stimeNow']);
 			}
-			$item->setAttribute('id', $containerid);
+			$item->setAttribute('id', $containerId);
 
 			return $this->getOutput($item);
 		}
