@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -22,11 +22,15 @@
 class CScreenHistory extends CScreenBase {
 
 	/**
-	 * Item ids
+	 * Type of graph to display.
 	 *
-	 * @var array
+	 * Supported values:
+	 * - GRAPH_TYPE_NORMAL
+	 * - GRAPH_TYPE_STACKED
+	 *
+	 * @var int
 	 */
-	public $itemids;
+	protected $graphType;
 
 	/**
 	 * Search string
@@ -63,24 +67,15 @@ class CScreenHistory extends CScreenBase {
 	 */
 	public $items;
 
-	/**
-	 * Item data
-	 *
-	 * @var array
-	 */
-	public $item;
-
 	/**
 	 * Init screen data.
 	 *
 	 * @param array		$options
-	 * @param array		$options['itemids']
 	 * @param string	$options['filter']
 	 * @param int		$options['filterTask']
 	 * @param int		$options['markColor']
 	 * @param boolean	$options['plaintext']
 	 * @param array		$options['items']
-	 * @param array		$options['item']
 	 */
 	public function __construct(array $options = array()) {
 		parent::__construct($options);
@@ -88,28 +83,14 @@ class CScreenHistory extends CScreenBase {
 		$this->resourcetype = SCREEN_RESOURCE_HISTORY;
 
 		// mandatory
-		$this->itemids = isset($options['itemids']) ? $options['itemids'] : null;
-		$this->filter = isset($options['filter']) ? $options['filter'] : null;
+		$this->filter = isset($options['filter']) ? $options['filter'] : '';
 		$this->filterTask = isset($options['filter_task']) ? $options['filter_task'] : null;
 		$this->markColor = isset($options['mark_color']) ? $options['mark_color'] : MARK_COLOR_RED;
+		$this->graphType = isset($options['graphtype']) ? $options['graphtype'] : GRAPH_TYPE_NORMAL;
 
 		// optional
 		$this->items = isset($options['items']) ? $options['items'] : null;
-		$this->item = isset($options['item']) ? $options['item'] : null;
 		$this->plaintext = isset($options['plaintext']) ? $options['plaintext'] : false;
-
-		if (empty($this->items)) {
-			$this->items = API::Item()->get(array(
-				'nodeids' => get_current_nodeid(),
-				'itemids' => $this->itemids,
-				'webitems' => true,
-				'selectHosts' => array('name'),
-				'output' => array('itemid', 'key_', 'name', 'value_type', 'valuemapid'),
-				'preservekeys' => true
-			));
-
-			$this->item = reset($this->items);
-		}
 	}
 
 	/**
@@ -121,6 +102,8 @@ class CScreenHistory extends CScreenBase {
 		$output = array();
 
 		$stime = zbxDateToTime($this->timeline['stime']);
+		$itemIds = zbx_objectValues($this->items, 'itemid');
+		$firstItem = reset($this->items);
 
 		$iv_string = array(
 			ITEM_VALUE_TYPE_LOG => 1,
@@ -131,17 +114,17 @@ class CScreenHistory extends CScreenBase {
 			ITEM_VALUE_TYPE_UINT64 => 1
 		);
 
-		if ($this->action == 'showvalues' || $this->action == 'showlatest') {
+		if ($this->action == HISTORY_VALUES || $this->action == HISTORY_LATEST) {
 			$options = array(
-				'history' => $this->item['value_type'],
-				'itemids' => array_keys($this->items),
+				'history' => $firstItem['value_type'],
+				'itemids' => $itemIds,
 				'output' => API_OUTPUT_EXTEND,
 				'sortorder' => ZBX_SORT_DOWN
 			);
-			if ($this->action == 'showlatest') {
+			if ($this->action == HISTORY_LATEST) {
 				$options['limit'] = 500;
 			}
-			elseif ($this->action == 'showvalues') {
+			elseif ($this->action == HISTORY_VALUES) {
 				$config = select_config();
 
 				$options['time_from'] = $stime - 10; // some seconds to allow script to execute
@@ -150,10 +133,10 @@ class CScreenHistory extends CScreenBase {
 			}
 
 			// text log
-			if (isset($iv_string[$this->item['value_type']])) {
+			if (isset($iv_string[$firstItem['value_type']])) {
 				$isManyItems = (count($this->items) > 1);
-				$useLogItem = ($this->item['value_type'] == ITEM_VALUE_TYPE_LOG);
-				$useEventLogItem = (strpos($this->item['key_'], 'eventlog[') === 0);
+				$useLogItem = ($firstItem['value_type'] == ITEM_VALUE_TYPE_LOG);
+				$useEventLogItem = (strpos($firstItem['key_'], 'eventlog[') === 0);
 
 				if (empty($this->plaintext)) {
 					$historyTable = new CTableInfo(_('No values found.'));
@@ -171,7 +154,7 @@ class CScreenHistory extends CScreenBase {
 					);
 				}
 
-				if (!zbx_empty($this->filter) && in_array($this->filterTask, array(FILTER_TASK_SHOW, FILTER_TASK_HIDE))) {
+				if ($this->filter !== '' && in_array($this->filterTask, array(FILTER_TASK_SHOW, FILTER_TASK_HIDE))) {
 					$options['search'] = array('value' => $this->filter);
 					if ($this->filterTask == FILTER_TASK_HIDE) {
 						$options['excludeSearch'] = 1;
@@ -182,20 +165,22 @@ class CScreenHistory extends CScreenBase {
 				$historyData = API::History()->get($options);
 
 				foreach ($historyData as $data) {
-					$data['value'] = encode_log(trim($data['value'], "\r\n"));
+					$data['value'] = trim($data['value'], "\r\n");
 
 					if (empty($this->plaintext)) {
 						$item = $this->items[$data['itemid']];
 						$host = reset($item['hosts']);
 						$color = null;
 
-						if (isset($this->filter) && !zbx_empty($this->filter)) {
-							$contain = zbx_stristr($data['value'], $this->filter);
+						if ($this->filter !== '') {
+							$haystack = mb_strtolower($data['value']);
+							$needle = mb_strtolower($this->filter);
+							$pos = mb_strpos($haystack, $needle);
 
-							if ($contain && $this->filterTask == FILTER_TASK_MARK) {
+							if ($pos !== false && $this->filterTask == FILTER_TASK_MARK) {
 								$color = $this->markColor;
 							}
-							if (!$contain && $this->filterTask == FILTER_TASK_INVERT_MARK) {
+							elseif ($pos === false && $this->filterTask == FILTER_TASK_INVERT_MARK) {
 								$color = $this->markColor;
 							}
 
@@ -212,18 +197,20 @@ class CScreenHistory extends CScreenBase {
 							}
 						}
 
-						$row = array(nbsp(zbx_date2str(_('Y.M.d H:i:s'), $data['clock'])));
+						$row = array(nbsp(zbx_date2str(DATE_TIME_FORMAT_SECONDS, $data['clock'])));
 
 						if ($isManyItems) {
-							$row[] = $host['name'].NAME_DELIMITER.itemName($item);
+							$row[] = $host['name'].NAME_DELIMITER.$item['name_expanded'];
 						}
 
 						if ($useLogItem) {
-							$row[] = ($data['timestamp'] == 0) ? '-' : zbx_date2str(HISTORY_LOG_LOCALTIME_DATE_FORMAT, $data['timestamp']);
+							$row[] = ($data['timestamp'] == 0)
+								? '-'
+								: zbx_date2str(DATE_TIME_FORMAT_SECONDS, $data['timestamp']);
 
 							// if this is a eventLog item, showing additional info
 							if ($useEventLogItem) {
-								$row[] = zbx_empty($data['source']) ? '-' : $data['source'];
+								$row[] = ($data['source'] === '') ? '-' : $data['source'];
 								$row[] = ($data['severity'] == 0)
 								? '-'
 								: new CCol(get_item_logtype_description($data['severity']), get_item_logtype_style($data['severity']));
@@ -234,22 +221,14 @@ class CScreenHistory extends CScreenBase {
 						$row[] = new CCol($data['value'], 'pre');
 
 						$newRow = new CRow($row);
-						if (is_null($color)) {
-							$min_color = 0x98;
-							$max_color = 0xF8;
-							$int_color = ($max_color - $min_color) / count($this->itemids);
-							$int_color *= array_search($data['itemid'], $this->itemids);
-							$int_color += $min_color;
-							$newRow->setAttribute('style', 'background-color: '.sprintf("#%X%X%X", $int_color, $int_color, $int_color));
-						}
-						elseif (!is_null($color)) {
+						if (!is_null($color)) {
 							$newRow->setAttribute('class', $color);
 						}
 
 						$historyTable->addRow($newRow);
 					}
 					else {
-						$output[] = zbx_date2str(HISTORY_LOG_ITEM_PLAINTEXT, $data['clock']);
+						$output[] = zbx_date2str(DATE_TIME_FORMAT_SECONDS, $data['clock']);
 						$output[] = "\t".$data['clock']."\t".htmlspecialchars($data['value'])."\n";
 					}
 				}
@@ -285,13 +264,13 @@ class CScreenHistory extends CScreenBase {
 						}
 
 						$historyTable->addRow(array(
-							zbx_date2str(HISTORY_ITEM_DATE_FORMAT, $data['clock']),
+							zbx_date2str(DATE_TIME_FORMAT_SECONDS, $data['clock']),
 							zbx_nl2br($value)
 						));
 					}
 					// plain text
 					else {
-						$output[] = zbx_date2str(HISTORY_PLAINTEXT_DATE_FORMAT, $data['clock']);
+						$output[] = zbx_date2str(DATE_TIME_FORMAT_SECONDS, $data['clock']);
 						$output[] = "\t".$data['clock']."\t".htmlspecialchars($value)."\n";
 					}
 				}
@@ -302,36 +281,32 @@ class CScreenHistory extends CScreenBase {
 			}
 		}
 
-		if ($this->action == 'showgraph' && !isset($iv_string[$this->item['value_type']])) {
-			$this->dataId = 'historyGraph';
-			$containerId = 'graph_cont1';
-			$src = 'chart.php?itemid='.$this->item['itemid'].'&period='.$this->timeline['period'].'&stime='.$this->timeline['stime'].$this->getProfileUrlParams();
-
-			$output[] = new CDiv(null, 'center', $containerId);
-		}
-
 		// time control
-		if (!$this->plaintext && str_in_array($this->action, array('showvalues', 'showgraph'))) {
+		if (!$this->plaintext && str_in_array($this->action, array(HISTORY_VALUES, HISTORY_GRAPH, HISTORY_BATCH_GRAPH))) {
 			$graphDims = getGraphDims();
 
-			$this->timeline['starttime'] = date(TIMESTAMP_FORMAT, get_min_itemclock_by_itemid($this->item['itemid']));
+			$this->timeline['starttime'] = date(TIMESTAMP_FORMAT, get_min_itemclock_by_itemid($firstItem['itemid']));
+
+			$this->dataId = 'historyGraph';
 
 			$timeControlData = array(
 				'periodFixed' => CProfile::get('web.history.timelinefixed', 1),
 				'sliderMaximumTimePeriod' => ZBX_MAX_PERIOD
 			);
 
-			if (!empty($this->dataId)) {
+			if (($this->action == HISTORY_GRAPH || $this->action == HISTORY_BATCH_GRAPH) && !isset($iv_string[$firstItem['value_type']])) {
+				$containerId = 'graph_cont1';
+				$output[] = new CDiv(null, 'center', $containerId);
+
 				$timeControlData['id'] = $this->getDataId();
 				$timeControlData['containerid'] = $containerId;
-				$timeControlData['src'] = $src;
+				$timeControlData['src'] = $this->getGraphUrl($itemIds);
 				$timeControlData['objDims'] = $graphDims;
 				$timeControlData['loadSBox'] = 1;
 				$timeControlData['loadImage'] = 1;
 				$timeControlData['dynamic'] = 1;
 			}
 			else {
-				$this->dataId = 'historyGraph';
 				$timeControlData['id'] = $this->getDataId();
 				$timeControlData['mainObject'] = 1;
 			}
@@ -339,10 +314,10 @@ class CScreenHistory extends CScreenBase {
 			if ($this->mode == SCREEN_MODE_JS) {
 				$timeControlData['dynamic'] = 0;
 
-				return 'timeControl.addObject("'.$this->getDataId().'", '.zbx_jsvalue($this->timeline).', '.zbx_jsvalue($timeControlData).');';
+				return 'timeControl.addObject("'.$this->getDataId().'", '.CJs::encodeJson($this->timeline).', '.CJs::encodeJson($timeControlData).');';
 			}
 			else {
-				zbx_add_post_js('timeControl.addObject("'.$this->getDataId().'", '.zbx_jsvalue($this->timeline).', '.zbx_jsvalue($timeControlData).');');
+				zbx_add_post_js('timeControl.addObject("'.$this->getDataId().'", '.CJs::encodeJson($this->timeline).', '.CJs::encodeJson($timeControlData).');');
 			}
 		}
 
@@ -352,8 +327,8 @@ class CScreenHistory extends CScreenBase {
 		else {
 			if ($this->mode != SCREEN_MODE_JS) {
 				$flickerfreeData = array(
-					'itemids' => $this->itemids,
-					'action' => $this->action,
+					'itemids' => $itemIds,
+					'action' => ($this->action == HISTORY_BATCH_GRAPH) ? HISTORY_GRAPH : $this->action,
 					'filter' => $this->filter,
 					'filterTask' => $this->filterTask,
 					'markColor' => $this->markColor
@@ -363,4 +338,25 @@ class CScreenHistory extends CScreenBase {
 			}
 		}
 	}
+
+	/**
+	 * Return the URL for the graph.
+	 *
+	 * @param array $itemIds
+	 *
+	 * @return string
+	 */
+	protected function getGraphUrl(array $itemIds) {
+		$url = new CUrl('chart.php');
+		$url->setArgument('period', $this->timeline['period']);
+		$url->setArgument('stime', $this->timeline['stime']);
+		$url->setArgument('itemids', $itemIds);
+		$url->setArgument('type', $this->graphType);
+
+		if ($this->action == HISTORY_BATCH_GRAPH) {
+			$url->setArgument('batch', 1);
+		}
+
+		return $url->getUrl().$this->getProfileUrlParams();
+	}
 }
