@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,13 +18,26 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 **/
 
+
+// reset the LC_CTYPE locale so that case transformation functions would work correctly
+// it is also required for PHP to work with the Turkish locale (https://bugs.php.net/bug.php?id=18556)
+// WARNING: this must be done before executing any other code, otherwise code execution could fail!
+// this will be unnecessary in PHP 5.5
+setlocale(LC_CTYPE, array(
+	'C', 'POSIX', 'en', 'en_US', 'en_US.UTF-8', 'English_United States.1252', 'en_GB', 'en_GB.UTF-8'
+));
+
 require_once dirname(__FILE__).'/classes/core/Z.php';
 
 try {
 	Z::getInstance()->run();
 }
 catch (DBException $e) {
-	$warningView = new CView('general.warning', array('message' => 'Database error: '.$e->getMessage()));
+	$warningView = new CView('general.warning', array(
+		'message' => array(
+			'header' => 'Database error', 'text' => $e->getMessage()
+		)
+	));
 	$warningView->render();
 	exit;
 }
@@ -35,7 +48,11 @@ catch (ConfigFileException $e) {
 			exit;
 
 		case CConfigFile::CONFIG_ERROR:
-			$warningView = new CView('general.warning', array('message' => 'Configuration file error: '.$e->getMessage()));
+			$warningView = new CView('general.warning', array(
+				'message' => array(
+					'header' => 'Configuration file error', 'text' => $e->getMessage()
+				)
+			));
 			$warningView->render();
 			exit;
 	}
@@ -48,6 +65,13 @@ catch (Exception $e) {
 
 CProfiler::getInstance()->start();
 
-global $ZBX_PAGE_POST_JS, $page;
-global $ZBX_SERVER, $ZBX_SERVER_PORT;
-$page = array();
+global $ZBX_PAGE_POST_JS, $ZBX_SERVER, $ZBX_SERVER_PORT, $page;
+
+$page = array(
+	'title' => null,
+	'file' => null,
+	'hist_arg' => null,
+	'scripts' => null,
+	'type' => null,
+	'menu' => null
+);
