@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,20 +18,26 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-define('ZABBIX_VERSION',     '2.2.1');
-define('ZABBIX_API_VERSION', '2.2.1');
-define('ZABBIX_DB_VERSION',	 2020000);
 
-define('ZABBIX_COPYRIGHT_FROM', '2001');
-define('ZABBIX_COPYRIGHT_TO',   '2013');
+define('ZABBIX_VERSION',		'2.4.3');
+define('ZABBIX_API_VERSION',	'2.4.3');
+define('ZABBIX_DB_VERSION',		2040000);
+
+define('ZABBIX_COPYRIGHT_FROM',	'2001');
+define('ZABBIX_COPYRIGHT_TO',	'2014');
 
 define('ZBX_LOGIN_ATTEMPTS',	5);
 define('ZBX_LOGIN_BLOCK',		30); // sec
 
 define('ZBX_MIN_PERIOD',		3600); // 1 hour
 define('ZBX_MAX_PERIOD',		63072000); // the maximum period for the time bar control, ~2 years (2 * 365 * 86400)
+define('ZBX_MAX_DATE',			2147483647); // 19 Jan 2038 05:14:07
 define('ZBX_PERIOD_DEFAULT',	3600); // 1 hour
 
+// the maximum period to display history data for the latest data and item overview pages in seconds
+// by default set to 86400 seconds (24 hours)
+define('ZBX_HISTORY_PERIOD', 86400);
+
 define('ZBX_WIDGET_ROWS', 20);
 
 define('ZBX_FONTPATH',				realpath('fonts')); // where to search for font (GD > 2.0.18)
@@ -62,17 +68,18 @@ define('ZBX_SCRIPT_TYPE_GLOBAL_SCRIPT',	4);
 define('ZBX_SCRIPT_EXECUTE_ON_AGENT',	0);
 define('ZBX_SCRIPT_EXECUTE_ON_SERVER',	1);
 
-define('ZBX_FLAG_DISCOVERY_NORMAL',		0x0); // a normal item
-define('ZBX_FLAG_DISCOVERY_RULE',		0x1); // a low level discovery rule
-define('ZBX_FLAG_DISCOVERY_PROTOTYPE',	0x2); // an item prototype
-define('ZBX_FLAG_DISCOVERY_CREATED',	0x4); // an item created via a discovery rule
+define('ZBX_FLAG_DISCOVERY_NORMAL',		0x0);
+define('ZBX_FLAG_DISCOVERY_RULE',		0x1);
+define('ZBX_FLAG_DISCOVERY_PROTOTYPE',	0x2);
+define('ZBX_FLAG_DISCOVERY_CREATED',	0x4);
 
 define('EXTACK_OPTION_ALL',		0);
 define('EXTACK_OPTION_UNACK',	1);
 define('EXTACK_OPTION_BOTH',	2);
 
-define('TRIGGERS_OPTION_ONLYTRUE',	1);
-define('TRIGGERS_OPTION_ALL',		2);
+define('TRIGGERS_OPTION_RECENT_PROBLEM',	1);
+define('TRIGGERS_OPTION_ALL',				2);
+define('TRIGGERS_OPTION_IN_PROBLEM',		3);
 
 define('ZBX_ACK_STS_ANY',				1);
 define('ZBX_ACK_STS_WITH_UNACK',		2);
@@ -94,6 +101,8 @@ define('ZBX_DB_ORACLE',		'ORACLE');
 define('ZBX_DB_POSTGRESQL',	'POSTGRESQL');
 define('ZBX_DB_SQLITE3',	'SQLITE3');
 
+define('ZBX_DB_MAX_ID', '9223372036854775807');
+
 define('PAGE_TYPE_HTML',				0);
 define('PAGE_TYPE_IMAGE',				1);
 define('PAGE_TYPE_XML',					2);
@@ -116,11 +125,12 @@ define('ZBX_DROPDOWN_FIRST_ALL',	1);
 define('T_ZBX_STR',			0);
 define('T_ZBX_INT',			1);
 define('T_ZBX_DBL',			2);
-define('T_ZBX_PERIOD',		3);
 define('T_ZBX_IP',			4);
 define('T_ZBX_CLR',			5);
 define('T_ZBX_IP_RANGE',	7);
 define('T_ZBX_INT_RANGE',	8);
+define('T_ZBX_DBL_BIG',		9);
+define('T_ZBX_DBL_STR',		10);
 
 define('O_MAND',	0);
 define('O_OPT',		1);
@@ -130,20 +140,18 @@ define('P_SYS',				1);
 define('P_UNSET_EMPTY',		2);
 define('P_ACT',				16);
 define('P_NZERO',			32);
+define('P_NO_TRIM',			64);
 
 //	misc parameters
 define('IMAGE_FORMAT_PNG',	'PNG');
 define('IMAGE_FORMAT_JPEG',	'JPEG');
 define('IMAGE_FORMAT_TEXT',	'JPEG');
 
-define('IMAGE_TYPE_UNKNOWN',		0);
 define('IMAGE_TYPE_ICON',			1);
 define('IMAGE_TYPE_BACKGROUND',		2);
 
 define('ITEM_CONVERT_WITH_UNITS',	0); // - do not convert empty units
 define('ITEM_CONVERT_NO_UNITS',		1); // - no units
-define('ITEM_CONVERT_SHORT_UNITS',	2); // - to short units
-define('ITEM_CONVERT_LONG_UNITS',	3); // - to long units
 
 define('ZBX_SORT_UP',	'ASC');
 define('ZBX_SORT_DOWN',	'DESC');
@@ -173,7 +181,6 @@ define('AUDIT_RESOURCE_VALUE_MAP',		17);
 define('AUDIT_RESOURCE_IT_SERVICE',		18);
 define('AUDIT_RESOURCE_MAP',			19);
 define('AUDIT_RESOURCE_SCREEN',			20);
-define('AUDIT_RESOURCE_NODE',			21);
 define('AUDIT_RESOURCE_SCENARIO',		22);
 define('AUDIT_RESOURCE_DISCOVERY_RULE',	23);
 define('AUDIT_RESOURCE_SLIDESHOW',		24);
@@ -202,7 +209,6 @@ define('CONDITION_TYPE_TEMPLATE',			13);
 define('CONDITION_TYPE_EVENT_ACKNOWLEDGED',	14);
 define('CONDITION_TYPE_APPLICATION',		15);
 define('CONDITION_TYPE_MAINTENANCE',		16);
-define('CONDITION_TYPE_NODE',				17);
 define('CONDITION_TYPE_DRULE',				18);
 define('CONDITION_TYPE_DCHECK',				19);
 define('CONDITION_TYPE_PROXY',				20);
@@ -219,6 +225,7 @@ define('CONDITION_OPERATOR_IN',			4);
 define('CONDITION_OPERATOR_MORE_EQUAL',	5);
 define('CONDITION_OPERATOR_LESS_EQUAL',	6);
 define('CONDITION_OPERATOR_NOT_IN',		7);
+define('CONDITION_OPERATOR_REGEXP',		8);
 
 // event type action condition values
 define('EVENT_TYPE_ITEM_NOTSUPPORTED',		0);
@@ -250,6 +257,9 @@ define('INTERFACE_TYPE_SNMP',		2);
 define('INTERFACE_TYPE_IPMI',		3);
 define('INTERFACE_TYPE_JMX',		4);
 
+define('SNMP_BULK_DISABLED',	0);
+define('SNMP_BULK_ENABLED',		1);
+
 define('MAINTENANCE_STATUS_ACTIVE',		0);
 define('MAINTENANCE_STATUS_APPROACH',	1);
 define('MAINTENANCE_STATUS_EXPIRED',	2);
@@ -306,12 +316,6 @@ define('SYSMAP_ELEMENT_ICON_DISABLED',		4);
 define('SYSMAP_HIGHLIGHT_OFF',	0);
 define('SYSMAP_HIGHLIGHT_ON',	1);
 
-define('SYSMAP_EXPANDPROBLEM_OFF',	0);
-define('SYSMAP_EXPANDPROBLEM_ON',	1);
-
-define('SYSMAP_MARKELEMENTS_OFF',	0);
-define('SYSMAP_MARKELEMENTS_ON',	1);
-
 define('SYSMAP_GRID_SHOW_ON',	1);
 define('SYSMAP_GRID_SHOW_OFF',	0);
 
@@ -425,7 +429,6 @@ define('TRIGGER_STATUS_DISABLED',	1);
 
 define('TRIGGER_VALUE_FALSE',	0);
 define('TRIGGER_VALUE_TRUE',	1);
-define('TRIGGER_VALUE_UNKNOWN', 2); // only in "events" table
 
 define('TRIGGER_STATE_NORMAL',	0);
 define('TRIGGER_STATE_UNKNOWN',	1);
@@ -492,21 +495,10 @@ define('OPERATION_TYPE_TEMPLATE_REMOVE',7);
 define('OPERATION_TYPE_HOST_ENABLE',	8);
 define('OPERATION_TYPE_HOST_DISABLE',	9);
 
-define('ACTION_EVAL_TYPE_AND_OR',	0);
-define('ACTION_EVAL_TYPE_AND',		1);
-define('ACTION_EVAL_TYPE_OR',		2);
-
-define('OPERATION_OBJECT_USER',		0);
-define('OPERATION_OBJECT_GROUP',	1);
-
-define('LOGFILE_SEVERITY_NOT_CLASSIFIED',	0);
-define('LOGFILE_SEVERITY_INFORMATION',		1);
-define('LOGFILE_SEVERITY_WARNING',			2);
-define('LOGFILE_SEVERITY_AVERAGE',			3);
-define('LOGFILE_SEVERITY_HIGH',				4);
-define('LOGFILE_SEVERITY_DISASTER',			5);
-define('LOGFILE_SEVERITY_AUDIT_SUCCESS',	6);
-define('LOGFILE_SEVERITY_AUDIT_FAILURE',	7);
+define('CONDITION_EVAL_TYPE_AND_OR',		0);
+define('CONDITION_EVAL_TYPE_AND',			1);
+define('CONDITION_EVAL_TYPE_OR',			2);
+define('CONDITION_EVAL_TYPE_EXPRESSION', 	3);
 
 // screen
 define('SCREEN_RESOURCE_GRAPH',				0);
@@ -529,6 +521,8 @@ define('SCREEN_RESOURCE_HOST_TRIGGERS',		16);
 // used in Monitoring > Latest data > Graph (history.php)
 define('SCREEN_RESOURCE_HISTORY',			17);
 define('SCREEN_RESOURCE_CHART',				18);
+define('SCREEN_RESOURCE_LLD_SIMPLE_GRAPH',	19);
+define('SCREEN_RESOURCE_LLD_GRAPH',			20);
 
 define('SCREEN_SORT_TRIGGERS_DATE_DESC',			0);
 define('SCREEN_SORT_TRIGGERS_SEVERITY_DESC',		1);
@@ -539,8 +533,6 @@ define('SCREEN_SORT_TRIGGERS_TYPE_ASC',				5);
 define('SCREEN_SORT_TRIGGERS_TYPE_DESC',			6);
 define('SCREEN_SORT_TRIGGERS_STATUS_ASC',			7);
 define('SCREEN_SORT_TRIGGERS_STATUS_DESC',			8);
-define('SCREEN_SORT_TRIGGERS_RETRIES_LEFT_ASC',		9);
-define('SCREEN_SORT_TRIGGERS_RETRIES_LEFT_DESC',	10);
 define('SCREEN_SORT_TRIGGERS_RECIPIENT_ASC',		11);
 define('SCREEN_SORT_TRIGGERS_RECIPIENT_DESC',		12);
 
@@ -549,18 +541,19 @@ define('SCREEN_MODE_EDIT',		1);
 define('SCREEN_MODE_SLIDESHOW',		2);
 define('SCREEN_MODE_JS',		3);
 
-define('SCREEN_TYPE_NORMAL',	0);
-define('SCREEN_TYPE_TEMPLATED',	1);
-
 define('SCREEN_SIMPLE_ITEM',	0);
 define('SCREEN_DYNAMIC_ITEM',	1);
 
 define('SCREEN_REFRESH_TIMEOUT',		30);
 define('SCREEN_REFRESH_RESPONSIVENESS',	10);
 
+define('SCREEN_SURROGATE_MAX_COLUMNS_MIN', 1);
+define('SCREEN_SURROGATE_MAX_COLUMNS_DEFAULT', 3);
+define('SCREEN_SURROGATE_MAX_COLUMNS_MAX', 100);
+
 define('DEFAULT_LATEST_ISSUES_CNT', 20);
 
-// alignes
+// alignments
 define('HALIGN_DEFAULT',	0);
 define('HALIGN_CENTER',		0);
 define('HALIGN_LEFT',		1);
@@ -572,7 +565,7 @@ define('VALIGN_TOP',		1);
 define('VALIGN_BOTTOM',		2);
 
 // info module style
-define('STYLE_HORISONTAL',	0);
+define('STYLE_HORIZONTAL',	0);
 define('STYLE_VERTICAL',	1);
 
 // view style [Overview]
@@ -593,13 +586,9 @@ define('MARK_COLOR_RED',	1);
 define('MARK_COLOR_GREEN',	2);
 define('MARK_COLOR_BLUE',	3);
 
-define('PROFILE_TYPE_UNKNOWN',		0);
 define('PROFILE_TYPE_ID',			1);
 define('PROFILE_TYPE_INT',			2);
 define('PROFILE_TYPE_STR',			3);
-define('PROFILE_TYPE_ARRAY_ID',		4);
-define('PROFILE_TYPE_ARRAY_INT',	5);
-define('PROFILE_TYPE_ARRAY_STR',	6);
 
 define('CALC_FNC_MIN', 1);
 define('CALC_FNC_AVG', 2);
@@ -629,9 +618,6 @@ define('GROUP_GUI_ACCESS_SYSTEM',	0);
 define('GROUP_GUI_ACCESS_INTERNAL', 1);
 define('GROUP_GUI_ACCESS_DISABLED', 2);
 
-define('GROUP_API_ACCESS_DISABLED', 0);
-define('GROUP_API_ACCESS_ENABLED',	1);
-
 /**
  * @see access_deny()
  */
@@ -645,22 +631,9 @@ define('PERM_READ_WRITE',	3);
 define('PERM_READ',			2);
 define('PERM_DENY',			0);
 
-define('PERM_RES_IDS_ARRAY',	1); // return array of nodes id - array(1,2,3,4)
-define('PERM_RES_DATA_ARRAY',	2);
-
-define('RESOURCE_TYPE_NODE',	0);
-define('RESOURCE_TYPE_GROUP',	1);
-
 define('PARAM_TYPE_TIME',		0);
 define('PARAM_TYPE_COUNTS',		1);
 
-define('ZBX_NODE_CHILD',	0);
-define('ZBX_NODE_LOCAL',	1);
-define('ZBX_NODE_MASTER',	2);
-
-define('ZBX_FLAG_TRIGGER',	0);
-define('ZBX_FLAG_EVENT',	1);
-
 define('HTTPTEST_AUTH_NONE',	0);
 define('HTTPTEST_AUTH_BASIC',	1);
 define('HTTPTEST_AUTH_NTLM',	2);
@@ -674,16 +647,24 @@ define('HTTPSTEP_ITEM_TYPE_IN',			2);
 define('HTTPSTEP_ITEM_TYPE_LASTSTEP',	3);
 define('HTTPSTEP_ITEM_TYPE_LASTERROR',	4);
 
+define('HTTPTEST_STEP_RETRIEVE_MODE_CONTENT', 0);
+define('HTTPTEST_STEP_RETRIEVE_MODE_HEADERS', 1);
+
+define('HTTPTEST_STEP_FOLLOW_REDIRECTS_OFF', 0);
+define('HTTPTEST_STEP_FOLLOW_REDIRECTS_ON', 1);
+
+define('HTTPTEST_VERIFY_PEER_OFF', 0);
+define('HTTPTEST_VERIFY_PEER_ON', 1);
+
+define('HTTPTEST_VERIFY_HOST_OFF', 0);
+define('HTTPTEST_VERIFY_HOST_ON', 1);
+
 define('EVENT_ACK_DISABLED',	'0');
 define('EVENT_ACK_ENABLED',		'1');
 
 define('EVENT_NOT_ACKNOWLEDGED',	'0');
 define('EVENT_ACKNOWLEDGED',		'1');
 
-define('EVENTS_NOFALSEFORB_STATUS_ALL',		0); // used with TRIGGERS_OPTION_NOFALSEFORB
-define('EVENTS_NOFALSEFORB_STATUS_FALSE',	1); // used with TRIGGERS_OPTION_NOFALSEFORB
-define('EVENTS_NOFALSEFORB_STATUS_TRUE',	2); // used with TRIGGERS_OPTION_NOFALSEFORB
-
 define('EVENT_SOURCE_TRIGGERS',				0);
 define('EVENT_SOURCE_DISCOVERY',			1);
 define('EVENT_SOURCE_AUTO_REGISTRATION',	2);
@@ -717,6 +698,10 @@ define('GRAPH_TYPE_COLUMN',			7);
 define('GRAPH_TYPE_BAR_STACKED',	8);
 define('GRAPH_TYPE_COLUMN_STACKED',	9);
 
+define('BR_DISTRIBUTION_MULTIPLE_PERIODS',	1);
+define('BR_DISTRIBUTION_MULTIPLE_ITEMS',	2);
+define('BR_COMPARE_VALUE_MULTIPLE_PERIODS',	3);
+
 define('GRAPH_3D_ANGLE', 70);
 
 define('GRAPH_STACKED_ALFA', 15); // 0..100 transparency
@@ -781,23 +766,20 @@ define('EXPRESSION_HOST_ITEM_UNKNOWN',	'#ERROR_ITEM#');
 define('EXPRESSION_NOT_A_MACRO_ERROR',	'#ERROR_MACRO#');
 define('EXPRESSION_FUNCTION_UNKNOWN',	'#ERROR_FUNCTION#');
 
-define('AVAILABLE_NOCACHE', 0);	// take available objects not from cache
-
-define('SBR',	"<br/>\n");
+/**
+ * @deprecated use either a literal space " " or a non-breakable space "&nbsp;" instead
+ */
 define('SPACE',	'&nbsp;');
-define('RARR',	'&rArr;');
-define('SQUAREBRACKETS', '%5B%5D');
+
+/**
+ * Symbol used to separate name pairs such as "host: item" or "proxy: host".
+ *
+ * Should not be used as just a colon.
+ */
 define('NAME_DELIMITER', ': ');
+
 define('UNKNOWN_VALUE', '-');
 
-// affects multibyte strings [in mb_ereg char "-" must be backslashed]!!!
-if (in_array(ini_get('mbstring.func_overload'), array(2,3,6,7))) {
-	define('ZBX_MBSTRINGS_OVERLOADED', 1);
-}
-
-define('REGEXP_INCLUDE', 0);
-define('REGEXP_EXCLUDE', 1);
-
 // suffixes
 define('ZBX_BYTE_SUFFIXES', 'KMGT');
 define('ZBX_TIME_SUFFIXES', 'smhdw');
@@ -808,16 +790,13 @@ define('ZBX_PREG_MACRO_NAME', '([A-Z0-9\._]+)');
 define('ZBX_PREG_MACRO_NAME_LLD', '([A-Z0-9\._]+)');
 define('ZBX_PREG_INTERNAL_NAMES', '([0-9a-zA-Z_\. \-]+)'); // !!! Don't forget sync code with C !!!
 define('ZBX_PREG_PARAMS', '(['.ZBX_PREG_PRINT.']+?)?');
-define('ZBX_PREG_SIGN', '([&|><=+*\/#\-])');
 define('ZBX_PREG_NUMBER', '([\-+]?[0-9]+[.]?[0-9]*['.ZBX_BYTE_SUFFIXES.ZBX_TIME_SUFFIXES.']?)');
 define('ZBX_PREG_DEF_FONT_STRING', '/^[0-9\.:% ]+$/');
 define('ZBX_PREG_DNS_FORMAT', '([0-9a-zA-Z_\.\-$]|\{\$?'.ZBX_PREG_MACRO_NAME.'\})*');
 define('ZBX_PREG_HOST_FORMAT', ZBX_PREG_INTERNAL_NAMES);
-define('ZBX_PREG_NODE_FORMAT', ZBX_PREG_INTERNAL_NAMES);
-define('ZBX_PREG_FUNCTION_FORMAT', '([a-z]+(\('.ZBX_PREG_PARAMS.'\)))');
 define('ZBX_PREG_MACRO_NAME_FORMAT', '(\{[A-Z\.]+\})');
-define('ZBX_PREG_EXPRESSION_SIMPLE_MACROS', '(\{TRIGGER\.VALUE\})');
 define('ZBX_PREG_EXPRESSION_USER_MACROS', '(\{\$'.ZBX_PREG_MACRO_NAME.'\})');
+define('ZBX_PREG_EXPRESSION_LLD_MACROS', '(\{\#'.ZBX_PREG_MACRO_NAME_LLD.'\})');
 
 // !!! should be used with "x" modifier
 define('ZBX_PREG_ITEM_KEY_PARAMETER_FORMAT', '(
@@ -836,7 +815,7 @@ define('ZBX_PREG_ITEM_KEY_PARAMETER_FORMAT', '(
 	() # match empty and only empty part
 )');
 define('ZBX_PREG_ITEM_KEY_FORMAT', '([0-9a-zA-Z_\. \-]+? # match key
-(?<param>( # name parameter group used in recursion
+(?P<param>( # name parameter group used in recursion
 	\[ # match opening bracket
 		(
 			\s*?'.ZBX_PREG_ITEM_KEY_PARAMETER_FORMAT .' # match spaces and parameter
@@ -850,18 +829,9 @@ define('ZBX_PREG_ITEM_KEY_FORMAT', '([0-9a-zA-Z_\. \-]+? # match key
 ))*? # matches non comma seperated brackets with parameters zero or more times
 )');
 
-// regexp ids
-define('ZBX_KEY_ID',		1);
-define('ZBX_KEY_NAME_ID',	2);
-define('ZBX_KEY_PARAM_ID',	6);
-
-define('ZBX_HISTORY_COUNT', 5);
-
 define('ZBX_USER_ONLINE_TIME', 600); // 10min
 define('ZBX_GUEST_USER','guest');
 
-define('ZBX_FAVORITES_ALL', -1);
-
 // IPMI
 define('IPMI_AUTHTYPE_DEFAULT',		-1);
 define('IPMI_AUTHTYPE_NONE',		0);
@@ -897,6 +867,14 @@ define('XML_TAG_DEPENDENCY',		'dependency');
 
 define('ZBX_DEFAULT_IMPORT_HOST_GROUP', 'Imported hosts');
 
+// XML import flags
+// See ZBX-8151. Old version of libxml suffered from setting DTDLOAD and NOENT flags by default, which allowed
+// performing XXE attacks. Calling libxml_disable_entity_loader(true) also had no affect if flags passed to libxml
+// calls were 0 - so for better security with legacy libxml we need to call libxml_disable_entity_loader(true) AND
+// pass the LIBXML_NONET flag. Please keep in mind that LIBXML_NOENT actually EXPANDS entities, opposite to it's name -
+// so this flag is not needed here.
+define('LIBXML_IMPORT_FLAGS', LIBXML_NONET);
+
 // API errors
 define('ZBX_API_ERROR_INTERNAL',	111);
 define('ZBX_API_ERROR_PARAMETERS',	100);
@@ -904,7 +882,6 @@ define('ZBX_API_ERROR_PERMISSIONS',	120);
 define('ZBX_API_ERROR_NO_AUTH',		200);
 define('ZBX_API_ERROR_NO_METHOD',	300);
 
-define('API_OUTPUT_REFER',		'refer');
 define('API_OUTPUT_EXTEND',		'extend');
 define('API_OUTPUT_COUNT',		'count');
 
@@ -915,6 +892,8 @@ define('SEC_PER_WEEK',	604800); // 7 * SEC_PER_DAY
 define('SEC_PER_MONTH',	2592000); // 30 * SEC_PER_DAY
 define('SEC_PER_YEAR',	31536000); // 365 * SEC_PER_DAY
 
+define('ZBX_JAN_2038', 2145916800);
+
 define('DAY_IN_YEAR', 365);
 
 define('ZBX_MIN_PORT_NUMBER', 0);
@@ -928,11 +907,22 @@ define('ZBX_TEXTAREA_STANDARD_WIDTH',	312);
 define('ZBX_TEXTAREA_BIG_WIDTH',		524);
 define('ZBX_TEXTAREA_STANDARD_ROWS',	7);
 
+// widgets
+define('WIDGET_DISCOVERY_STATUS',	'dscvry');
+define('WIDGET_FAVOURITE_GRAPHS',	'favgrph');
+define('WIDGET_FAVOURITE_MAPS',		'favmap');
+define('WIDGET_FAVOURITE_SCREENS',	'favscr');
+define('WIDGET_HOST_STATUS',		'hoststat');
+define('WIDGET_LAST_ISSUES',		'lastiss');
+define('WIDGET_SLIDESHOW',			'hat_slides');
+define('WIDGET_SYSTEM_STATUS',		'syssum');
+define('WIDGET_WEB_OVERVIEW',		'webovr');
+define('WIDGET_ZABBIX_STATUS',		'stszbx');
+
 // validation
 define('DB_ID',		"({}>=0&&bccomp('{}',\"10000000000000000000\")<0)&&");
 define('NOT_EMPTY',	"({}!='')&&");
 define('NOT_ZERO',	"({}!=0)&&");
-define('NO_TRIM',	'NO_TRIM');
 
 define('ZBX_VALID_OK',		0);
 define('ZBX_VALID_ERROR',	1);
@@ -950,6 +940,9 @@ define('ZABBIX_HOMEPAGE', 'http://www.zabbix.com');
 define('TIMESTAMP_FORMAT', 'YmdHis');
 define('TIMESTAMP_FORMAT_ZERO_TIME', 'Ymd0000');
 
+// date format context, usable for translators
+define('DATE_FORMAT_CONTEXT', 'Date format (see http://php.net/date)');
+
 // actions
 define('LONG_DESCRIPTION',	0);
 define('SHORT_DESCRIPTION',	1);
@@ -966,6 +959,16 @@ define('QUEUE_DETAILS', 2);
 // item count to display in the details queue
 define('QUEUE_DETAIL_ITEM_COUNT', 500);
 
+// constants for element "copy to..." target types
+define('COPY_TYPE_TO_HOST', 0);
+define('COPY_TYPE_TO_TEMPLATE', 2);
+define('COPY_TYPE_TO_HOST_GROUP', 1);
+
+define('HISTORY_GRAPH', 'showgraph');
+define('HISTORY_BATCH_GRAPH', 'batchgraph');
+define('HISTORY_VALUES', 'showvalues');
+define('HISTORY_LATEST', 'showlatest');
+
 // configuration -> maps default add icon name
 define('MAP_DEFAULT_ICON', 'Server_(96)');
 
