@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2000-2012 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -10,7 +10,7 @@
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
@@ -19,24 +19,81 @@
 **/
 
 
-function event_source2str($sourceid) {
-	switch ($sourceid) {
-		case EVENT_SOURCE_TRIGGERS:
-			return _('Triggers');
-		case EVENT_SOURCE_DISCOVERY:
-			return _('Discovery');
-		default:
-			return _('Unknown');
+/**
+ * Returns the names of supported event sources.
+ *
+ * If the $source parameter is passed, returns the name of the specific source, otherwise - returns an array of all
+ * supported sources.
+ *
+ * @param int $source
+ *
+ * @return array|string
+ */
+function eventSource($source = null) {
+	$sources = array(
+		EVENT_SOURCE_TRIGGERS => _('trigger'),
+		EVENT_SOURCE_DISCOVERY => _('discovery'),
+		EVENT_SOURCE_AUTO_REGISTRATION => _('auto registration'),
+		EVENT_SOURCE_INTERNAL => _x('internal', 'event source')
+	);
+
+	if ($source === null) {
+		return $sources;
+	}
+	elseif (isset($sources[$source])) {
+		return $sources[$source];
+	}
+	else {
+		return _('Unknown');
 	}
 }
 
-function get_tr_event_by_eventid($eventid) {
-	$sql = 'SELECT e.*,t.triggerid,t.description,t.expression,t.priority,t.status,t.type'.
-			' FROM events e,triggers t'.
-			' WHERE e.eventid='.$eventid.
-				' AND e.object='.EVENT_OBJECT_TRIGGER.
-				' AND t.triggerid=e.objectid';
-	return DBfetch(DBselect($sql));
+/**
+ * Returns the names of supported event objects.
+ *
+ * If the $source parameter is passed, returns the name of the specific object, otherwise - returns an array of all
+ * supported objects.
+ *
+ * @param int $object
+ *
+ * @return array|string
+ */
+function eventObject($object = null) {
+	$objects = array(
+		EVENT_OBJECT_TRIGGER => _('trigger'),
+		EVENT_OBJECT_DHOST => _('discovered host'),
+		EVENT_OBJECT_DSERVICE => _('discovered service'),
+		EVENT_OBJECT_AUTOREGHOST => _('auto-registered host'),
+		EVENT_OBJECT_ITEM => _('item'),
+		EVENT_OBJECT_LLDRULE => _('low-level discovery rule')
+	);
+
+	if ($object === null) {
+		return $objects;
+	}
+	elseif (isset($objects[$object])) {
+		return $objects[$object];
+	}
+	else {
+		return _('Unknown');
+	}
+}
+
+/**
+ * Returns all supported event source-object pairs.
+ *
+ * @return array
+ */
+function eventSourceObjects() {
+	return array(
+		array('source' => EVENT_SOURCE_TRIGGERS, 'object' => EVENT_OBJECT_TRIGGER),
+		array('source' => EVENT_SOURCE_DISCOVERY, 'object' => EVENT_OBJECT_DHOST),
+		array('source' => EVENT_SOURCE_DISCOVERY, 'object' => EVENT_OBJECT_DSERVICE),
+		array('source' => EVENT_SOURCE_AUTO_REGISTRATION, 'object' => EVENT_OBJECT_AUTOREGHOST),
+		array('source' => EVENT_SOURCE_INTERNAL, 'object' => EVENT_OBJECT_TRIGGER),
+		array('source' => EVENT_SOURCE_INTERNAL, 'object' => EVENT_OBJECT_ITEM),
+		array('source' => EVENT_SOURCE_INTERNAL, 'object' => EVENT_OBJECT_LLDRULE)
+	);
 }
 
 function get_events_unacknowledged($db_element, $value_trigger = null, $value_event = null, $ack = false) {
@@ -49,8 +106,7 @@ function get_events_unacknowledged($db_element, $value_trigger = null, $value_ev
 
 	$config = select_config();
 	$options = array(
-		'nodeids' => get_current_nodeid(),
-		'output' => API_OUTPUT_SHORTEN,
+		'output' => array('triggerid'),
 		'monitored' => 1,
 		'skipDependent' => 1,
 		'limit' => $config['search_limit'] + 1
@@ -70,19 +126,18 @@ function get_events_unacknowledged($db_element, $value_trigger = null, $value_ev
 	$triggerids = API::Trigger()->get($options);
 
 	return API::Event()->get(array(
-		'countOutput' => 1,
-		'triggerids' => zbx_objectValues($triggerids, 'triggerid'),
-		'filter' => array(
-			'value_changed' => TRIGGER_VALUE_CHANGED_YES,
-			'value' => is_null($value_event) ? array(TRIGGER_VALUE_TRUE, TRIGGER_VALUE_FALSE) : $value_event,
-			'acknowledged' => $ack ? 1 : 0
-		),
+		'source' => EVENT_SOURCE_TRIGGERS,
 		'object' => EVENT_OBJECT_TRIGGER,
-		'nopermissions' => true
+		'countOutput' => true,
+		'objectids' => zbx_objectValues($triggerids, 'triggerid'),
+		'filter' => array(
+			'value' => $value_event,
+			'acknowledged' => $ack ? 1 : 0
+		)
 	));
 }
 
-function get_next_event($currentEvent, array $eventList = array(), $showUnknown = false) {
+function get_next_event($currentEvent, array $eventList = array()) {
 	$nextEvent = false;
 
 	foreach ($eventList as $event) {
@@ -100,11 +155,13 @@ function get_next_event($currentEvent, array $eventList = array(), $showUnknown
 
 	$sql = 'SELECT e.*'.
 			' FROM events e'.
-			' WHERE e.objectid='.$currentEvent['objectid'].
-				' AND e.eventid>'.$currentEvent['eventid'].
-				' AND e.object='.$currentEvent['object'].
-				($showUnknown ? '' : ' AND e.value_changed='.TRIGGER_VALUE_CHANGED_YES).
-			' ORDER BY e.object,e.objectid,e.eventid';
+			' WHERE e.source='.zbx_dbstr($currentEvent['source']).
+				' AND e.object='.zbx_dbstr($currentEvent['object']).
+				' AND e.objectid='.zbx_dbstr($currentEvent['objectid']).
+				' AND e.clock>='.zbx_dbstr($currentEvent['clock']).
+				' AND ((e.clock='.zbx_dbstr($currentEvent['clock']).' AND e.ns>'.$currentEvent['ns'].')'.
+					' OR e.clock>'.zbx_dbstr($currentEvent['clock']).')'.
+			' ORDER BY e.clock,e.eventid';
 	return DBfetch(DBselect($sql, 1));
 }
 
@@ -112,8 +169,11 @@ function make_event_details($event, $trigger) {
 	$config = select_config();
 	$table = new CTableInfo();
 
-	$table->addRow(array(_('Event'), CEventHelper::expandDescription(array_merge($trigger, $event))));
-	$table->addRow(array(_('Time'), zbx_date2str(_('d M Y H:i:s'), $event['clock'])));
+	$table->addRow(array(
+		new CCol(_('Event')),
+		new CCol(CMacrosResolverHelper::resolveEventDescription(array_merge($trigger, $event)), 'wraptext')
+	));
+	$table->addRow(array(_('Time'), zbx_date2str(DATE_TIME_FORMAT_SECONDS, $event['clock'])));
 
 	if ($config['event_ack_enable']) {
 		// to make resulting link not have hint with acknowledges
@@ -128,7 +188,7 @@ function make_event_details($event, $trigger) {
 function make_small_eventlist($startEvent) {
 	$config = select_config();
 
-	$table = new CTableInfo();
+	$table = new CTableInfo(_('No events found.'));
 	$table->setHeader(array(
 		_('Time'),
 		_('Status'),
@@ -140,28 +200,32 @@ function make_small_eventlist($startEvent) {
 
 	$clock = $startEvent['clock'];
 
-	$options = array(
-		'triggerids' => $startEvent['objectid'],
+	$events = API::Event()->get(array(
+		'source' => EVENT_SOURCE_TRIGGERS,
+		'object' => EVENT_OBJECT_TRIGGER,
+		'objectids' => $startEvent['objectid'],
 		'eventid_till' => $startEvent['eventid'],
 		'output' => API_OUTPUT_EXTEND,
 		'select_acknowledges' => API_OUTPUT_COUNT,
-		'sortfield' => 'eventid',
+		'sortfield' => array('clock', 'eventid'),
 		'sortorder' => ZBX_SORT_DOWN,
 		'limit' => 20
-	);
-	$events = API::Event()->get($options);
+	));
+
 	$sortFields = array(
 		array('field' => 'clock', 'order' => ZBX_SORT_DOWN),
 		array('field' => 'eventid', 'order' => ZBX_SORT_DOWN)
 	);
 	CArrayHelper::sort($events, $sortFields);
 
+	$actions = getEventActionsStatHints(zbx_objectValues($events, 'eventid'));
+
 	foreach ($events as $event) {
 		$lclock = $clock;
 		$duration = zbx_date2age($lclock, $event['clock']);
 		$clock = $event['clock'];
 
-		if (bccomp($startEvent['eventid'],$event['eventid']) == 0 && $nextevent = get_next_event($event, $events, true)) {
+		if (bccomp($startEvent['eventid'],$event['eventid']) == 0 && $nextevent = get_next_event($event, $events)) {
 			$duration = zbx_date2age($nextevent['clock'], $clock);
 		}
 		elseif (bccomp($startEvent['eventid'], $event['eventid']) == 0) {
@@ -169,6 +233,7 @@ function make_small_eventlist($startEvent) {
 		}
 
 		$eventStatusSpan = new CSpan(trigger_value2str($event['value']));
+
 		// add colors and blinking to span depending on configuration and trigger parameters
 		addTriggerValueStyle(
 			$eventStatusSpan,
@@ -179,11 +244,9 @@ function make_small_eventlist($startEvent) {
 
 		$ack = getEventAckState($event, true);
 
-		$actions = get_event_actions_stat_hints($event['eventid']);
-
 		$table->addRow(array(
 			new CLink(
-				zbx_date2str(_('d M Y H:i:s'), $event['clock']),
+				zbx_date2str(DATE_TIME_FORMAT_SECONDS, $event['clock']),
 				'tr_events.php?triggerid='.$event['objectid'].'&eventid='.$event['eventid'],
 				'action'
 			),
@@ -191,17 +254,18 @@ function make_small_eventlist($startEvent) {
 			$duration,
 			zbx_date2age($event['clock']),
 			$config['event_ack_enable'] ? $ack : null,
-			$actions
+			isset($actions[$event['eventid']]) ? $actions[$event['eventid']] : SPACE
 		));
 	}
 
 	return $table;
 }
 
-function make_popup_eventlist($eventid, $trigger_type, $triggerid) {
+function make_popup_eventlist($triggerId, $eventId) {
 	$config = select_config();
 
 	$table = new CTableInfo();
+	$table->setAttribute('style', 'width: 400px;');
 
 	// if acknowledges are turned on, we show 'ack' column
 	if ($config['event_ack_enable']) {
@@ -211,26 +275,21 @@ function make_popup_eventlist($eventid, $trigger_type, $triggerid) {
 		$table->setHeader(array(_('Time'), _('Status'), _('Duration'), _('Age')));
 	}
 
-	$table->setAttribute('style', 'width: 400px;');
-
-	$options = array(
+	$events = API::Event()->get(array(
+		'source' => EVENT_SOURCE_TRIGGERS,
+		'object' => EVENT_OBJECT_TRIGGER,
 		'output' => API_OUTPUT_EXTEND,
-		'triggerids' => $triggerid,
-		'eventid_till' => $eventid,
-		'filter' => array(
-			'object' => EVENT_OBJECT_TRIGGER,
-			'value_changed' => TRIGGER_VALUE_CHANGED_YES
-		),
-		'nopermissions' => 1,
+		'objectids' => $triggerId,
+		'eventid_till' => $eventId,
 		'select_acknowledges' => API_OUTPUT_COUNT,
-		'sortfield' => 'eventid',
+		'sortfield' => array('clock', 'eventid'),
 		'sortorder' => ZBX_SORT_DOWN,
 		'limit' => ZBX_WIDGET_ROWS
-	);
-	$db_events = API::Event()->get($options);
+	));
 
 	$lclock = time();
-	foreach ($db_events as $event) {
+
+	foreach ($events as $event) {
 		$duration = zbx_date2age($lclock, $event['clock']);
 		$lclock = $event['clock'];
 
@@ -239,14 +298,12 @@ function make_popup_eventlist($eventid, $trigger_type, $triggerid) {
 		// add colors and blinking to span depending on configuration and trigger parameters
 		addTriggerValueStyle($eventStatusSpan, $event['value'], $event['clock'], $event['acknowledged']);
 
-		$ack = getEventAckState($event, false, false);
-
 		$table->addRow(array(
-			zbx_date2str(_('d M Y H:i:s'), $event['clock']),
+			zbx_date2str(DATE_TIME_FORMAT_SECONDS, $event['clock']),
 			$eventStatusSpan,
 			$duration,
 			zbx_date2age($event['clock']),
-			$ack
+			getEventAckState($event, false, false)
 		));
 	}
 
@@ -257,10 +314,14 @@ function make_popup_eventlist($eventid, $trigger_type, $triggerid) {
  * Create element with event acknowledges info.
  * If $event has subarray 'acknowledges', returned link will have hint with acknowledges.
  *
- * @param array       $event   event data
- * @param bool|string $backUrl if true, add backurl param to link with current page file name
- * @param bool        $isLink  if true, return link otherwise span
- * @param array       $params  additional params for link
+ * @param array			$event   event data
+ * @param int			$event['acknowledged']
+ * @param int			$event['eventid']
+ * @param int			$event['objectid']
+ * @param array			$event['acknowledges']
+ * @param bool|string	$backUrl if true, add backurl param to link with current page file name
+ * @param bool			$isLink  if true, return link otherwise span
+ * @param array			$params  additional params for link
  *
  * @return array|CLink|CSpan|null|string
  */
@@ -271,10 +332,6 @@ function getEventAckState($event, $backUrl = false, $isLink = true, $params = ar
 		return null;
 	}
 
-	if ($event['value_changed'] == TRIGGER_VALUE_CHANGED_NO) {
-		return SPACE;
-	}
-
 	if ($isLink) {
 		if (!empty($backUrl)) {
 			if (is_bool($backUrl)) {
@@ -300,9 +357,9 @@ function getEventAckState($event, $backUrl = false, $isLink = true, $params = ar
 		else {
 			$ackLink = new CLink(_('Yes'), 'acknow.php?eventid='.$event['eventid'].'&triggerid='.$event['objectid'].$backurl.$additionalParams, 'enabled');
 			if (is_array($event['acknowledges'])) {
-				$ackLinkHints = make_acktab_by_eventid($event);
+				$ackLinkHints = makeAckTab($event);
 				if (!empty($ackLinkHints)) {
-					$ackLink->setHint($ackLinkHints, '', '', false);
+					$ackLink->setHint($ackLinkHints, '', false);
 				}
 				$ack = array($ackLink, ' ('.count($event['acknowledges']).')');
 			}
@@ -331,27 +388,25 @@ function getLastEvents($options) {
 	$triggerOptions = array(
 		'filter' => array(),
 		'skipDependent' => 1,
-		'selectHosts' => array('hostid', 'host'),
+		'selectHosts' => array('hostid', 'name'),
 		'output' => API_OUTPUT_EXTEND,
 		'sortfield' => 'lastchange',
 		'sortorder' => ZBX_SORT_DOWN,
-		'limit' => $options['limit']
+		'limit' => $options['triggerLimit']
 	);
 
 	$eventOptions = array(
+		'source' => EVENT_SOURCE_TRIGGERS,
+		'object' => EVENT_OBJECT_TRIGGER,
 		'output' => API_OUTPUT_EXTEND,
-		'filter' => array(
-			'object' => EVENT_OBJECT_TRIGGER,
-			'value_changed' => TRIGGER_VALUE_CHANGED_YES
-		),
-		'sortfield' => 'eventid',
-		'sortorder' => ZBX_SORT_DOWN,
-		'limit' => $options['limit']
+		'sortfield' => array('clock', 'eventid'),
+		'sortorder' => ZBX_SORT_DOWN
 	);
 
-	if (isset($options['nodeids'])) {
-		$triggerOptions['nodeids'] = $options['nodeids'];
+	if (isset($options['eventLimit'])) {
+		$eventOptions['limit'] = $options['eventLimit'];
 	}
+
 	if (isset($options['priority'])) {
 		$triggerOptions['filter']['priority'] = $options['priority'];
 	}
@@ -372,7 +427,7 @@ function getLastEvents($options) {
 	$triggers = zbx_toHash($triggers, 'triggerid');
 
 	// events
-	$eventOptions['triggerids'] = zbx_objectValues($triggers, 'triggerid');
+	$eventOptions['objectids'] = zbx_objectValues($triggers, 'triggerid');
 	$events = API::Event()->get($eventOptions);
 
 	$sortClock = array();
@@ -389,7 +444,7 @@ function getLastEvents($options) {
 
 		//expanding description for the state where event was
 		$merged_event = array_merge($event, $triggers[$event['objectid']]);
-		$events[$enum]['trigger']['description'] = CEventHelper::expandDescription($merged_event);
+		$events[$enum]['trigger']['description'] = CMacrosResolverHelper::resolveEventDescription($merged_event);
 	}
 	array_multisort($sortClock, SORT_DESC, $sortEvent, SORT_DESC, $events);
 
