@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,16 +38,6 @@ function graphType($type = null) {
 	}
 }
 
-function graph_item_type2str($type) {
-	switch ($type) {
-		case GRAPH_ITEM_SUM:
-			return _('Graph sum');
-		case GRAPH_ITEM_SIMPLE:
-		default:
-			return _('Simple');
-	}
-}
-
 function graph_item_drawtypes() {
 	return array(
 		GRAPH_ITEM_DRAWTYPE_LINE,
@@ -120,7 +110,7 @@ function getGraphDims($graphid = null) {
 	$dbGraphs = DBselect(
 		'SELECT MAX(g.graphtype) AS graphtype,MIN(gi.yaxisside) AS yaxissidel,MAX(gi.yaxisside) AS yaxissider,MAX(g.height) AS height'.
 		' FROM graphs g,graphs_items gi'.
-		' WHERE g.graphid='.$graphid.
+		' WHERE g.graphid='.zbx_dbstr($graphid).
 			' AND gi.graphid=g.graphid'
 	);
 	if ($graph = DBfetch($dbGraphs)) {
@@ -148,18 +138,8 @@ function getGraphDims($graphid = null) {
 	return $graphDims;
 }
 
-function get_graphs_by_hostid($hostid) {
-	return DBselect(
-		'SELECT DISTINCT g.*'.
-		' FROM graphs g,graphs_items gi,items i'.
-		' WHERE g.graphid=gi.graphid'.
-			' AND gi.itemid=i.itemid'.
-			' AND i.hostid='.$hostid
-	);
-}
-
 function get_realhosts_by_graphid($graphid) {
-	$graph = get_graph_by_graphid($graphid);
+	$graph = getGraphByGraphId($graphid);
 	if (!empty($graph['templateid'])) {
 		return get_realhosts_by_graphid($graph['templateid']);
 	}
@@ -172,7 +152,7 @@ function get_hosts_by_graphid($graphid) {
 		' FROM graphs_items gi,items i,hosts h'.
 		' WHERE h.hostid=i.hostid'.
 			' AND gi.itemid=i.itemid'.
-			' AND gi.graphid='.$graphid
+			' AND gi.graphid='.zbx_dbstr($graphid)
 	);
 }
 
@@ -187,7 +167,7 @@ function get_min_itemclock_by_graphid($graphid) {
 	$dbItems = DBselect(
 		'SELECT DISTINCT gi.itemid'.
 		' FROM graphs_items gi'.
-		' WHERE gi.graphid='.$graphid
+		' WHERE gi.graphid='.zbx_dbstr($graphid)
 	);
 	while ($item = DBfetch($dbItems)) {
 		$itemids[$item['itemid']] = $item['itemid'];
@@ -199,18 +179,19 @@ function get_min_itemclock_by_graphid($graphid) {
 /**
  * Return the time of the 1st appearance of item in trends.
  *
- * @param array|int $itemids
+ * @param array $itemIds
  *
  * @return int (unixtime)
  */
-function get_min_itemclock_by_itemid($itemids) {
-	zbx_value2array($itemids);
+function get_min_itemclock_by_itemid($itemIds) {
+	zbx_value2array($itemIds);
+
 	$min = null;
 	$result = time() - SEC_PER_YEAR;
 
-	$items_by_type = array(
+	$itemTypes = array(
 		ITEM_VALUE_TYPE_FLOAT => array(),
-		ITEM_VALUE_TYPE_STR =>  array(),
+		ITEM_VALUE_TYPE_STR => array(),
 		ITEM_VALUE_TYPE_LOG => array(),
 		ITEM_VALUE_TYPE_UINT64 => array(),
 		ITEM_VALUE_TYPE_TEXT => array()
@@ -219,96 +200,116 @@ function get_min_itemclock_by_itemid($itemids) {
 	$dbItems = DBselect(
 		'SELECT i.itemid,i.value_type'.
 		' FROM items i'.
-		' WHERE '.dbConditionInt('i.itemid', $itemids)
+		' WHERE '.dbConditionInt('i.itemid', $itemIds)
 	);
 
 	while ($item = DBfetch($dbItems)) {
-		$items_by_type[$item['value_type']][$item['itemid']] = $item['itemid'];
+		$itemTypes[$item['value_type']][$item['itemid']] = $item['itemid'];
 	}
 
 	// data for ITEM_VALUE_TYPE_FLOAT and ITEM_VALUE_TYPE_UINT64 can be stored in trends tables or history table
 	// get max trends and history values for such type items to find out in what tables to look for data
-	$sql_from = 'history';
-	$sql_from_num = '';
+	$sqlFrom = 'history';
+	$sqlFromNum = '';
 
-	if (!empty($items_by_type[ITEM_VALUE_TYPE_FLOAT]) || !empty($items_by_type[ITEM_VALUE_TYPE_UINT64])) {
-		$itemids_numeric = zbx_array_merge($items_by_type[ITEM_VALUE_TYPE_FLOAT], $items_by_type[ITEM_VALUE_TYPE_UINT64]);
+	if (!empty($itemTypes[ITEM_VALUE_TYPE_FLOAT]) || !empty($itemTypes[ITEM_VALUE_TYPE_UINT64])) {
+		$itemIdsNumeric = zbx_array_merge($itemTypes[ITEM_VALUE_TYPE_FLOAT], $itemTypes[ITEM_VALUE_TYPE_UINT64]);
 
 		$sql = 'SELECT MAX(i.history) AS history,MAX(i.trends) AS trends'.
 				' FROM items i'.
-				' WHERE '.dbConditionInt('i.itemid', $itemids_numeric);
-		if ($table_for_numeric = DBfetch(DBselect($sql))) {
-			$sql_from_num = ($table_for_numeric['history'] > $table_for_numeric['trends']) ? 'history' : 'trends';
-			$result = time() - (SEC_PER_DAY * max($table_for_numeric['history'], $table_for_numeric['trends']));
+				' WHERE '.dbConditionInt('i.itemid', $itemIdsNumeric);
+		if ($tableForNumeric = DBfetch(DBselect($sql))) {
+			// look for data in one of the tables
+			$sqlFromNum = ($tableForNumeric['history'] > $tableForNumeric['trends']) ? 'history' : 'trends';
+
+			$result = time() - (SEC_PER_DAY * max($tableForNumeric['history'], $tableForNumeric['trends']));
+
+			/*
+			 * In case history storage exceeds the maximum time difference between current year and minimum 1970
+			 * (for example year 2014 - 200 years < year 1970), correct year to 1970 (unix time timestamp 0).
+			 */
+			if ($result < 0) {
+				$result = 0;
+			}
 		}
 	}
 
-	foreach ($items_by_type as $type => $items) {
+	foreach ($itemTypes as $type => $items) {
 		if (empty($items)) {
 			continue;
 		}
 
-		switch($type) {
+		switch ($type) {
 			case ITEM_VALUE_TYPE_FLOAT:
-				$sql_from = $sql_from_num;
+				$sqlFrom = $sqlFromNum;
 				break;
 			case ITEM_VALUE_TYPE_STR:
-				$sql_from = 'history_str';
+				$sqlFrom = 'history_str';
 				break;
 			case ITEM_VALUE_TYPE_LOG:
-				$sql_from = 'history_log';
+				$sqlFrom = 'history_log';
 				break;
 			case ITEM_VALUE_TYPE_UINT64:
-				$sql_from = $sql_from_num.'_uint';
+				$sqlFrom = $sqlFromNum.'_uint';
 				break;
 			case ITEM_VALUE_TYPE_TEXT:
-				$sql_from = 'history_text';
+				$sqlFrom = 'history_text';
 				break;
 			default:
-				$sql_from = 'history';
+				$sqlFrom = 'history';
+		}
+
+		foreach ($itemIds as $itemId) {
+			$sqlUnions[] = 'SELECT MIN(ht.clock) AS c FROM '.$sqlFrom.' ht WHERE ht.itemid='.zbx_dbstr($itemId);
 		}
 
 		$dbMin = DBfetch(DBselect(
-			'SELECT MIN(ht.clock) AS min_clock'.
-			' FROM '.$sql_from.' ht'.
-			' WHERE '.dbConditionInt('ht.itemid', $itemids)
+			'SELECT MIN(ht.c) AS min_clock'.
+			' FROM ('.implode(' UNION ALL ', $sqlUnions).') ht'
 		));
-		$min = empty($min) ? $dbMin['min_clock'] : min($min, $dbMin['min_clock']);
+
+		$min = $min ? min($min, $dbMin['min_clock']) : $dbMin['min_clock'];
 	}
 
-	return empty($min) ? $result : $min;
+	// in case DB clock column is corrupted having negative numbers, return min clock from max possible history storage
+	return ($min > 0) ? $min : $result;
 }
 
-function get_graph_by_graphid($graphid) {
-	$dbGraphs = DBselect('SELECT g.* FROM graphs g WHERE g.graphid='.$graphid);
-	$dbGraphs = DBfetch($dbGraphs);
-	if (!empty($dbGraphs)) {
-		return $dbGraphs;
+function getGraphByGraphId($graphId) {
+	$dbGraph = DBfetch(DBselect('SELECT g.* FROM graphs g WHERE g.graphid='.zbx_dbstr($graphId)));
+
+	if ($dbGraph) {
+		return $dbGraph;
 	}
 
-	error(_s('No graph item with graphid "%s".', $graphid));
+	error(_s('No graph item with graphid "%s".', $graphId));
 
 	return false;
 }
 
 /**
- * Replace items for specified host.
+ * Search items by same key in destination host.
+ *
+ * @param array  $gitems
+ * @param string $destinationHostId
+ * @param bool   $error					if false error won't be thrown when item does not exist
+ * @param array  $flags
  *
- * @param $gitems
- * @param $dest_hostid
- * @param bool $error if false error won't be thrown when item does not exist
  * @return array|bool
  */
-function get_same_graphitems_for_host($gitems, $dest_hostid, $error = true) {
+function getSameGraphItemsForHost($gitems, $destinationHostId, $error = true, array $flags = array()) {
 	$result = array();
 
+	$flagsSql = $flags ? ' AND '.dbConditionInt('dest.flags', $flags) : '';
+
 	foreach ($gitems as $gitem) {
 		$dbItem = DBfetch(DBselect(
 			'SELECT dest.itemid,src.key_'.
 			' FROM items dest,items src'.
 			' WHERE dest.key_=src.key_'.
-				' AND dest.hostid='.$dest_hostid.
-				' AND src.itemid='.$gitem['itemid']
+				' AND dest.hostid='.zbx_dbstr($destinationHostId).
+				' AND src.itemid='.zbx_dbstr($gitem['itemid']).
+				$flagsSql
 		));
 
 		if ($dbItem) {
@@ -317,13 +318,16 @@ function get_same_graphitems_for_host($gitems, $dest_hostid, $error = true) {
 		}
 		elseif ($error) {
 			$item = get_item_by_itemid($gitem['itemid']);
-			$host = get_host_by_hostid($dest_hostid);
+			$host = get_host_by_hostid($destinationHostId);
+
 			error(_s('Missing key "%1$s" for host "%2$s".', $item['key_'], $host['host']));
+
 			return false;
 		}
 		else {
 			continue;
 		}
+
 		$result[] = $gitem;
 	}
 
@@ -333,44 +337,54 @@ function get_same_graphitems_for_host($gitems, $dest_hostid, $error = true) {
 /**
  * Copy specified graph to specified host.
  *
- * @param $graphid
- * @param $hostid
- * @return array|bool
+ * @param string $graphId
+ * @param string $hostId
+ *
+ * @return array
  */
-function copy_graph_to_host($graphid, $hostid) {
+function copyGraphToHost($graphId, $hostId) {
 	$graphs = API::Graph()->get(array(
-		'graphids' => $graphid,
+		'graphids' => $graphId,
 		'output' => API_OUTPUT_EXTEND,
+		'selectHosts' => array('hostid', 'name'),
 		'selectGraphItems' => API_OUTPUT_EXTEND
 	));
 	$graph = reset($graphs);
+	$graphHost = reset($graph['hosts']);
 
-	$new_gitems = get_same_graphitems_for_host($graph['gitems'], $hostid);
+	if ($graphHost['hostid'] == $hostId) {
+		error(_s('Graph "%1$s" already exists on "%2$s".', $graph['name'], $graphHost['name']));
+
+		return false;
+	}
+
+	$graph['gitems'] = getSameGraphItemsForHost(
+		$graph['gitems'],
+		$hostId,
+		true,
+		array(ZBX_FLAG_DISCOVERY_NORMAL, ZBX_FLAG_DISCOVERY_CREATED)
+	);
+
+	if (!$graph['gitems']) {
+		$host = get_host_by_hostid($hostId);
 
-	if (!$new_gitems) {
-		$host = get_host_by_hostid($hostid);
 		info(_s('Skipped copying of graph "%1$s" to host "%2$s".', $graph['name'], $host['host']));
+
 		return false;
 	}
 
 	// retrieve actual ymax_itemid and ymin_itemid
-	if ($graph['ymax_itemid']) {
-		if ($itemid = get_same_item_for_host($graph['ymax_itemid'], $hostid)) {
-			$graph['ymax_itemid'] = $itemid;
-		};
+	if ($graph['ymax_itemid'] && $itemId = get_same_item_for_host($graph['ymax_itemid'], $hostId)) {
+		$graph['ymax_itemid'] = $itemId;
 	}
 
-	if ($graph['ymin_itemid']) {
-		if ($itemid = get_same_item_for_host($graph['ymin_itemid'], $hostid)) {
-			$graph['ymin_itemid'] = $itemid;
-		}
+	if ($graph['ymin_itemid'] && $itemId = get_same_item_for_host($graph['ymin_itemid'], $hostId)) {
+		$graph['ymin_itemid'] = $itemId;
 	}
 
-	$graph['gitems'] = $new_gitems;
 	unset($graph['templateid']);
-	$result = API::Graph()->create($graph);
 
-	return $result;
+	return API::Graph()->create($graph);
 }
 
 function navigation_bar_calc($idx = null, $idx2 = 0, $update = false) {
@@ -383,23 +397,23 @@ function navigation_bar_calc($idx = null, $idx2 = 0, $update = false) {
 				CProfile::update($idx.'.stime', $_REQUEST['stime'], PROFILE_TYPE_STR, $idx2);
 			}
 		}
-		$_REQUEST['period'] = get_request('period', CProfile::get($idx.'.period', ZBX_PERIOD_DEFAULT, $idx2));
-		$_REQUEST['stime'] = get_request('stime', CProfile::get($idx.'.stime', null, $idx2));
+		$_REQUEST['period'] = getRequest('period', CProfile::get($idx.'.period', ZBX_PERIOD_DEFAULT, $idx2));
+		$_REQUEST['stime'] = getRequest('stime', CProfile::get($idx.'.stime', null, $idx2));
 	}
 
-	$_REQUEST['period'] = get_request('period', ZBX_PERIOD_DEFAULT);
-	$_REQUEST['stime'] = get_request('stime', null);
+	$_REQUEST['period'] = getRequest('period', ZBX_PERIOD_DEFAULT);
+	$_REQUEST['stime'] = getRequest('stime');
 
 	if ($_REQUEST['period'] < ZBX_MIN_PERIOD) {
-		show_message(_n('Warning. Minimum time period to display is %1$s hour.',
-			'Warning. Minimum time period to display is %1$s hours.',
+		show_message(_n('Minimum time period to display is %1$s hour.',
+			'Minimum time period to display is %1$s hours.',
 			(int) ZBX_MIN_PERIOD / SEC_PER_HOUR
 		));
 		$_REQUEST['period'] = ZBX_MIN_PERIOD;
 	}
 	elseif ($_REQUEST['period'] > ZBX_MAX_PERIOD) {
-		show_message(_n('Warning. Maximum time period to display is %1$s day.',
-			'Warning. Maximum time period to display is %1$s days.',
+		show_message(_n('Maximum time period to display is %1$s day.',
+			'Maximum time period to display is %1$s days.',
 			(int) ZBX_MAX_PERIOD / SEC_PER_DAY
 		));
 		$_REQUEST['period'] = ZBX_MAX_PERIOD;
@@ -408,11 +422,11 @@ function navigation_bar_calc($idx = null, $idx2 = 0, $update = false) {
 	if (!empty($_REQUEST['stime'])) {
 		$time = zbxDateToTime($_REQUEST['stime']);
 		if (($time + $_REQUEST['period']) > time()) {
-			$_REQUEST['stime'] = date('YmdHis', time() - $_REQUEST['period']);
+			$_REQUEST['stime'] = date(TIMESTAMP_FORMAT, time() - $_REQUEST['period']);
 		}
 	}
 	else {
-		$_REQUEST['stime'] = date('YmdHis', time() - $_REQUEST['period']);
+		$_REQUEST['stime'] = date(TIMESTAMP_FORMAT, time() - $_REQUEST['period']);
 	}
 
 	return $_REQUEST['period'];
@@ -440,10 +454,10 @@ function get_next_color($palettetype = 0) {
 
 	switch ($prev_color['color']) {
 		case 0:
-			$r = $set_grad;
+			$g = $set_grad;
 			break;
 		case 1:
-			$g = $set_grad;
+			$r = $set_grad;
 			break;
 		case 2:
 			$b = $set_grad;
@@ -533,74 +547,25 @@ function get_next_palette($palette = 0, $palettetype = 0) {
 	return $result;
 }
 
-function imageDiagonalMarks($im,$x, $y, $offset, $color) {
-	global $colors;
-
-	$gims = array(
-		'lt' => array(0, 0, -9, 0, -9, -3, -3, -9, 0, -9),
-		'rt' => array(0, 0, 9, 0, 9, -3, 3,-9, 0, -9),
-		'lb' => array(0, 0, -9, 0, -9, 3, -3, 9, 0, 9),
-		'rb' => array(0, 0, 9, 0, 9, 3, 3, 9, 0, 9)
-	);
-
-	foreach ($gims['lt'] as $num => $px) {
-		if (($num % 2) == 0) {
-			$gims['lt'][$num] = $px + $x - $offset;
-		}
-		else {
-			$gims['lt'][$num] = $px + $y - $offset;
-		}
-	}
-
-	foreach ($gims['rt'] as $num => $px) {
-		if (($num % 2) == 0) {
-			$gims['rt'][$num] = $px + $x + $offset;
-		}
-		else {
-			$gims['rt'][$num] = $px + $y - $offset;
-		}
-	}
-
-	foreach ($gims['lb'] as $num => $px) {
-		if (($num % 2) == 0) {
-			$gims['lb'][$num] = $px + $x - $offset;
-		}
-		else {
-			$gims['lb'][$num] = $px + $y + $offset;
-		}
-	}
-
-	foreach ($gims['rb'] as $num => $px) {
-		if (($num % 2) == 0) {
-			$gims['rb'][$num] = $px + $x + $offset;
-		}
-		else {
-			$gims['rb'][$num] = $px + $y + $offset;
-		}
-	}
-
-	imagefilledpolygon($im, $gims['lt'], 5, $color);
-	imagepolygon($im, $gims['lt'], 5, $colors['Dark Red']);
-
-	imagefilledpolygon($im, $gims['rt'], 5, $color);
-	imagepolygon($im, $gims['rt'], 5, $colors['Dark Red']);
-
-	imagefilledpolygon($im, $gims['lb'], 5, $color);
-	imagepolygon($im, $gims['lb'], 5, $colors['Dark Red']);
-
-	imagefilledpolygon($im, $gims['rb'], 5, $color);
-	imagepolygon($im, $gims['rb'], 5, $colors['Dark Red']);
-}
-
-function imageVerticalMarks($im, $x, $y, $offset, $color, $marks = 'tlbr') {
+/**
+ * Draw trigger recent change markers.
+ *
+ * @param resource $im
+ * @param int      $x
+ * @param int      $y
+ * @param int      $offset
+ * @param string   $color
+ * @param string   $marks	"t" - top, "r" - right, "b" - bottom, "l" - left
+ */
+function imageVerticalMarks($im, $x, $y, $offset, $color, $marks) {
 	global $colors;
 
 	$polygons = 5;
 	$gims = array(
 		't' => array(0, 0, -6, -6, -3, -9, 3, -9, 6, -6),
-		'l' => array(0, 0, -6, 6, -9, 3, -9, -3, -6, -6),
+		'r' => array(0, 0, 6, -6, 9, -3, 9, 3, 6, 6),
 		'b' => array(0, 0, 6, 6, 3, 9, -3, 9, -6, 6),
-		'r' => array(0, 0, 6, -6, 9, -3, 9, 3, 6, 6)
+		'l' => array(0, 0, -6, 6, -9, 3, -9, -3, -6, -6)
 	);
 
 	foreach ($gims['t'] as $num => $px) {
@@ -612,24 +577,6 @@ function imageVerticalMarks($im, $x, $y, $offset, $color, $marks = 'tlbr') {
 		}
 	}
 
-	foreach ($gims['l'] as $num => $px) {
-		if (($num % 2) == 0) {
-			$gims['l'][$num] = $px + $x - $offset;
-		}
-		else {
-			$gims['l'][$num] = $px + $y;
-		}
-	}
-
-	foreach ($gims['b'] as $num => $px) {
-		if (($num % 2) == 0) {
-			$gims['b'][$num] = $px + $x;
-		}
-		else {
-			$gims['b'][$num] = $px + $y + $offset;
-		}
-	}
-
 	foreach ($gims['r'] as $num => $px) {
 		if (($num % 2) == 0) {
 			$gims['r'][$num] = $px + $x + $offset;
@@ -639,176 +586,108 @@ function imageVerticalMarks($im, $x, $y, $offset, $color, $marks = 'tlbr') {
 		}
 	}
 
+	foreach ($gims['b'] as $num => $px) {
+		if (($num % 2) == 0) {
+			$gims['b'][$num] = $px + $x;
+		}
+		else {
+			$gims['b'][$num] = $px + $y + $offset;
+		}
+	}
+
+	foreach ($gims['l'] as $num => $px) {
+		if (($num % 2) == 0) {
+			$gims['l'][$num] = $px + $x - $offset;
+		}
+		else {
+			$gims['l'][$num] = $px + $y;
+		}
+	}
+
 	if (strpos($marks, 't') !== false) {
 		imagefilledpolygon($im, $gims['t'], $polygons, $color);
 		imagepolygon($im, $gims['t'], $polygons, $colors['Dark Red']);
 	}
-	if (strpos($marks, 'l') !== false) {
-		imagefilledpolygon($im, $gims['l'], $polygons, $color);
-		imagepolygon($im, $gims['l'], $polygons, $colors['Dark Red']);
-	}
-	if (strpos($marks, 'b') !== false) {
-		imagefilledpolygon($im, $gims['b'], $polygons, $color);
-		imagepolygon($im, $gims['b'], $polygons, $colors['Dark Red']);
-	}
 	if (strpos($marks, 'r') !== false) {
 		imagefilledpolygon($im, $gims['r'], $polygons, $color);
 		imagepolygon($im, $gims['r'], $polygons, $colors['Dark Red']);
 	}
+	if (strpos($marks, 'b') !== false) {
+		imagefilledpolygon($im, $gims['b'], $polygons, $color);
+		imagepolygon($im, $gims['b'], $polygons, $colors['Dark Red']);
+	}
+	if (strpos($marks, 'l') !== false) {
+		imagefilledpolygon($im, $gims['l'], $polygons, $color);
+		imagepolygon($im, $gims['l'], $polygons, $colors['Dark Red']);
+	}
 }
 
+/**
+ * Draws a text on an image. Supports TrueType fonts.
+ *
+ * @param resource 	$image
+ * @param int		$fontsize
+ * @param int 		$angle
+ * @param int		$x
+ * @param int 		$y
+ * @param int		$color		a numeric color identifier from imagecolorallocate() or imagecolorallocatealpha()
+ * @param string	$string
+ */
 function imageText($image, $fontsize, $angle, $x, $y, $color, $string) {
-	$gdinfo = gd_info();
-
-	if ($gdinfo['FreeType Support'] && function_exists('imagettftext')) {
-		if ((preg_match(ZBX_PREG_DEF_FONT_STRING, $string) && $angle != 0) || ZBX_FONT_NAME == ZBX_GRAPH_FONT_NAME) {
-			$ttf = ZBX_FONTPATH.'/'.ZBX_FONT_NAME.'.ttf';
-			imagettftext($image, $fontsize, $angle, $x, $y, $color, $ttf, $string);
-		}
-		elseif ($angle == 0) {
-			$ttf = ZBX_FONTPATH.'/'.ZBX_GRAPH_FONT_NAME.'.ttf';
-			imagettftext($image, $fontsize, $angle, $x, $y, $color, $ttf, $string);
-		}
-		else {
-			$ttf = ZBX_FONTPATH.'/'.ZBX_GRAPH_FONT_NAME.'.ttf';
-			$size = imageTextSize($fontsize, 0, $string);
-
-			$imgg = imagecreatetruecolor($size['width'] + 1, $size['height']);
-			$transparentColor = imagecolorallocatealpha($imgg, 200, 200, 200, 127);
-			imagefill($imgg, 0, 0, $transparentColor);
-			imagettftext($imgg, $fontsize, 0, 0, $size['height'], $color, $ttf, $string);
-
-			$imgg = imagerotate($imgg, $angle, $transparentColor);
-			ImageAlphaBlending($imgg, false);
-			imageSaveAlpha($imgg, true);
-			imagecopy($image, $imgg, $x - $size['height'], $y - $size['width'], 0, 0, $size['height'], $size['width'] + 1);
-			imagedestroy($imgg);
-		}
+	if ((preg_match(ZBX_PREG_DEF_FONT_STRING, $string) && $angle != 0) || ZBX_FONT_NAME == ZBX_GRAPH_FONT_NAME) {
+		$ttf = ZBX_FONTPATH.'/'.ZBX_FONT_NAME.'.ttf';
+		imagettftext($image, $fontsize, $angle, $x, $y, $color, $ttf, $string);
+	}
+	elseif ($angle == 0) {
+		$ttf = ZBX_FONTPATH.'/'.ZBX_GRAPH_FONT_NAME.'.ttf';
+		imagettftext($image, $fontsize, $angle, $x, $y, $color, $ttf, $string);
 	}
 	else {
-		$dims = imageTextSize($fontsize, $angle, $string);
+		$ttf = ZBX_FONTPATH.'/'.ZBX_GRAPH_FONT_NAME.'.ttf';
+		$size = imageTextSize($fontsize, 0, $string);
 
-		switch($fontsize) {
-			case 5:
-				$fontsize = 1;
-				break;
-			case 6:
-				$fontsize = 1;
-				break;
-			case 7:
-				$fontsize = 2;
-				break;
-			case 8:
-				$fontsize = 2;
-				break;
-			case 9:
-				$fontsize = 3;
-				break;
-			case 10:
-				$fontsize = 3;
-				break;
-			case 11:
-				$fontsize = 4;
-				break;
-			case 12:
-				$fontsize = 4;
-				break;
-			case 13:
-				$fontsize = 5;
-				break;
-			case 14:
-				$fontsize = 5;
-				break;
-			default:
-				$fontsize = 2;
-				break;
-		}
+		$imgg = imagecreatetruecolor($size['width'] + 1, $size['height']);
+		$transparentColor = imagecolorallocatealpha($imgg, 200, 200, 200, 127);
+		imagefill($imgg, 0, 0, $transparentColor);
+		imagettftext($imgg, $fontsize, 0, 0, $size['height'], $color, $ttf, $string);
 
-		if ($angle) {
-			$x -= $dims['width'];
-			$y -= 2;
-		}
-		else {
-			$y -= $dims['height'] - 2;
-		}
-
-		if ($angle > 0) {
-			return imagestringup($image, $fontsize, $x, $y, $string, $color);
-		}
-		return imagestring($image, $fontsize, $x, $y, $string, $color);
+		$imgg = imagerotate($imgg, $angle, $transparentColor);
+		imagealphablending($imgg, false);
+		imagesavealpha($imgg, true);
+		imagecopy($image, $imgg, $x - $size['height'], $y - $size['width'], 0, 0, $size['height'], $size['width'] + 1);
+		imagedestroy($imgg);
 	}
-
-	return true;
 }
 
+/**
+ * Calculates the size of the given string.
+ *
+ * Returns the following data:
+ * - height 	- height of the text;
+ * - width		- width of the text;
+ * - baseline	- baseline Y coordinate (can only be used for horizontal text, can be negative).
+ *
+ * @param int 		$fontsize
+ * @param int 		$angle
+ * @param string 	$string
+ *
+ * @return array
+ */
 function imageTextSize($fontsize, $angle, $string) {
-	$gdinfo = gd_info();
-
-	$result = array();
-
-	if ($gdinfo['FreeType Support'] && function_exists('imagettfbbox')) {
-		if (preg_match(ZBX_PREG_DEF_FONT_STRING, $string) && $angle != 0) {
-			$ttf = ZBX_FONTPATH.'/'.ZBX_FONT_NAME.'.ttf';
-		}
-		else {
-			$ttf = ZBX_FONTPATH.'/'.ZBX_GRAPH_FONT_NAME.'.ttf';
-		}
-
-		$ar = imagettfbbox($fontsize, $angle, $ttf, $string);
-
-		$result['height'] = abs($ar[1] - $ar[5]);
-		$result['width'] = abs($ar[0] - $ar[4]);
-		$result['baseline'] = $ar[1];
+	if (preg_match(ZBX_PREG_DEF_FONT_STRING, $string) && $angle != 0) {
+		$ttf = ZBX_FONTPATH.'/'.ZBX_FONT_NAME.'.ttf';
 	}
 	else {
-		switch($fontsize) {
-			case 5:
-				$fontsize = 1;
-				break;
-			case 6:
-				$fontsize = 1;
-				break;
-			case 7:
-				$fontsize = 2;
-				break;
-			case 8:
-				$fontsize = 2;
-				break;
-			case 9:
-				$fontsize = 3;
-				break;
-			case 10:
-				$fontsize = 3;
-				break;
-			case 11:
-				$fontsize = 4;
-				break;
-			case 12:
-				$fontsize = 4;
-				break;
-			case 13:
-				$fontsize = 5;
-				break;
-			case 14:
-				$fontsize = 5;
-				break;
-			default:
-				$fontsize = 2;
-				break;
-		}
-
-		if ($angle) {
-			$result['width'] = imagefontheight($fontsize);
-			$result['height'] = imagefontwidth($fontsize) * zbx_strlen($string);
-		}
-		else {
-			$result['height'] = imagefontheight($fontsize);
-			$result['width'] = imagefontwidth($fontsize) * zbx_strlen($string);
-		}
-		$result['baseline'] = 0;
+		$ttf = ZBX_FONTPATH.'/'.ZBX_GRAPH_FONT_NAME.'.ttf';
 	}
 
-	return $result;
+	$ar = imagettfbbox($fontsize, $angle, $ttf, $string);
+
+	return array(
+		'height' => abs($ar[1] - $ar[5]),
+		'width' => abs($ar[0] - $ar[4]),
+		'baseline' => $ar[1]
+	);
 }
 
 function dashedLine($image, $x1, $y1, $x2, $y2, $color) {
@@ -821,7 +700,7 @@ function dashedLine($image, $x1, $y1, $x2, $y2, $color) {
 	}
 
 	imagesetstyle($image, $style);
-	imageline($image, $x1, $y1, $x2, $y2, IMG_COLOR_STYLED);
+	zbx_imageline($image, $x1, $y1, $x2, $y2, IMG_COLOR_STYLED);
 }
 
 function dashedRectangle($image, $x1, $y1, $x2, $y2, $color) {
@@ -931,3 +810,135 @@ function find_period_end($periods, $time, $max_time) {
 
 	return -1;
 }
+
+/**
+ * Converts Base1000 values to Base1024 and calculate pow
+ * Example:
+ * 	204800 (200 KBytes) with '1024' step convert to 209715,2 (0.2MB (204.8 KBytes))
+ *
+ * @param string   $value
+ * @param bool|int $step
+ *
+ * @return array
+ */
+function convertToBase1024($value, $step = false) {
+	if (!$step) {
+		$step = 1000;
+	}
+
+	if ($value < 0) {
+		$abs = bcmul($value, '-1');
+	}
+	else {
+		$abs = $value;
+	}
+
+	// set default values
+	$valData['pow'] = 0;
+	$valData['value'] = 0;
+
+	// supported pows ('-2' - '8')
+	for ($i = -2; $i < 9; $i++) {
+		$val = bcpow($step, $i);
+		if (bccomp($abs, $val) > -1) {
+			$valData['pow'] = $i;
+			$valData['value'] = $val;
+		}
+		else {
+			break;
+		}
+	}
+
+	if ($valData['pow'] >= 0) {
+		if ($valData['value'] != 0) {
+			$valData['value'] = bcdiv(sprintf('%.10f',$value), sprintf('%.10f', $valData['value']),
+				ZBX_PRECISION_10);
+
+			$valData['value'] = sprintf('%.10f', round(bcmul($valData['value'], bcpow(1024, $valData['pow'])),
+				ZBX_PRECISION_10));
+		}
+	}
+	else {
+		$valData['pow'] = 0;
+		if (round($valData['value'], 6) > 0) {
+			$valData['value'] = $value;
+		}
+		else {
+			$valData['value'] = 0;
+		}
+	}
+
+	return $valData;
+}
+
+/**
+ * Calculate interval for base 1024 values.
+ * Example:
+ * 	Convert 1000 to 1024
+ *
+ * @param $interval
+ * @param $minY
+ * @param $maxY
+ *
+ * @return float|int
+ */
+function getBase1024Interval($interval, $minY, $maxY) {
+	$intervalData = convertToBase1024($interval);
+	$interval = $intervalData['value'];
+
+	if ($maxY > 0) {
+		$absMaxY = $maxY;
+	}
+	else {
+		$absMaxY = bcmul($maxY, '-1');
+	}
+
+	if ($minY > 0) {
+		$absMinY = $minY;
+	}
+	else {
+		$absMinY = bcmul($minY, '-1');
+	}
+
+	if ($absMaxY > $absMinY) {
+		$sideMaxData = convertToBase1024($maxY);
+	}
+	else {
+		$sideMaxData = convertToBase1024($minY);
+	}
+
+	if ($sideMaxData['pow'] != $intervalData['pow']) {
+		// interval correction, if Max Y have other unit, then interval unit = Max Y unit
+		if ($intervalData['pow'] < 0) {
+			$interval = sprintf('%.10f', bcmul($interval, 1.024, 10));
+		}
+		else {
+			$interval = sprintf('%.6f', round(bcmul($interval, 1.024), ZBX_UNITS_ROUNDOFF_UPPER_LIMIT));
+		}
+	}
+
+	return $interval;
+}
+
+/**
+ * Returns digit count for the item with most digit after point in given array.
+ * Example:
+ *	Input: array(0, 0.1, 0.25, 0.005)
+ *	Return 3
+ *
+ * @param array $calcValues
+ *
+ * @return int
+ */
+function calcMaxLengthAfterDot($calcValues) {
+	$maxLength = 0;
+
+	foreach ($calcValues as $calcValue) {
+		preg_match('/^-?[0-9].?([0-9]*)\s?/', $calcValue, $matches);
+		if ($matches['1'] != 0 && strlen($matches['1']) > $maxLength) {
+			$maxLength = strlen($matches['1']);
+		}
+	}
+
+	return $maxLength;
+}
