@@ -57,11 +57,16 @@ function bold($str) {
 
 function make_decoration($haystack, $needle, $class = null) {
 	$result = $haystack;
-	$pos = zbx_stripos($haystack, $needle);
+
+	$tmpHaystack = mb_strtolower($haystack);
+	$tmpNeedle = mb_strtolower($needle);
+	$pos = mb_strpos($tmpHaystack, $tmpNeedle);
+
 	if ($pos !== false) {
-		$start = CHtml::encode(zbx_substring($haystack, 0, $pos));
-		$end = CHtml::encode(zbx_substring($haystack, $pos + zbx_strlen($needle)));
-		$found = CHtml::encode(zbx_substring($haystack, $pos, $pos + zbx_strlen($needle)));
+		$start = CHtml::encode(mb_substr($haystack, 0, $pos));
+		$end = CHtml::encode(mb_substr($haystack, $pos + mb_strlen($needle)));
+		$found = CHtml::encode(mb_substr($haystack, $pos, mb_strlen($needle)));
+
 		if (is_null($class)) {
 			$result = array($start, bold($found), $end);
 		}
@@ -69,6 +74,7 @@ function make_decoration($haystack, $needle, $class = null) {
 			$result = array($start, new CSpan($found, $class), $end);
 		}
 	}
+
 	return $result;
 }
 
@@ -140,52 +146,6 @@ function BR() {
 	return new CTag('br', 'no');
 }
 
-function create_hat($caption, $items, $addicons = null, $id = null, $state = null) {
-	if (is_null($id)) {
-		list($usec, $sec) = explode(' ', microtime());
-		$id = 'hat_'.((int)($sec % 10)).((int)($usec * 1000));
-	}
-	$td_l = new CCol(SPACE);
-	$td_l->setAttribute('width', '100%');
-
-	$icons_row = array($td_l);
-	if (!is_null($addicons)) {
-		if (!is_array($addicons)) {
-			$addicons = array($addicons);
-		}
-		foreach ($addicons as $value) {
-			$icons_row[] = $value;
-		}
-	}
-
-	if (!is_null($state)) {
-		$icon = new CIcon(_('Show').'/'._('Hide'), $state ? 'arrowup' : 'arrowdown', "change_hat_state(this,'".$id."');");
-		$icon->setAttribute('id', $id.'_icon');
-		$icons_row[] = $icon;
-	}
-	else {
-		$state = true;
-	}
-
-	$icon_tab = new CTable();
-	$icon_tab->setAttribute('width', '100%');
-	$icon_tab->addRow($icons_row);
-
-	$table = new CTable();
-	$table->setAttribute('width', '100%');
-	$table->setCellPadding(0);
-	$table->setCellSpacing(0);
-	$table->addRow(get_table_header($caption, $icon_tab));
-
-	$div = new CDiv($items);
-	$div->setAttribute('id', $id);
-	if (!$state) {
-		$div->setAttribute('style', 'display: none;');
-	}
-	$table->addRow($div);
-	return $table;
-}
-
 function get_table_header($columnLeft, $columnRights = SPACE) {
 	$rights = array();
 
@@ -214,14 +174,14 @@ function show_table_header($columnLeft, $columnRights = SPACE){
 	$table->show();
 }
 
-function get_icon($name, $params = array()) {
-	switch ($name) {
+function get_icon($type, $params = array()) {
+	switch ($type) {
 		case 'favourite':
 			if (CFavorite::exists($params['fav'], $params['elid'], $params['elname'])) {
 				$icon = new CIcon(
 					_('Remove from favourites'),
 					'iconminus',
-					'rm4favorites("'.$params['elname'].'", "'.$params['elid'].'", 0);'
+					'rm4favorites("'.$params['elname'].'", "'.$params['elid'].'");'
 				);
 			}
 			else {
@@ -232,24 +192,24 @@ function get_icon($name, $params = array()) {
 				);
 			}
 			$icon->setAttribute('id', 'addrm_fav');
-			break;
+
+			return $icon;
+
 		case 'fullscreen':
-			$url = new Curl();
+			$url = new CUrl();
 			$url->setArgument('fullscreen', $params['fullscreen'] ? '0' : '1');
-			$icon = new CIcon(
-				$_REQUEST['fullscreen'] ? _('Normal view') : _('Fullscreen'),
+
+			return new CIcon(
+				$params['fullscreen'] ? _('Normal view') : _('Fullscreen'),
 				'fullscreen',
 				"document.location = '".$url->getUrl()."';"
 			);
-			break;
-		case 'menu':
-			$icon = new CIcon(_('Menu'), 'iconmenu', 'create_page_menu(event, "'.$params['menu'].'");');
-			break;
+
 		case 'reset':
-			$icon = new CIcon(_('Reset'), 'iconreset', 'timeControl.objectReset();');
-			break;
+			return new CIcon(_('Reset'), 'iconreset', 'timeControl.objectReset();');
 	}
-	return $icon;
+
+	return null;
 }
 
 /**
@@ -357,7 +317,7 @@ function get_header_host_table($currentElement, $hostid, $discoveryid = null) {
 		$proxyName = CHtml::encode($proxy['host']).NAME_DELIMITER;
 	}
 
-	$name = get_node_name_by_elid($dbHost['hostid'], true, NAME_DELIMITER).$proxyName.CHtml::encode($dbHost['name']);
+	$name = $proxyName.CHtml::encode($dbHost['name']);
 
 	if ($dbHost['status'] == HOST_STATUS_TEMPLATE) {
 		$list->addItem(array(bold(_('Template').NAME_DELIMITER), new CLink($name, 'templates.php?form=update&templateid='.$dbHost['hostid'])));
@@ -369,11 +329,11 @@ function get_header_host_table($currentElement, $hostid, $discoveryid = null) {
 					$status = new CSpan(_('In maintenance'), 'orange');
 				}
 				else {
-					$status = new CSpan(_('Monitored'), 'enabled');
+					$status = new CSpan(_('Enabled'), 'enabled');
 				}
 				break;
 			case HOST_STATUS_NOT_MONITORED:
-				$status = new CSpan(_('Not monitored'), 'on');
+				$status = new CSpan(_('Disabled'), 'on');
 				break;
 			default:
 				$status = _('Unknown');
@@ -580,7 +540,7 @@ function getAvailabilityTable($host) {
 				break;
 			case HOST_AVAILABLE_FALSE:
 				$ai = new CDiv(SPACE, 'status_icon status_icon_extra icon'.$val.'unavailable');
-				$ai->setHint($host[$val.'_error'], '', 'on');
+				$ai->setHint($host[$val.'_error'], 'on');
 				break;
 			case HOST_AVAILABLE_UNKNOWN:
 				$ai = new CDiv(SPACE, 'status_icon status_icon_extra icon'.$val.'unknown');
@@ -592,11 +552,12 @@ function getAvailabilityTable($host) {
 	// discovered host lifetime indicator
 	if ($host['flags'] == ZBX_FLAG_DISCOVERY_CREATED && $host['hostDiscovery']['ts_delete']) {
 		$deleteError = new CDiv(SPACE, 'status_icon status_icon_extra iconwarning');
-		$deleteError->setHint(
-			_s('The host is not discovered anymore and will be deleted in %1$s (on %2$s at %3$s).',
-				zbx_date2age($host['hostDiscovery']['ts_delete']), zbx_date2str(_('d M Y'), $host['hostDiscovery']['ts_delete']),
-				zbx_date2str(_('H:i:s'), $host['hostDiscovery']['ts_delete'])
-			));
+		$deleteError->setHint(_s(
+			'The host is not discovered anymore and will be deleted in %1$s (on %2$s at %3$s).',
+			zbx_date2age($host['hostDiscovery']['ts_delete']),
+			zbx_date2str(DATE_FORMAT, $host['hostDiscovery']['ts_delete']),
+			zbx_date2str(TIME_FORMAT, $host['hostDiscovery']['ts_delete'])
+		));
 		$ad->addItem($deleteError);
 	}
 
@@ -637,18 +598,30 @@ function createDateSelector($name, $date, $relatedCalendar = null) {
 		$i = date('i', $date);
 	}
 
-	$day = new CNumericBox($name.'_day', $d, 2);
+	$day = new CTextBox($name.'_day', $d, 2, false, 2);
+	$day->attr('style', 'text-align: right;');
 	$day->attr('placeholder', _('dd'));
-	$month = new CNumericBox($name.'_month', $m, 2);
+	$day->addAction('onchange', 'validateDatePartBox(this, 1, 31, 2);');
+
+	$month = new CTextBox($name.'_month', $m, 2, false, 2);
+	$month->attr('style', 'text-align: right;');
 	$month->attr('placeholder', _('mm'));
+	$month->addAction('onchange', 'validateDatePartBox(this, 1, 12, 2);');
+
 	$year = new CNumericBox($name.'_year', $y, 4);
 	$year->attr('placeholder', _('yyyy'));
-	$hour = new CNumericBox($name.'_hour', $h, 2);
-	$hour->attr('placeholder', _('hh'));
-	$minute = new CNumericBox($name.'_minute', $i, 2);
-	$minute->attr('placeholder', _('mm'));
 
-	$fields = array($day, '/', $month, '/', $year, SPACE, $hour, ':', $minute, $calendarIcon);
+	$hour = new CTextBox($name.'_hour', $h, 2, false, 2);
+	$hour->attr('style', 'text-align: right;');
+	$hour->attr('placeholder', _('hh'));
+	$hour->addAction('onchange', 'validateDatePartBox(this, 0, 23, 2);');
+
+	$minute = new CTextBox($name.'_minute', $i, 2, false, 2);
+	$minute->attr('style', 'text-align: right;');
+	$minute->attr('placeholder', _('mm'));
+	$minute->addAction('onchange', 'validateDatePartBox(this, 0, 59, 2);');
+
+	$fields = array($year, '-', $month, '-', $day, ' ', $hour, ':', $minute, $calendarIcon);
 
 	zbx_add_post_js('create_calendar(null,'.
 		'["'.$name.'_day","'.$name.'_month","'.$name.'_year","'.$name.'_hour","'.$name.'_minute"],'.
