@@ -100,9 +100,10 @@ function encodeValues(&$value, $encodeTwice = true) {
 function zbx_add_post_js($script) {
 	global $ZBX_PAGE_POST_JS;
 
-	if (!isset($ZBX_PAGE_POST_JS)) {
+	if ($ZBX_PAGE_POST_JS === null) {
 		$ZBX_PAGE_POST_JS = array();
 	}
+
 	if (!in_array($script, $ZBX_PAGE_POST_JS)) {
 		$ZBX_PAGE_POST_JS[] = $script;
 	}
@@ -116,45 +117,37 @@ function insert_javascript_for_editable_combobox() {
 
 	$js = '
 		function CEditableComboBoxInit(obj) {
-			// check if option exist
-			var opt = obj.options;
-			if (obj.value) {
-				obj.oldValue = obj.value;
-			}
-			for (var i = 0; i < opt.length; i++) {
-				if (-1 == opt.item(i).value) {
-					return null;
-				}
-			}
-			// create option
-			opt = document.createElement("option");
-			opt.value = -1;
-			if (IE) {
-				opt.innerHTML = "('._('other').' ...)";
-			}
-			else {
-				opt.text = "('._('other').' ...)";
-			}
-			obj.insertBefore(opt, obj.firstChild);
+			// store previous value
+			obj.oldValue = obj.value;
 		}
 
-		function CEditableComboBoxOnChange(obj, size) {
+		function CEditableComboBoxOnChange(obj, size, width) {
 			if (-1 != obj.value) {
 				obj.oldValue = obj.value;
 			}
 			else {
-				var new_obj = document.createElement("input");
-				new_obj.type = "text";
-				new_obj.name = obj.name;
-				if (size && size > 0) {
-					new_obj.size = size;
+				var newObj = document.createElement("input");
+
+				newObj.type = "text";
+				newObj.name = obj.name;
+				newObj.className = "input text";
+
+				if (size !== null) {
+					newObj.size = size;
 				}
+
+				if (width !== null) {
+					newObj.style.width = width + "px";
+				}
+
 				if (obj.oldValue) {
-					new_obj.value = obj.oldValue;
+					newObj.value = obj.oldValue;
 				}
-				obj.parentNode.replaceChild(new_obj, obj);
-				new_obj.focus();
-				new_obj.select();
+
+				obj.parentNode.replaceChild(newObj, obj);
+
+				newObj.focus();
+				newObj.select();
 			}
 		}';
 	insert_js($js);
@@ -282,17 +275,6 @@ function insert_javascript_for_visibilitybox() {
 	insert_js($js);
 }
 
-function play_sound($filename) {
-	insert_js('
-		if (IE) {
-			document.writeln(\'<bgsound src="'.$filename.'" loop="0" />\');
-		}
-		else {
-			document.writeln(\'<embed src="'.$filename.'" autostart="true" width="0" height="0" loop="0" />\');
-			document.writeln(\'<noembed><bgsound src="'.$filename.'" loop="0" /></noembed>\');
-		}');
-}
-
 function insert_js_function($fnct_name) {
 	switch ($fnct_name) {
 		case 'add_item_variable':
@@ -523,20 +505,21 @@ function insert_js($script, $jQueryDocumentReady = false) {
 
 function get_js($script, $jQueryDocumentReady = false) {
 	return $jQueryDocumentReady
-		? '<script type="text/javascript">// <![CDATA['."\n".'jQuery(document).ready(function() { '.$script.' });'."\n".'// ]]></script>'
-		: '<script type="text/javascript">// <![CDATA['."\n".$script."\n".'// ]]></script>';
+		? '<script type="text/javascript">'."\n".'jQuery(document).ready(function() { '.$script.' });'."\n".'</script>'
+		: '<script type="text/javascript">'."\n".$script."\n".'</script>';
 }
 
 function insertPagePostJs() {
 	global $ZBX_PAGE_POST_JS;
 
-	if (!empty($ZBX_PAGE_POST_JS)) {
+	if ($ZBX_PAGE_POST_JS) {
 		$js = '';
+
 		foreach ($ZBX_PAGE_POST_JS as $script) {
 			$js .= $script."\n";
 		}
 
-		if (!empty($js)) {
+		if ($js) {
 			echo get_js($js, true);
 		}
 	}
