@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 
 $iconMapTable = new CTableInfo(_('No icon maps found.'));
 $iconMapTable->setHeader(array(
-	$this->data['displayNodes'] ? _('Node') : null,
 	_('Name'),
 	_('Icon map')
 ));
@@ -31,12 +30,11 @@ foreach ($this->data['iconmaps'] as $iconMap) {
 	$row = array();
 	foreach ($iconMap['mappings'] as $mapping) {
 		$row[] = $this->data['inventoryList'][$mapping['inventory_link']].NAME_DELIMITER.
-				$mapping['expression'].SPACE.RARR.SPACE.$this->data['iconList'][$mapping['iconid']];
+				$mapping['expression'].SPACE.'&rArr;'.SPACE.$this->data['iconList'][$mapping['iconid']];
 		$row[] = BR();
 	}
 
 	$iconMapTable->addRow(array(
-		$this->data['displayNodes'] ? $iconMap['nodename'] : null,
 		new CLink($iconMap['name'], 'adm.iconmapping.php?form=update&iconmapid='.$iconMap['iconmapid']),
 		$row
 	));
