@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -17,8 +17,8 @@
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
-?>
-<?php
+
+
 include('include/views/js/administration.general.triggerSeverity.js.php');
 
 $severityTab = new CFormList('scriptsTab');
@@ -71,9 +71,10 @@ $severityView->addTab('severities', _('Trigger severities'), $severityTab);
 
 $severityForm = new CForm();
 $severityForm->setName('triggerSeverity');
-$severityForm->addVar('form_refresh', $this->data['form_refresh'] + 1);
 $severityForm->addItem($severityView);
-$severityForm->addItem(makeFormFooter(new CSubmit('save', _('Save')), new CButton('resetDefaults', _('Reset defaults'))));
+$severityForm->addItem(makeFormFooter(
+	new CSubmit('update', _('Update')),
+	new CButton('resetDefaults', _('Reset defaults'))
+));
 
 return $severityForm;
-?>
