@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -28,11 +28,13 @@ $actionWidget->addPageHeader(_('CONFIGURATION OF ACTIONS'));
 $actionForm = new CForm();
 $actionForm->setName('action.edit');
 $actionForm->addVar('form', $this->data['form']);
-$actionForm->addVar('form_refresh', $this->data['form_refresh']);
-$actionForm->addVar('eventsource', $this->data['eventsource']);
-if (!empty($this->data['actionid'])) {
+
+if ($this->data['actionid']) {
 	$actionForm->addVar('actionid', $this->data['actionid']);
 }
+else {
+	$actionForm->addVar('eventsource', $this->data['eventsource']);
+}
 
 /*
  * Action tab
@@ -70,7 +72,7 @@ $conditionTable->attr('style', 'min-width: 350px;');
 $conditionTable->setHeader(array(_('Label'), _('Name'), _('Action')));
 
 $i = 0;
-foreach ($this->data['action']['conditions'] as $condition) {
+foreach ($this->data['action']['filter']['conditions'] as $condition) {
 	if (!isset($condition['conditiontype'])) {
 		$condition['conditiontype'] = 0;
 	}
@@ -84,10 +86,11 @@ foreach ($this->data['action']['conditions'] as $condition) {
 		continue;
 	}
 
-	$label = num2letter($i);
-	$labelSpan = new CSpan('('.$label.')', 'label');
+	$label = isset($condition['formulaid']) ? $condition['formulaid'] : num2letter($i);
+
+	$labelSpan = new CSpan($label, 'label');
 	$labelSpan->setAttribute('data-conditiontype', $condition['conditiontype']);
-	$labelSpan->setAttribute('data-label', $label);
+	$labelSpan->setAttribute('data-formulaid', $label);
 
 	$conditionTable->addRow(
 		array(
@@ -96,7 +99,8 @@ foreach ($this->data['action']['conditions'] as $condition) {
 			array(
 				new CButton('remove', _('Remove'), 'javascript: removeCondition('.$i.');', 'link_menu'),
 				new CVar('conditions['.$i.']', $condition)
-			)
+			),
+			new CVar('conditions[' . $i . '][formulaid]', $label)
 		),
 		null, 'conditions_'.$i
 	);
@@ -104,11 +108,30 @@ foreach ($this->data['action']['conditions'] as $condition) {
 	$i++;
 }
 
-$calculationTypeComboBox = new CComboBox('evaltype', $this->data['action']['evaltype'], 'submit()');
-$calculationTypeComboBox->addItem(ACTION_EVAL_TYPE_AND_OR, _('AND / OR'));
-$calculationTypeComboBox->addItem(ACTION_EVAL_TYPE_AND, _('AND'));
-$calculationTypeComboBox->addItem(ACTION_EVAL_TYPE_OR, _('OR'));
-$conditionFormList->addRow(_('Type of calculation'), array($calculationTypeComboBox, new CSpan('', null, 'conditionLabel')), false, 'conditionRow');
+$formula = new CTextBox('formula', $this->data['action']['filter']['formula'], ZBX_TEXTBOX_STANDARD_SIZE);
+$formula->attr('id', 'formula');
+$formula->attr('placeholder', 'A or (B and C) &hellip;');
+if ($this->data['action']['filter']['evaltype'] != CONDITION_EVAL_TYPE_EXPRESSION)  {
+	$formula->addClass('hidden');
+}
+
+$calculationTypeComboBox = new CComboBox('evaltype', $this->data['action']['filter']['evaltype'], 'processTypeOfCalculation()');
+$calculationTypeComboBox->addItem(CONDITION_EVAL_TYPE_AND_OR, _('And/Or'));
+$calculationTypeComboBox->addItem(CONDITION_EVAL_TYPE_AND, _('And'));
+$calculationTypeComboBox->addItem(CONDITION_EVAL_TYPE_OR, _('Or'));
+$calculationTypeComboBox->addItem(CONDITION_EVAL_TYPE_EXPRESSION, _('Custom expression'));
+$calculationTypeComboBox->setAttribute('id', 'evaltype');
+
+$conditionFormList->addRow(
+	_('Type of calculation'),
+	array(
+		$calculationTypeComboBox,
+		new CSpan('', ($this->data['action']['filter']['evaltype'] == CONDITION_EVAL_TYPE_EXPRESSION) ? 'hidden' : '', 'conditionLabel'),
+		$formula
+	),
+	false,
+	'conditionRow'
+);
 $conditionFormList->addRow(_('Conditions'), new CDiv($conditionTable, 'objectgroup inlineblock border_dotted ui-corner-all'));
 
 // append new condition to form list
@@ -137,7 +160,13 @@ switch ($this->data['new_condition']['conditiontype']) {
 			'objectOptions' => array(
 				'editable' => true
 			),
-			'defaultValue' => 0
+			'defaultValue' => 0,
+			'popup' => array(
+				'parameters' => 'srctbl=host_groups&dstfrm='.$actionForm->getName().'&dstfld1=new_condition_value_'.
+					'&srcfld1=groupid&writeonly=1&multiselect=1',
+				'width' => 450,
+				'height' => 450
+			)
 		));
 		break;
 
@@ -148,7 +177,13 @@ switch ($this->data['new_condition']['conditiontype']) {
 			'objectOptions' => array(
 				'editable' => true
 			),
-			'defaultValue' => 0
+			'defaultValue' => 0,
+			'popup' => array(
+				'parameters' => 'srctbl=templates&srcfld1=hostid&srcfld2=host&dstfrm='.$actionForm->getName().
+					'&dstfld1=new_condition_value_&templated_hosts=1&multiselect=1&writeonly=1',
+				'width' => 450,
+				'height' => 450
+			)
 		));
 		break;
 
@@ -159,7 +194,13 @@ switch ($this->data['new_condition']['conditiontype']) {
 			'objectOptions' => array(
 				'editable' => true
 			),
-			'defaultValue' => 0
+			'defaultValue' => 0,
+			'popup' => array(
+				'parameters' => 'srctbl=hosts&dstfrm='.$actionForm->getName().'&dstfld1=new_condition_value_'.
+					'&srcfld1=hostid&writeonly=1&multiselect=1',
+				'width' => 450,
+				'height' => 450
+			)
 		));
 		break;
 
@@ -170,7 +211,13 @@ switch ($this->data['new_condition']['conditiontype']) {
 			'objectOptions' => array(
 				'editable' => true
 			),
-			'defaultValue' => 0
+			'defaultValue' => 0,
+			'popup' => array(
+				'parameters' => 'srctbl=triggers&dstfrm='.$actionForm->getName().'&dstfld1=new_condition_value_'.
+					'&srcfld1=triggerid&writeonly=1&multiselect=1&noempty=1',
+				'width' => 600,
+				'height' => 450
+			)
 		));
 		break;
 
@@ -198,24 +245,10 @@ switch ($this->data['new_condition']['conditiontype']) {
 		$condition = new CCol(_('maintenance'));
 		break;
 
-	case CONDITION_TYPE_NODE:
-		$conditionFormList->addItem(new CVar('new_condition[value]', '0'));
-		$condition = array(
-			new CTextBox('node', '', ZBX_TEXTBOX_STANDARD_SIZE, 'yes'),
-			SPACE,
-			new CButton('btn1', _('Select'),
-				'return PopUp("popup.php?srctbl=nodes&srcfld1=nodeid&srcfld2=name'.
-					'&dstfrm='.$actionForm->getName().'&dstfld1=new_condition_value&dstfld2=node'.
-					'&writeonly=1", 450, 450);',
-				'link_menu'
-			)
-		);
-		break;
-
 	case CONDITION_TYPE_DRULE:
 		$conditionFormList->addItem(new CVar('new_condition[value]', '0'));
 		$condition = array(
-			new CTextBox('drule', '', ZBX_TEXTBOX_STANDARD_SIZE, 'yes'),
+			new CTextBox('drule', '', ZBX_TEXTBOX_STANDARD_SIZE, true),
 			SPACE,
 			new CButton('btn1', _('Select'),
 				'return PopUp("popup.php?srctbl=drules&srcfld1=druleid&srcfld2=name'.
@@ -228,7 +261,7 @@ switch ($this->data['new_condition']['conditiontype']) {
 	case CONDITION_TYPE_DCHECK:
 		$conditionFormList->addItem(new CVar('new_condition[value]', '0'));
 		$condition = array(
-			new CTextBox('dcheck', '', ZBX_TEXTBOX_STANDARD_SIZE, 'yes'),
+			new CTextBox('dcheck', '', ZBX_TEXTBOX_STANDARD_SIZE, true),
 			SPACE,
 			new CButton('btn1', _('Select'),
 				'return PopUp("popup.php?srctbl=dchecks&srcfld1=dcheckid&srcfld2=name'.
@@ -241,7 +274,7 @@ switch ($this->data['new_condition']['conditiontype']) {
 	case CONDITION_TYPE_PROXY:
 		$conditionFormList->addItem(new CVar('new_condition[value]', '0'));
 		$condition = array(
-			new CTextBox('proxy', '', ZBX_TEXTBOX_STANDARD_SIZE, 'yes'),
+			new CTextBox('proxy', '', ZBX_TEXTBOX_STANDARD_SIZE, true),
 			SPACE,
 			new CButton('btn1', _('Select'),
 				'return PopUp("popup.php?srctbl=proxies&srcfld1=hostid&srcfld2=host'.
@@ -257,10 +290,12 @@ switch ($this->data['new_condition']['conditiontype']) {
 		break;
 
 	case CONDITION_TYPE_DSERVICE_TYPE:
+		$discoveryCheckTypes = discovery_check_type2str();
+		order_result($discoveryCheckTypes);
+
 		$condition = new CComboBox('new_condition[value]');
-		foreach (array(SVC_SSH, SVC_LDAP, SVC_SMTP, SVC_FTP, SVC_HTTP, SVC_HTTPS, SVC_POP, SVC_NNTP, SVC_IMAP, SVC_TCP,
-				SVC_AGENT, SVC_SNMPv1, SVC_SNMPv2c, SVC_SNMPv3, SVC_ICMPPING, SVC_TELNET) as $svc) {
-			$condition->addItem($svc,discovery_check_type2str($svc));
+		foreach ($discoveryCheckTypes as $key => $discoveryCheckType) {
+			$condition->addItem($key, $discoveryCheckType);
 		}
 		break;
 
@@ -314,7 +349,7 @@ $conditionTable = new CTable(null, 'newActionConditionTable');
 $conditionTable->addRow(array($conditionTypeComboBox, $conditionOperatorsComboBox, $condition));
 $conditionTable->addRow(array(new CSubmit('add_condition', _('Add'), null, 'link_menu'), SPACE, SPACE));
 
-$conditionFormList->addRow(_('New condition'), new CDiv($conditionTable, 'objectgroup inlineblock border_dotted ui-corner-all'));
+$conditionFormList->addRow(_('New condition'), new CDiv($conditionTable, 'objectgroup floatleft border_dotted ui-corner-all'));
 
 /*
  * Operation tab
@@ -323,7 +358,7 @@ $operationFormList = new CFormList('operationlist');
 
 if ($this->data['eventsource'] == EVENT_SOURCE_TRIGGERS || $this->data['eventsource'] == EVENT_SOURCE_INTERNAL) {
 	$operationFormList->addRow(_('Default operation step duration'), array(
-		new CNumericBox('esc_period', $this->data['action']['esc_period'], 6, 'no'),
+		new CNumericBox('esc_period', $this->data['action']['esc_period'], 6),
 		' ('._('minimum 60 seconds').')')
 	);
 }
@@ -331,7 +366,7 @@ if ($this->data['eventsource'] == EVENT_SOURCE_TRIGGERS || $this->data['eventsou
 // create operation table
 $operationsTable = new CTable(_('No operations defined.'), 'formElementTable');
 $operationsTable->attr('style', 'min-width: 600px;');
-if ($this->data['action']['eventsource'] == EVENT_SOURCE_TRIGGERS || $this->data['eventsource'] == EVENT_SOURCE_INTERNAL) {
+if ($this->data['eventsource'] == EVENT_SOURCE_TRIGGERS || $this->data['eventsource'] == EVENT_SOURCE_INTERNAL) {
 	$operationsTable->setHeader(array(_('Steps'), _('Details'), _('Start in'), _('Duration (sec)'), _('Action')));
 	$delay = count_operations_delay($this->data['action']['operations'], $this->data['action']['esc_period']);
 }
@@ -420,7 +455,7 @@ $operationFormList->addRow(_('Action operations'), new CDiv(array($operationsTab
 // create new operation table
 if (!empty($this->data['new_operation'])) {
 	$newOperationsTable = new CTable(null, 'formElementTable');
-	$newOperationsTable->addItem(new CVar('new_operation[action]', $this->data['new_operation']['action']));
+	$newOperationsTable->addItem(new CVar('new_operation[actionid]', $this->data['actionid']));
 
 	if (isset($this->data['new_operation']['id'])) {
 		$newOperationsTable->addItem(new CVar('new_operation[id]', $this->data['new_operation']['id']));
@@ -567,11 +602,8 @@ if (!empty($this->data['new_operation'])) {
 			$mediaTypeComboBox = new CComboBox('new_operation[opmessage][mediatypeid]', $this->data['new_operation']['opmessage']['mediatypeid']);
 			$mediaTypeComboBox->addItem(0, '- '._('All').' -');
 
-			$dbMediaTypes = DBfetchArray(DBselect(
-				'SELECT mt.mediatypeid,mt.description'.
-				' FROM media_type mt'.
-				whereDbNode('mt.mediatypeid')
-			));
+			$dbMediaTypes = DBfetchArray(DBselect('SELECT mt.mediatypeid,mt.description FROM media_type mt'));
+
 			order_result($dbMediaTypes, 'description');
 
 			foreach ($dbMediaTypes as $dbMediaType) {
@@ -797,17 +829,26 @@ if (!empty($this->data['new_operation'])) {
 			$groupList = new CTable();
 			$groupList->setAttribute('id', 'opGroupList');
 			$groupList->addRow(new CRow(
-				new CCol(array(
+				new CCol(
 					new CMultiSelect(array(
 						'name' => 'discoveryHostGroup',
 						'objectName' => 'hostGroup',
-						'objectOptions' => array('editable' => true)
+						'objectOptions' => array('editable' => true),
+						'popup' => array(
+							'parameters' => 'srctbl=host_groups&dstfrm='.$actionForm->getName().
+								'&dstfld1=discoveryHostGroup&srcfld1=groupid&writeonly=1&multiselect=1',
+							'width' => 450,
+							'height' => 450
+						)
 					)),
-					new CButton('add', _('Add'), 'return addDiscoveryHostGroup();', 'link_menu')
-				), null, 2),
+					null, 2
+				),
 				null,
 				'opGroupListFooter'
 			));
+			$groupList->addRow(new CCol(
+				new CButton('add', _('Add'), 'return addDiscoveryHostGroup();', 'link_menu'), null, 2
+			));
 
 			// load host groups
 			$groupIds = isset($this->data['new_operation']['opgroup'])
@@ -842,17 +883,26 @@ if (!empty($this->data['new_operation'])) {
 			$templateList = new CTable();
 			$templateList->setAttribute('id', 'opTemplateList');
 			$templateList->addRow(new CRow(
-				new CCol(array(
+				new CCol(
 					new CMultiSelect(array(
 						'name' => 'discoveryTemplates',
 						'objectName' => 'templates',
-						'objectOptions' => array('editable' => true)
+						'objectOptions' => array('editable' => true),
+						'popup' => array(
+							'parameters' => 'srctbl=templates&srcfld1=hostid&srcfld2=host&dstfrm='.$actionForm->getName().
+								'&dstfld1=discoveryTemplates&templated_hosts=1&multiselect=1&writeonly=1',
+							'width' => 450,
+							'height' => 450
+						)
 					)),
-					new CButton('add', _('Add'), 'return addDiscoveryTemplates();', 'link_menu')
-				), null, 2),
+					null, 2
+				),
 				null,
 				'opTemplateListFooter'
 			));
+			$templateList->addRow(new CCol(
+				new CButton('add', _('Add'), 'return addDiscoveryTemplates();', 'link_menu'), null, 2
+			));
 
 			// load templates
 			$templateIds = isset($this->data['new_operation']['optemplate'])
@@ -875,7 +925,7 @@ if (!empty($this->data['new_operation'])) {
 				? _('Link with templates')
 				: _('Unlink from templates');
 
-			$newOperationsTable->addRow(array($caption, new CDiv($templateList, 'objectgroup inlineblock border_dotted ui-corner-all')));
+			$newOperationsTable->addRow(array($caption, new CDiv($templateList, 'objectgroup border_dotted ui-corner-all')));
 			break;
 	}
 
@@ -892,6 +942,7 @@ if (!empty($this->data['new_operation'])) {
 		$grouped_opconditions = array();
 
 		$operationConditionsTable = new CTable(_('No conditions defined.'), 'formElementTable');
+		$operationConditionsTable->attr('id', 'operationConditionTable');
 		$operationConditionsTable->attr('style', 'min-width: 310px;');
 		$operationConditionsTable->setHeader(array(_('Label'), _('Name'), _('Action')));
 
@@ -911,9 +962,12 @@ if (!empty($this->data['new_operation'])) {
 			}
 
 			$label = num2letter($i);
+			$labelCol = new CCol($label, 'label');
+			$labelCol->setAttribute('data-conditiontype', $opcondition['conditiontype']);
+			$labelCol->setAttribute('data-formulaid', $label);
 			$operationConditionsTable->addRow(
 				array(
-					'('.$label.')',
+					$labelCol,
 					get_condition_desc($opcondition['conditiontype'], $opcondition['operator'], $opcondition['value']),
 					array(
 						new CButton('remove', _('Remove'), 'javascript: removeOperationCondition('.$i.');', 'link_menu'),
@@ -925,45 +979,21 @@ if (!empty($this->data['new_operation'])) {
 				null, 'opconditions_'.$i
 			);
 
-			$grouped_opconditions[$opcondition['conditiontype']][] = $label;
 			$i++;
 		}
 
-		if ($operationConditionsTable->itemsCount() > 1) {
-			switch ($this->data['new_operation']['evaltype']) {
-				case ACTION_EVAL_TYPE_AND:
-					$group_op = $glog_op = _('and');
-					break;
-				case ACTION_EVAL_TYPE_OR:
-					$group_op = $glog_op = _('or');
-					break;
-				default:
-					$group_op = _('or');
-					$glog_op = _('and');
-					break;
-			}
+		$calcTypeComboBox = new CComboBox('new_operation[evaltype]', $this->data['new_operation']['evaltype'], 'submit()');
+		$calcTypeComboBox->attr('id', 'operationEvaltype');
+		$calcTypeComboBox->addItem(CONDITION_EVAL_TYPE_AND_OR, _('And/Or'));
+		$calcTypeComboBox->addItem(CONDITION_EVAL_TYPE_AND, _('And'));
+		$calcTypeComboBox->addItem(CONDITION_EVAL_TYPE_OR, _('Or'));
 
-			foreach ($grouped_opconditions as $id => $condition) {
-				$grouped_opconditions[$id] = '('.implode(' '.$group_op.' ', $condition).')';
-			}
-			$grouped_opconditions = implode(' '.$glog_op.' ', $grouped_opconditions);
-
-			$calcTypeComboBox = new CComboBox('new_operation[evaltype]', $this->data['new_operation']['evaltype'], 'submit()');
-			$calcTypeComboBox->addItem(ACTION_EVAL_TYPE_AND_OR, _('AND / OR'));
-			$calcTypeComboBox->addItem(ACTION_EVAL_TYPE_AND, _('AND'));
-			$calcTypeComboBox->addItem(ACTION_EVAL_TYPE_OR, _('OR'));
-
-			$newOperationsTable->addRow(array(
+		$newOperationsTable->addRow(array(
 				_('Type of calculation'),
-				array(
-					$calcTypeComboBox,
-					new CTextBox('preview', $grouped_opconditions, ZBX_TEXTBOX_STANDARD_SIZE, 'yes')
-				)
-			));
-		}
-		else {
-			$operationConditionsTable->addItem(new CVar('new_operation[evaltype]', ACTION_EVAL_TYPE_AND_OR));
-		}
+				array($calcTypeComboBox, new CSpan('', null, 'operationConditionLabel'))
+			),
+			null, 'operationConditionRow'
+		);
 
 		if (!isset($_REQUEST['new_opcondition'])) {
 			$operationConditionsTable->addRow(new CCol(new CSubmit('new_opcondition', _('New'), null, 'link_menu')));
@@ -977,7 +1007,7 @@ if (!empty($this->data['new_operation'])) {
 
 		$allowedOpConditions = get_opconditions_by_eventsource($this->data['eventsource']);
 
-		$new_opcondition = get_request('new_opcondition', array());
+		$new_opcondition = getRequest('new_opcondition', array());
 		if (!is_array($new_opcondition)) {
 			$new_opcondition = array();
 		}
@@ -1023,16 +1053,16 @@ if (!empty($this->data['new_operation'])) {
 	}
 
 	$footer = array(
-		new CSubmit('add_operation', ($this->data['new_operation']['action'] == 'update') ? _('Update') : _('Add'), null, 'link_menu'),
+		new CSubmit('add_operation', (isset($this->data['new_operation']['id'])) ? _('Update') : _('Add'), null, 'link_menu'),
 		SPACE.SPACE,
 		new CSubmit('cancel_new_operation', _('Cancel'), null, 'link_menu')
 	);
-	$operationFormList->addRow(_('Operation details'), new CDiv(array($newOperationsTable, $footer), 'objectgroup inlineblock border_dotted ui-corner-all'));
+	$operationFormList->addRow(_('Operation details'), new CDiv(array($newOperationsTable, $footer), 'objectgroup floatleft border_dotted ui-corner-all'));
 }
 
 // append tabs to form
 $actionTabs = new CTabView();
-if (!isset($_REQUEST['form_refresh'])) {
+if (!hasRequest('form_refresh')) {
 	$actionTabs->setSelected(0);
 }
 $actionTabs->addTab('actionTab', _('Action'), $actionFormList);
@@ -1043,12 +1073,25 @@ $actionForm->addItem($actionTabs);
 // append buttons to form
 $others = array();
 if (!empty($this->data['actionid'])) {
-	$others[] = new CButton('clone', _('Clone'));
-	$others[] = new CButtonDelete(_('Delete current action?'), url_param('form').url_param('eventsource').url_param('actionid'));
+	$actionForm->addItem(makeFormFooter(
+		new CSubmit('update', _('Update')),
+		array(
+			new CButton('clone', _('Clone')),
+			new CButtonDelete(
+				_('Delete current action?'),
+				url_param('form').url_param('eventsource').url_param('actionid')
+			),
+			new CButtonCancel(url_param('actiontype'))
+		)
+	));
+}
+else {
+	$actionForm->addItem(makeFormFooter(
+		new CSubmit('add', _('Add')),
+		new CButtonCancel(url_param('actiontype'))
+	));
 }
-$others[] = new CButtonCancel(url_param('actiontype'));
 
-$actionForm->addItem(makeFormFooter(new CSubmit('save', _('Save')), $others));
 
 // append form to widget
 $actionWidget->addItem($actionForm);
