@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -50,8 +50,8 @@ else {
 	$graphWidget->addPageHeader(_('CONFIGURATION OF GRAPHS'), $createForm);
 
 	$filterForm = new CForm('get');
-	$filterForm->addItem(array(_('Group').SPACE, $this->data['pageFilter']->getGroupsCB(true)));
-	$filterForm->addItem(array(SPACE._('Host').SPACE, $this->data['pageFilter']->getHostsCB(true)));
+	$filterForm->addItem(array(_('Group').SPACE, $this->data['pageFilter']->getGroupsCB()));
+	$filterForm->addItem(array(SPACE._('Host').SPACE, $this->data['pageFilter']->getHostsCB()));
 
 	$graphWidget->addHeader(_('Graphs'), $filterForm);
 
@@ -73,12 +73,11 @@ if (!empty($this->data['parent_discoveryid'])) {
 $graphTable = new CTableInfo(!empty($this->data['parent_discoveryid']) ? _('No graph prototypes found.') : _('No graphs found.'));
 $graphTable->setHeader(array(
 	new CCheckBox('all_graphs', null, "checkAll('".$graphForm->getName()."', 'all_graphs', 'group_graphid');"),
-	$this->data['displayNodes'] ? _('Node') : null,
 	!empty($this->data['hostid']) ? null : _('Hosts'),
-	make_sorting_header(_('Name'), 'name'),
+	make_sorting_header(_('Name'), 'name', $this->data['sort'], $this->data['sortorder']),
 	_('Width'),
 	_('Height'),
-	make_sorting_header(_('Graph type'), 'graphtype')
+	make_sorting_header(_('Graph type'), 'graphtype', $this->data['sort'], $this->data['sortorder'])
 ));
 
 foreach ($this->data['graphs'] as $graph) {
@@ -112,7 +111,9 @@ foreach ($this->data['graphs'] as $graph) {
 				'&hostid='.$this->data['hostid']
 		);
 
-		$isCheckboxEnabled = false;
+		if ($graph['discoveryRule']) {
+			$isCheckboxEnabled = false;
+		}
 	}
 	elseif (!empty($graph['discoveryRule']) && empty($this->data['parent_discoveryid'])) {
 		$name[] = new CLink(
@@ -140,7 +141,6 @@ foreach ($this->data['graphs'] as $graph) {
 
 	$graphTable->addRow(array(
 		$checkBox,
-		$this->data['displayNodes'] ? $graph['nodename'] : null,
 		$hostList,
 		$name,
 		$graph['width'],
@@ -150,12 +150,13 @@ foreach ($this->data['graphs'] as $graph) {
 }
 
 // create go buttons
-$goComboBox = new CComboBox('go');
+$goComboBox = new CComboBox('action');
+
 if (!$this->data['parent_discoveryid']) {
-	$goComboBox->addItem('copy_to', _('Copy selected to ...'));
+	$goComboBox->addItem('graph.masscopyto', _('Copy selected to ...'));
 }
 
-$goOption = new CComboItem('delete', _('Delete selected'));
+$goOption = new CComboItem('graph.massdelete', _('Delete selected'));
 $goOption->setAttribute(
 	'confirm',
 	$this->data['parent_discoveryid'] ? _('Delete selected graph prototypes?') : _('Delete selected graphs?')
