@@ -20,49 +20,42 @@
 
 
 $hostInventoryWidget = new CWidget(null, 'inventory-host');
-
 $hostInventoryWidget->addPageHeader(_('HOST INVENTORY'), SPACE);
 
-$hostInventoriesForm = new CForm();
-
 /*
  * Overview tab
  */
 $overviewFormList = new CFormList();
 
 $hostSpan = new CSpan($this->data['host']['host'], 'link_menu menu-host');
-
-$hostSpan->setMenuPopup(getMenuPopupHost(
+$hostSpan->setMenuPopup(CMenuPopupHelper::getHost(
 	$this->data['host'],
 	$this->data['hostScripts'][$this->data['host']['hostid']],
 	false
 ));
 
-$hostName = $this->data['host']['maintenance_status'] == HOST_MAINTENANCE_STATUS_ON
+$hostName = ($this->data['host']['maintenance_status'] == HOST_MAINTENANCE_STATUS_ON)
 	? array($hostSpan, SPACE, new CDiv(null, 'icon-maintenance-inline'))
 	: $hostSpan;
 
 $overviewFormList->addRow(_('Host name'), $hostName);
 
-if ($this->data['host']['host'] != $this->data['host']['name']) {
+if ($this->data['host']['host'] !== $this->data['host']['name']) {
 	$overviewFormList->addRow(_('Visible name'), new CSpan($this->data['host']['name'], 'text-field'));
 }
 
-$agentInterfaceRows = array();
-$snmpInterfaceRows = array();
-$ipmiInterfaceRows = array();
-$jmxInterfaceRows = array();
+$agentInterfaceRows = $snmpInterfaceRows = $ipmiInterfaceRows = $jmxInterfaceRows = array();
 
 foreach ($this->data['host']['interfaces'] as $interface) {
-	$spanClass = $interface['main'] ? ' default_interface' : null;
+	$spanClass = $interface['main'] ? ' default_interface' : '';
 
 	switch ($interface['type']) {
 		case INTERFACE_TYPE_AGENT:
 			$agentInterfaceRows[] = new CRow(array(
 				new CDiv($interface['ip'], 'ip'.$spanClass),
 				new CDiv($interface['dns'], 'dns'.$spanClass),
-				new CDiv($interface['useip'] == 1 ? _('IP') : _('DNS'), 'useip'.$spanClass),
-				new CDiv($interface['port'], 'port'.$spanClass),
+				new CDiv(($interface['useip'] == INTERFACE_USE_IP) ? _('IP') : _('DNS'), 'useip'.$spanClass),
+				new CDiv($interface['port'], 'port'.$spanClass)
 			));
 			break;
 
@@ -70,8 +63,8 @@ foreach ($this->data['host']['interfaces'] as $interface) {
 			$snmpInterfaceRows[] = new CRow(array(
 				new CDiv($interface['ip'], 'ip'.$spanClass),
 				new CDiv($interface['dns'], 'dns'.$spanClass),
-				new CDiv($interface['useip'] == 1 ? _('IP') : _('DNS'), 'useip'.$spanClass),
-				new CDiv($interface['port'], 'port'.$spanClass),
+				new CDiv(($interface['useip'] == INTERFACE_USE_IP) ? _('IP') : _('DNS'), 'useip'.$spanClass),
+				new CDiv($interface['port'], 'port'.$spanClass)
 			));
 			break;
 
@@ -79,8 +72,8 @@ foreach ($this->data['host']['interfaces'] as $interface) {
 			$ipmiInterfaceRows[] = new CRow(array(
 				new CDiv($interface['ip'], 'ip'.$spanClass),
 				new CDiv($interface['dns'], 'dns'.$spanClass),
-				new CDiv($interface['useip'] == 1 ? _('IP') : _('DNS'), 'useip'.$spanClass),
-				new CDiv($interface['port'], 'port'.$spanClass),
+				new CDiv(($interface['useip'] == INTERFACE_USE_IP) ? _('IP') : _('DNS'), 'useip'.$spanClass),
+				new CDiv($interface['port'], 'port'.$spanClass)
 			));
 			break;
 
@@ -88,8 +81,8 @@ foreach ($this->data['host']['interfaces'] as $interface) {
 			$jmxInterfaceRows[] = new CRow(array(
 				new CDiv($interface['ip'], 'ip'.$spanClass),
 				new CDiv($interface['dns'], 'dns'.$spanClass),
-				new CDiv($interface['useip'] == 1 ? _('IP') : _('DNS'), 'useip'.$spanClass),
-				new CDiv($interface['port'], 'port'.$spanClass),
+				new CDiv(($interface['useip'] == INTERFACE_USE_IP) ? _('IP') : _('DNS'), 'useip'.$spanClass),
+				new CDiv($interface['port'], 'port'.$spanClass)
 			));
 			break;
 	}
@@ -107,16 +100,13 @@ if ($agentInterfaceRows) {
 		$agentInterfacesTable->addRow($interface);
 	}
 
-	$overviewFormList->addRow(
-		_('Agent interfaces'),
-		new CDiv($agentInterfacesTable)
-	);
+	$overviewFormList->addRow(_('Agent interfaces'), new CDiv($agentInterfacesTable));
 }
 
-
 // SNMP interface
 if ($snmpInterfaceRows) {
 	$snmpInterfacesTable = new CTable(null, 'formElementTable border_dotted objectgroup interfaces');
+
 	if ($interfaceTableHeaderSet) {
 		$snmpInterfacesTable->addClass('element-row');
 	}
@@ -130,15 +120,13 @@ if ($snmpInterfaceRows) {
 		$snmpInterfacesTable->addRow($interface);
 	}
 
-	$overviewFormList->addRow(
-		_('SNMP interfaces'),
-		new CDiv($snmpInterfacesTable)
-	);
+	$overviewFormList->addRow(_('SNMP interfaces'), new CDiv($snmpInterfacesTable));
 }
 
 // JMX interface
 if ($jmxInterfaceRows) {
 	$jmxInterfacesTable = new CTable(null, 'formElementTable border_dotted objectgroup interfaces');
+
 	if ($interfaceTableHeaderSet) {
 		$jmxInterfacesTable->addClass('element-row');
 	}
@@ -151,15 +139,13 @@ if ($jmxInterfaceRows) {
 		$jmxInterfacesTable->addRow($interface);
 	}
 
-	$overviewFormList->addRow(
-		_('JMX interfaces'),
-		new CDiv($jmxInterfacesTable)
-	);
+	$overviewFormList->addRow(_('JMX interfaces'), new CDiv($jmxInterfacesTable));
 }
 
 // IPMI interface
 if ($ipmiInterfaceRows) {
 	$ipmiInterfacesTable = new CTable(null, 'formElementTable border_dotted objectgroup interfaces');
+
 	if ($interfaceTableHeaderSet) {
 		$ipmiInterfacesTable->addClass('element-row');
 	}
@@ -173,10 +159,7 @@ if ($ipmiInterfaceRows) {
 		$ipmiInterfacesTable->addRow($interface);
 	}
 
-	$overviewFormList->addRow(
-		_('IPMI interfaces'),
-		new CDiv($ipmiInterfacesTable)
-	);
+	$overviewFormList->addRow(_('IPMI interfaces'), new CDiv($ipmiInterfacesTable));
 }
 
 // inventory (OS, Hardware, Software)
@@ -184,30 +167,51 @@ if ($this->data['host']['inventory']) {
 	if ($this->data['host']['inventory']['os']) {
 		$overviewFormList->addRow(
 			$this->data['tableTitles']['os']['title'],
-			new CSpan(zbx_str2links($this->data['host']['inventory']['os']), 'text-field')
+			array(new CDiv(new CSpan(
+				zbx_str2links($this->data['host']['inventory']['os']), 'inventory-text-field'),
+				'inventory-text-field-wrap'
+			))
 		);
 	}
 	if ($this->data['host']['inventory']['hardware']) {
 		$overviewFormList->addRow(
 			$this->data['tableTitles']['hardware']['title'],
-			new CSpan(zbx_str2links($this->data['host']['inventory']['hardware']), 'text-field')
+			array(new CDiv(new CSpan(
+				zbx_str2links($this->data['host']['inventory']['hardware']), 'inventory-text-field'),
+				'inventory-text-field-wrap'
+			))
 		);
 	}
 	if ($this->data['host']['inventory']['software']) {
 		$overviewFormList->addRow(
 			$this->data['tableTitles']['software']['title'],
-			new CSpan(zbx_str2links($this->data['host']['inventory']['software']), 'text-field')
+			array(new CDiv(new CSpan(
+				zbx_str2links($this->data['host']['inventory']['software']), 'inventory-text-field'),
+				'inventory-text-field-wrap'
+			))
 		);
 	}
 }
 
+// description
+if ($this->data['host']['description'] !== '') {
+	$overviewFormList->addRow(_('Description'),
+		array(new CDiv(new CSpan(
+			zbx_str2links($this->data['host']['description']), 'inventory-text-field'),
+			'inventory-text-field-wrap'
+		))
+	);
+}
+
 // latest data
-$latestArray = array(
+$overviewFormList->addRow(_('Monitoring'), array(
 	new CLink(_('Web'), 'httpmon.php?hostid='.$this->data['host']['hostid'].url_param('groupid')),
-	new CLink(_('Latest data'), 'latest.php?form=1&select=&show_details=1&filter_set=Filter&hostid='.
-		$this->data['host']['hostid'].url_param('groupid'), 'overview-link'),
+	new CLink(_('Latest data'),
+		'latest.php?form=1&select=&show_details=1&filter_set=Filter&hostids[]='.$this->data['host']['hostid'],
+		'overview-link'
+	),
 	new CLink(_('Triggers'),
-		'tr_status.php?show_triggers=2&ack_status=1&show_events=1&show_events=0&show_details=1'.
+		'tr_status.php?filter_set=1&show_triggers=2&ack_status=1&show_events=1&show_events=0&show_details=1'.
 		'&txt_select=&show_maintenance=1&hostid='.$this->data['host']['hostid'].url_param('groupid'), 'overview-link'),
 	new CLink(_('Events'),
 		'events.php?hostid='.$this->data['host']['hostid'].url_param('groupid').'&source='.EVENT_SOURCE_TRIGGERS,
@@ -216,9 +220,7 @@ $latestArray = array(
 	new CLink(_('Graphs'), 'charts.php?hostid='.$this->data['host']['hostid'].url_param('groupid'), 'overview-link'),
 	new CLink(_('Screens'), 'host_screen.php?hostid='.$this->data['host']['hostid'].url_param('groupid'),
 		'overview-link')
-);
-
-$overviewFormList->addRow(_('Latest data'), $latestArray);
+));
 
 // configuration
 if ($this->data['rwHost']) {
@@ -226,7 +228,7 @@ if ($this->data['rwHost']) {
 		'hosts.php?form=update&hostid='.$this->data['host']['hostid'].url_param('groupid'));
 	$applicationsLink = new CLink(_('Applications'),
 		'applications.php?hostid='.$this->data['host']['hostid'].url_param('groupid'));
-	$itemsLink = new CLink(_('Items'), 'items.php?hostid='.$this->data['host']['hostid'].url_param('groupid'));
+	$itemsLink = new CLink(_('Items'), 'items.php?filter_set=1&hostid='.$this->data['host']['hostid'].url_param('groupid'));
 	$triggersLink = new CLink(_('Triggers'), 'triggers.php?hostid='.$this->data['host']['hostid'].url_param('groupid'));
 	$graphsLink = new CLink(_('Graphs'), 'graphs.php?hostid='.$this->data['host']['hostid'].url_param('groupid'));
 	$discoveryLink = new CLink(_('Discovery'),
@@ -243,21 +245,18 @@ else {
 	$webLink = _('Web');
 }
 
-$configurationArray = array(
+$overviewFormList->addRow(_('Configuration'), array(
 	$hostLink,
-	new CSpan (array($applicationsLink, SPACE, '('.$this->data['host']['applications'].')'), 'overview-link'),
-	new CSpan (array($itemsLink, SPACE, '('.$this->data['host']['items'].')'), 'overview-link'),
-	new CSpan (array($triggersLink, SPACE, '('.$this->data['host']['triggers'].')'), 'overview-link'),
-	new CSpan (array($graphsLink, SPACE, '('.$this->data['host']['graphs'].')'), 'overview-link'),
-	new CSpan (array($discoveryLink, SPACE, '('.$this->data['host']['discoveries'].')'), 'overview-link'),
-	new CSpan (array($webLink, SPACE, '('.$this->data['host']['httpTests'].')'), 'overview-link')
-);
-
-$overviewFormList->addRow(_('Configuration'), $configurationArray);
+	new CSpan(array($applicationsLink, SPACE, '('.$this->data['host']['applications'].')'), 'overview-link'),
+	new CSpan(array($itemsLink, SPACE, '('.$this->data['host']['items'].')'), 'overview-link'),
+	new CSpan(array($triggersLink, SPACE, '('.$this->data['host']['triggers'].')'), 'overview-link'),
+	new CSpan(array($graphsLink, SPACE, '('.$this->data['host']['graphs'].')'), 'overview-link'),
+	new CSpan(array($discoveryLink, SPACE, '('.$this->data['host']['discoveries'].')'), 'overview-link'),
+	new CSpan(array($webLink, SPACE, '('.$this->data['host']['httpTests'].')'), 'overview-link')
+));
 
 $hostInventoriesTab = new CTabView(array('remember' => true));
 $hostInventoriesTab->setSelected(0);
-
 $hostInventoriesTab->addTab('overviewTab', _('Overview'), $overviewFormList);
 
 /*
@@ -271,8 +270,9 @@ if ($this->data['host']['inventory']) {
 		if (!zbx_empty($value)) {
 			$detailsFormList->addRow(
 				$this->data['tableTitles'][$key]['title'],
-				new CSpan(zbx_str2links($value),
-				'text-field'));
+				array(new CDiv(new CSpan(zbx_str2links($value), 'inventory-text-field'), 'inventory-text-field-wrap'))
+			);
+
 			$inventoryValues = true;
 		}
 	}
@@ -285,11 +285,9 @@ if (!$inventoryValues) {
 $hostInventoriesTab->addTab('detailsTab', _('Details'), $detailsFormList);
 
 // append tabs and form
+$hostInventoriesForm = new CForm();
 $hostInventoriesForm->addItem($hostInventoriesTab);
-$hostInventoriesForm->addItem(makeFormFooter(
-	null,
-	new CButtonCancel(url_param('groupid'))
-));
+$hostInventoriesForm->addItem(makeFormFooter(null, new CButtonCancel(url_param('groupid'))));
 $hostInventoryWidget->addItem($hostInventoriesForm);
 
 return $hostInventoryWidget;
