@@ -1,7 +1,7 @@
 // JavaScript Document
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -170,14 +170,15 @@ calendar.prototype = {
 				var val = null;
 				var result = false;
 
-				if (this.timeobjects[0].tagName.toLowerCase() == 'input') {
+				if (this.timeobjects[0].tagName.toLowerCase() === 'input') {
 					val = this.timeobjects[0].value;
 				}
 				else {
 					val = (IE) ? this.timeobjects[0].innerText : this.timeobjects[0].textContent;
 				}
 
-				if (jQuery(this.timeobjects[0]).attr('data-timestamp') > 0) {
+				// allow unix timestamp 0 (year 1970)
+				if (jQuery(this.timeobjects[0]).attr('data-timestamp') >= 0) {
 					this.setNow(jQuery(this.timeobjects[0]).attr('data-timestamp'));
 				}
 				else {
@@ -203,7 +204,7 @@ calendar.prototype = {
 					}
 				}
 
-				if(!result) {
+				if (!result) {
 					return false;
 				}
 				break;
@@ -292,81 +293,37 @@ calendar.prototype = {
 	setDateToOuterObj: function() {
 		switch (this.timeobjects.length) {
 			case 1:
-				var timestring = this.sdt.getDate() + '.' + (this.sdt.getMonth() + 1) + '.' + this.sdt.getFullYear() + ' ' + this.sdt.getHours() + ':' + this.sdt.getMinutes();
-				if (this.timeobjects[0].tagName.toLowerCase() == 'input') {
-					this.timeobjects[0].value = timestring;
+				// uses default format
+				var date = this.sdt.format();
+
+				if (this.timeobjects[0].tagName.toLowerCase() === 'input') {
+					this.timeobjects[0].value = date;
 				}
 				else {
 					if (IE) {
-						this.timeobjects[0].innerText =  timestring;
+						this.timeobjects[0].innerText =  date;
 					}
 					else {
-						this.timeobjects[0].textContent = timestring;
+						this.timeobjects[0].textContent = date;
 					}
 				}
 				break;
+
 			case 3:
 			case 5:
-				// day
-				if (this.timeobjects[0].tagName.toLowerCase() == 'input') {
-					this.timeobjects[0].value = this.sdt.getDate();
-				}
-				else {
-					if (IE) {
-						this.timeobjects[0].innerText = this.sdt.getDate();
-					}
-					else {
-						this.timeobjects[0].textContent = this.sdt.getDate();
-					}
-				}
-				// month
-				if (this.timeobjects[1].tagName.toLowerCase() == 'input') {
-					this.timeobjects[1].value = this.sdt.getMonth() + 1;
-				}
-				else {
-					if(IE) {
-						this.timeobjects[1].innerText = this.sdt.getMonth() + 1;
-					}
-					else {
-						this.timeobjects[1].textContent = this.sdt.getMonth() + 1;
-					}
-				}
-				// year
-				if (this.timeobjects[2].tagName.toLowerCase() == 'input') {
-					this.timeobjects[2].value = this.sdt.getFullYear();
-				}
-				else {
-					if (IE) {
-						this.timeobjects[2].innerText = this.sdt.getFullYear();
-					}
-					else {
-						this.timeobjects[2].textContent = this.sdt.getFullYear();
-					}
-				}
+				// custom date format for input fields
+				var date = this.sdt.format('d m Y H i').split(' ');
 
-				if (this.timeobjects.length > 4) {
-					// hour
-					if (this.timeobjects[3].tagName.toLowerCase() == 'input') {
-						this.timeobjects[3].value = this.sdt.getHours();
+				for (var i = 0; i < this.timeobjects.length; i++) {
+					if (this.timeobjects[i].tagName.toLowerCase() === 'input') {
+						this.timeobjects[i].value = date[i];
 					}
 					else {
 						if (IE) {
-							this.timeobjects[3].innerText = this.sdt.getHours();
+							this.timeobjects[i].innerText = date[i];
 						}
 						else {
-							this.timeobjects[3].textContent = this.sdt.getHours();
-						}
-					}
-					// minute
-					if (this.timeobjects[4].tagName.toLowerCase() == 'input') {
-						this.timeobjects[4].value = this.sdt.getMinutes();
-					}
-					else {
-						if (IE) {
-							this.timeobjects[4].innerText = this.sdt.getMinutes();
-						}
-						else {
-							this.timeobjects[4].textContent = this.sdt.getMinutes();
+							this.timeobjects[i].textContent = date[i];
 						}
 					}
 				}
@@ -439,9 +396,16 @@ calendar.prototype = {
 
 	monthup: function() {
 		this.month++;
+
 		if (this.month > 11) {
-			this.month = 0;
-			this.yearup();
+			// prevent months from running in loop in year 2038
+			if (this.year < 2038) {
+				this.month = 0;
+				this.yearup();
+			}
+			else {
+				this.month = 11;
+			}
 		}
 		else {
 			this.syncCDT();
@@ -451,9 +415,16 @@ calendar.prototype = {
 
 	monthdown: function() {
 		this.month--;
+
 		if (this.month < 0) {
-			this.month = 11;
-			this.yeardown();
+			// prevent months from running in loop in year 1970
+			if (this.year > 1970) {
+				this.month = 11;
+				this.yeardown();
+			}
+			else {
+				this.month = 0;
+			}
 		}
 		else {
 			this.syncCDT();
@@ -513,7 +484,9 @@ calendar.prototype = {
 
 	setCDate: function() {
 		this.clndr_minute.value = this.minute;
+		this.clndr_minute.onchange();
 		this.clndr_hour.value = this.hour;
+		this.clndr_hour.onchange();
 		if (IE) {
 			this.clndr_month.innerHTML = this.monthname[this.month].toString();
 			this.clndr_year.innerHTML = this.year;
@@ -636,7 +609,7 @@ calendar.prototype = {
 		td.appendChild(this.clndr_yeardown);
 
 		this.clndr_yeardown.className = 'clndr_left_arrow';
-		this.clndr_yeardown.appendChild(document.createTextNode('«'));
+		this.clndr_yeardown.appendChild(document.createTextNode(String.fromCharCode(0x00AB)));
 
 		var td = document.createElement('td');
 		tr.appendChild(td);
@@ -655,7 +628,7 @@ calendar.prototype = {
 		td.appendChild(this.clndr_yearup);
 
 		this.clndr_yearup.className = 'clndr_right_arrow';
-		this.clndr_yearup.appendChild(document.createTextNode('»'));
+		this.clndr_yearup.appendChild(document.createTextNode(String.fromCharCode(0x00BB)));
 
 		// month
 		var tr = document.createElement('tr');
@@ -668,7 +641,7 @@ calendar.prototype = {
 		td.appendChild(this.clndr_monthdown);
 
 		this.clndr_monthdown.className = 'clndr_left_arrow';
-		this.clndr_monthdown.appendChild(document.createTextNode('«'));
+		this.clndr_monthdown.appendChild(document.createTextNode(String.fromCharCode(0x00AB)));
 
 		var td = document.createElement('td');
 		tr.appendChild(td);
@@ -689,7 +662,7 @@ calendar.prototype = {
 
 		this.clndr_monthup.className = 'clndr_right_arrow';
 
-		this.clndr_monthup.appendChild(document.createTextNode('»'));
+		this.clndr_monthup.appendChild(document.createTextNode(String.fromCharCode(0x00BB)));
 
 		// days heading
 		var table = document.createElement('table');
@@ -756,6 +729,7 @@ calendar.prototype = {
 		this.clndr_hour.setAttribute('name', 'hour');
 		this.clndr_hour.setAttribute('value', 'hh');
 		this.clndr_hour.setAttribute('maxlength', '2');
+		this.clndr_hour.onchange = function() { validateDatePartBox(this, 0, 23, 2); };
 		this.clndr_hour.className = 'calendar_textbox';
 
 		// minutes
@@ -764,6 +738,7 @@ calendar.prototype = {
 		this.clndr_minute.setAttribute('name', 'minute');
 		this.clndr_minute.setAttribute('value', 'mm');
 		this.clndr_minute.setAttribute('maxlength', '2');
+		this.clndr_minute.onchange = function() { validateDatePartBox(this, 0, 59, 2); };
 		this.clndr_minute.className = 'calendar_textbox';
 
 		// column 1
