@@ -52,7 +52,9 @@ CDate.prototype = {
 
 	/**
 	* Formats date according given format. Uses server timezone.
-	* Supported formats: 'd M Y H:i', 'j. M Y G:i', 'Y/m/d H:i', 'M jS, Y h:i A', 'Y M d H:i', 'd.m.Y H:i'
+	* Supported formats:	'd M Y H:i', 'j. M Y G:i', 'Y/m/d H:i', 'Y-m-d H:i', 'Y-m-d H:i:s', 'Y-m-d', 'H:i:s', 'H:i',
+	*						'M jS, Y h:i A', 'Y M d H:i', 'd.m.Y H:i' and 'd m Y H i'
+	*						Format 'd m Y H i' is also accepted but used internally for date input fields.
 	*
 	* @param format PHP style date format limited to supported formats
 	*
@@ -65,7 +67,8 @@ CDate.prototype = {
 			mnth = this.getMonth(),
 			yr = this.getFullYear(),
 			hrs = this.getHours(),
-			mnts = this.getMinutes();
+			mnts = this.getMinutes(),
+			sec = this.getSeconds();
 
 		/**
 		 * Transform datetime parts to two digits e.g., 2 becomes 02
@@ -101,6 +104,14 @@ CDate.prototype = {
 				return dt + '. ' + shortMn[mnth] + ' ' + yr + ' ' + hrs + ':' + appZr(mnts);
 			case 'Y/m/d H:i':
 				return yr + '/' + appZr(mnth + 1) + '/' + appZr(dt) + ' ' + appZr(hrs) + ':' + appZr(mnts);
+			case 'Y-m-d H:i':
+				return yr + '-' + appZr(mnth + 1) + '-' + appZr(dt) + ' ' + appZr(hrs) + ':' + appZr(mnts);
+			case 'Y-m-d':
+				return yr + '-' + appZr(mnth + 1) + '-' + appZr(dt);
+			case 'H:i:s':
+				return  appZr(hrs) + ':' + appZr(mnts) + ':' + appZr(sec);
+			case 'H:i':
+				return  appZr(hrs) + ':' + appZr(mnts);
 			case 'M jS, Y h:i A':
 				var ampm = (hrs < 12) ? 'AM' : 'PM';
 				hrs = appZr((hrs + 11) % 12 + 1);
@@ -109,9 +120,16 @@ CDate.prototype = {
 				return  yr + ' ' + shortMn[mnth] + ' ' +appZr(dt) + ' ' + appZr(hrs) + ':' + appZr(mnts);
 			case 'd.m.Y H:i':
 				return appZr(dt) + '.' + appZr(mnth + 1) + '.' + yr + ' ' + appZr(hrs) + ':' + appZr(mnts);
+			case 'd. m. Y H:i':
+				return appZr(dt) + '. ' + appZr(mnth + 1) + '. ' + yr + ' ' + appZr(hrs) + ':' + appZr(mnts);
+			// date format used for date input fields
+			case 'd m Y H i':
+				return appZr(dt) + ' ' + appZr(mnth + 1) + ' ' + yr + ' ' + appZr(hrs) + ' ' + appZr(mnts);
+			default:
+				// defaults to Y-m-d H:i:s
+				return yr + '-' + appZr(mnth + 1) + '-' + appZr(dt) + ' ' + appZr(hrs) + ':' + appZr(mnts) +
+					':' + appZr(sec);
 		}
-
-		return false;
 	},
 
 	getZBXDate: function() {
@@ -274,23 +292,5 @@ CDate.prototype = {
 		this.calcTZdiff(arg);
 		this.serverDate.setTime(arg - this.tzDiff * 1000);
 		this.clientDate.setTime(arg);
-	},
-
-	debug: function(fnc_name, id) {
-		if (this.debug_status) {
-			var str = 'CDate.' + fnc_name;
-			if (typeof(id) != 'undefined') {
-				str += ' :' + id;
-			}
-			if (this.debug_prev == str) {
-				return true;
-			}
-
-			this.debug_info += str;
-			if (this.debug_status == 2) {
-				SDI(str);
-			}
-			this.debug_prev = str;
-		}
 	}
 }
