@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,21 +18,20 @@
 **/
 
 
-var PMasters = [];
+var PMasters = {};
+
 function initPMaster(pmid, args) {
-	if (typeof(PMasters[pmid]) == 'undefined') {
+	if (typeof PMasters[pmid] === 'undefined') {
 		PMasters[pmid] = new CPMaster(pmid, args);
 	}
-	return pmid;
 }
 
-var CPMaster = Class.create(CDebug,{
+var CPMaster = Class.create({
 	pmasterid:	0,	// pmasters reference id
 	dolls:		[],	// list of updated objects
 
-	initialize: function($super, pmid, obj4upd) {
+	initialize: function(pmid, obj4upd) {
 		this.pmasterid = pmid;
-		$super('CPMaster[' + pmid + ']');
 
 		var doll = [];
 		for (var id in obj4upd) {
@@ -68,8 +67,6 @@ var CPMaster = Class.create(CDebug,{
 	},
 
 	addDoll: function(domid, frequency, url, counter, darken, params) {
-		this.debug('addDoll', domid);
-
 		var obj = document.getElementById(domid);
 		if (typeof(obj) == 'undefined') {
 			return false;
@@ -97,8 +94,6 @@ var CPMaster = Class.create(CDebug,{
 	},
 
 	rmvDoll: function(domid) {
-		this.debug('rmvDoll', domid);
-
 		if (typeof(this.dolls[domid]) != 'undefined' && !is_null(this.dolls[domid])) {
 			this.dolls[domid].pexec.stop();
 			this.dolls[domid].pexec = null;
@@ -114,8 +109,6 @@ var CPMaster = Class.create(CDebug,{
 	},
 
 	startAllDolls: function() {
-		this.debug('startAllDolls');
-
 		for (var domid in this.dolls) {
 			if (typeof(this.dolls[domid]) != 'undefined' && !is_null(this.dolls[domid])) {
 				this.dolls[domid].startDoll();
@@ -124,8 +117,6 @@ var CPMaster = Class.create(CDebug,{
 	},
 
 	stopAllDolls: function() {
-		this.debug('stopAllDolls');
-
 		for (var domid in this.dolls) {
 			if (typeof(this.dolls[domid]) != 'undefined' && !is_null(this.dolls[domid])) {
 				this.dolls[domid].stopDoll();
@@ -134,8 +125,6 @@ var CPMaster = Class.create(CDebug,{
 	},
 
 	clear: function() {
-		this.debug('clear');
-
 		for (var domid in this.dolls) {
 			this.rmvDoll(domid);
 		}
@@ -143,7 +132,7 @@ var CPMaster = Class.create(CDebug,{
 	}
 });
 
-var CDoll = Class.create(CDebug,{
+var CDoll = Class.create({
 	_pmasterid:		0,		// PMasters id to which doll belongs
 	_domobj:		null,	// DOM obj for update
 	_domid:			null,	// DOM obj id
@@ -159,10 +148,8 @@ var CDoll = Class.create(CDebug,{
 	pexec:			null,	// PeriodicalExecuter object
 	min_freq:		5,		// seconds
 
-	initialize: function($super, obj4update) {
+	initialize: function(obj4update) {
 		this._domid = obj4update.domid;
-		$super('CDoll[' + this._domid + ']');
-
 		this._domobj = jQuery('#'+this._domid);
 		this.url(obj4update.url);
 		this.frequency(obj4update.frequency);
@@ -174,8 +161,6 @@ var CDoll = Class.create(CDebug,{
 	},
 
 	startDoll: function() {
-		this.debug('startDoll');
-
 		if (is_null(this.pexec)) {
 			this.lastupdate(0);
 			this.pexec = new PeriodicalExecuter(this.check4Update.bind(this), this._frequency);
@@ -184,7 +169,6 @@ var CDoll = Class.create(CDebug,{
 	},
 
 	restartDoll: function() {
-		this.debug('restartDoll');
 		if (!is_null(this.pexec)) {
 			this.pexec.stop();
 
@@ -201,8 +185,6 @@ var CDoll = Class.create(CDebug,{
 	},
 
 	stopDoll: function() {
-		this.debug('stopDoll');
-
 		if (!is_null(this.pexec)) {
 			this.pexec.stop();
 			try {
@@ -294,7 +276,6 @@ var CDoll = Class.create(CDebug,{
 	},
 
 	check4Update: function() {
-		this.debug('check4Update');
 		var now = parseInt(new Date().getTime() / 1000);
 
 		if (this._ready && ((this._lastupdate + this._frequency) < (now + this.min_freq))) {
@@ -304,7 +285,6 @@ var CDoll = Class.create(CDebug,{
 	},
 
 	update: function() {
-		this.debug('update');
 		this._ready = false;
 
 		if (this._counter == 1) {
@@ -318,6 +298,9 @@ var CDoll = Class.create(CDebug,{
 		url.setArgument('upd_counter', this.counter());
 		url.setArgument('pmasterid', this.pmasterid());
 
+		jQuery(window).off('resize');
+		jQuery(document).off('mousemove');
+
 		new Ajax.Request(url.getUrl(), {
 				'method': 'post',
 				'parameters': this._params,
@@ -330,7 +313,6 @@ var CDoll = Class.create(CDebug,{
 	},
 
 	onSuccess: function(resp) {
-		this.debug('onSuccess');
 		this.rmwDarken();
 		this.updateSortable();
 
@@ -348,15 +330,12 @@ var CDoll = Class.create(CDebug,{
 	},
 
 	onFailure: function(resp) {
-		this.debug('onFailure');
 		this.rmwDarken();
 		this._ready = true;
 		this.notify(false, this._pmasterid, this._domid, this._lastupdate, this.counter());
 	},
 
 	setDarken: function() {
-		this.debug('setDarken');
-
 		if (is_null(this._domobj)) {
 			return false;
 		}
@@ -381,8 +360,6 @@ var CDoll = Class.create(CDebug,{
 	},
 
 	rmwDarken: function() {
-		this.debug('rmvDarken');
-
 		if (!is_null(this._domdark)) {
 			this._domdark.style.cursor = 'auto';
 
@@ -392,84 +369,38 @@ var CDoll = Class.create(CDebug,{
 	},
 
 	updateSortable: function() {
-		if (empty(jQuery('.column'))) {
-			return false;
-		}
+		var columnObj = jQuery('.column');
 
-		jQuery('.column')
-			.sortable({
-				connectWith: '.column',
-				handle: 'div.header',
-				forcePlaceholderSize: true,
-				placeholder: 'widget ui-corner-all ui-sortable-placeholder',
-				opacity: '0.8',
-				update: function() { jQuery('.column').portletState('save', {'name': 'dashboard'}); }
-			})
-			.portletState('load', {'name': 'dashboard'})
-			.children('div')
-			.children('div.header')
-			.addClass('move');
+		if (columnObj.length > 0) {
+			columnObj
+				.sortable({
+					connectWith: '.column',
+					handle: 'div.header',
+					forcePlaceholderSize: true,
+					placeholder: 'widget ui-corner-all ui-sortable-placeholder',
+					opacity: '0.8',
+					update: function(e, ui) {
+						// prevent duplicate save requests when moving a widget from one column to another
+						if (!ui.sender) {
+							var widgetPositions = {};
+
+							jQuery('.column').each(function(colNum, column) {
+								widgetPositions[colNum] = {};
+
+								jQuery('.widget', column).each(function(rowNum, widget) {
+									widgetPositions[colNum][rowNum] = widget.id;
+								});
+							});
+
+							sendAjaxData({
+								data: {widgetSort: Object.toJSON(widgetPositions)}
+							});
+						}
+					}
+				})
+				.children('div')
+				.children('div.header')
+				.addClass('move');
+		}
 	}
 });
-
-(function($) {
-	var methods = {
-		init: function(options) {},
-		save: function(method, options) {
-			var settings = {
-				'name': 'sortableOrder',
-				'sortable': '.widget'
-			};
-
-			$.extend(settings, options);
-
-			var positions = {};
-			this.each(function(colNum, column) {
-				positions[colNum] = {};
-				$(column).find(settings.sortable).each(function(rowNum, widget) {
-					positions[colNum][rowNum] = widget.id;
-				});
-			});
-
-			var strPos = Object.toJSON(positions);
-			$.cookie(settings.name, strPos, {expires: 365});
-
-			return this;
-		},
-		load: function(method, options) {
-			var settings = {
-				'name': 'sortableOrder',
-				'sortable': '.widget'
-			};
-
-			$.extend(settings, options);
-
-			var strPos = $.cookie(settings.name);
-			var positions = $.parseJSON(strPos);
-
-			this.each(function(colNum, column) {
-				if (!isset(colNum, positions)) {
-					return;
-				}
-
-				for (var rowNum in positions[colNum]) {
-					if (empty(positions[colNum][rowNum])) {
-						continue;
-					}
-					$('#' + positions[colNum][rowNum]).appendTo(column);
-				}
-			});
-
-			return this;
-		}
-	};
-
-	$.fn.portletState = function(method, options) {
-		if (isset(method, methods)) {
-			return methods[method].apply(this, arguments);
-		}
-		else {
-			$.error('Method ' +  method + ' does not exist on jQuery.portletState');
-		}
-	}
-})(jQuery);
