@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -273,6 +273,14 @@ var timeControl = {
 			location.href = url.getUrl();
 		}
 		else {
+			// calculate new gradation
+			this.scrollbar.px2sec =
+				(this.timeline.endtime() - this.timeline.starttime()) / this.scrollbar.size.scrollline;
+
+			// scrollbar
+			this.scrollbar.setBarPosition();
+			this.scrollbar.setGhostByBar();
+
 			flickerfreeScreen.refreshAll(period, date.getZBXDate(), this.timeline.isNow());
 		}
 	},
@@ -308,7 +316,7 @@ var timeControl = {
 };
 
 // timeline control
-var CTimeLine = Class.create(CDebug, {
+var CTimeLine = Class.create({
 
 	_starttime:	null,	// timeline start time (left, past)
 	_endtime:	null,	// timeline end time (right, now)
@@ -319,7 +327,7 @@ var CTimeLine = Class.create(CDebug, {
 	minperiod:	3600,	// minimal allowed period
 	maxperiod:	null,	// max period in seconds
 
-	initialize: function($super, period, starttime, usertime, endtime, maximumPeriod, isNow) {
+	initialize: function(period, starttime, usertime, endtime, maximumPeriod, isNow) {
 		if ((endtime - starttime) < (3 * this.minperiod)) {
 			starttime = endtime - (3 * this.minperiod);
 		}
@@ -417,7 +425,7 @@ var CTimeLine = Class.create(CDebug, {
 });
 
 // graph scrolling
-var CScrollBar = Class.create(CDebug, {
+var CScrollBar = Class.create({
 
 	ghostBox:		null, // ghost box object
 	clndrLeft:		null, // calendar object left
@@ -475,7 +483,7 @@ var CScrollBar = Class.create(CDebug, {
 	disabled:		1,		// activates/disables scrollbars
 	maxperiod:		null,	// max period in seconds
 
-	initialize: function($super, width, fixedperiod, maximalPeriod) {
+	initialize: function(width, fixedperiod, maximalPeriod) {
 		try {
 			this.fixedperiod = (fixedperiod == 1) ? 1 : 0;
 			this.maxperiod = maximalPeriod;
@@ -553,8 +561,6 @@ var CScrollBar = Class.create(CDebug, {
 			return false;
 		}
 
-		deselectAll();
-
 		var period = false;
 		if (empty(left)) {
 			period = timeControl.timeline.period();
@@ -592,8 +598,6 @@ var CScrollBar = Class.create(CDebug, {
 			return false;
 		}
 
-		deselectAll();
-
 		var period = false;
 		if (typeof(right) == 'undefined') {
 			period = timeControl.timeline.period();
@@ -966,15 +970,14 @@ var CScrollBar = Class.create(CDebug, {
 		this.fixedperiod = (this.fixedperiod == 1) ? 0 : 1;
 
 		// sending fixed/dynamic setting to server to save in a profile
-		var params = {
-			favobj: 'timelinefixedperiod',
-			favid: this.fixedperiod
-		};
-		send_params(params);
+		sendAjaxData({
+			data: {
+				favobj: 'timelinefixedperiod',
+				favid: this.fixedperiod
+			}
+		});
 
-		this.dom.period_state.innerHTML = (this.fixedperiod)
-			? locale['S_FIXED_SMALL']
-			: locale['S_DYNAMIC_SMALL'];
+		this.dom.period_state.innerHTML = this.fixedperiod ? locale['S_FIXED_SMALL'] : locale['S_DYNAMIC_SMALL'];
 	},
 
 	getTZOffset: function(time) {
@@ -1092,16 +1095,6 @@ var CScrollBar = Class.create(CDebug, {
 		};
 	},
 
-	deselectall: function() {
-		if (IE) {
-			document.selection.empty();
-		}
-		else {
-			var sel = window.getSelection();
-			sel.removeAllRanges();
-		}
-	},
-
 	//----------------------------------------------------------------
 	//-------- SCROLL CREATION ---------------------------------------
 	//----------------------------------------------------------------
@@ -1471,7 +1464,7 @@ var CScrollBar = Class.create(CDebug, {
 	}
 });
 
-var CGhostBox = Class.create(CDebug, {
+var CGhostBox = Class.create({
 
 	box:		null, // resized dom object
 	sideToMove:	null, // 0 - left side, 1 - right side
@@ -1491,10 +1484,9 @@ var CGhostBox = Class.create(CDebug, {
 		rightSide:	null
 	},
 
-	initialize: function($super, id) {
-		$super('CGhostBox[' + id + ']');
-
+	initialize: function(id) {
 		this.box = $(id);
+
 		if (is_null(this.box)) {
 			throw('Cannot initialize GhostBox with given object id.');
 		}
@@ -1573,7 +1565,7 @@ function sbox_init(id) {
 	return ZBX_SBOX[id];
 }
 
-var sbox = Class.create(CDebug, {
+var sbox = Class.create({
 
 	sbox_id:			'',		// id to create references in array to self
 	mouse_event:		{},		// json object wheres defined needed event params
@@ -1592,7 +1584,7 @@ var sbox = Class.create(CDebug, {
 	is_active:			false,	// flag show is sbox is selected, must be unique among all
 	is_activeIE:		false,
 
-	initialize: function($super, id) {
+	initialize: function(id) {
 		var tc = timeControl.objectList[id],
 			shiftL = parseInt(tc.objDims.shiftXleft),
 			shiftR = parseInt(tc.objDims.shiftXright),
@@ -1623,11 +1615,11 @@ var sbox = Class.create(CDebug, {
 		jQuery(this.grphobj).off();
 		jQuery(this.dom_obj).off();
 
-		if (IE) {
+		if (IE8 || IE9 || IE10) {
 			jQuery(this.grphobj).mousedown(jQuery.proxy(this.mouseDown, this));
 			jQuery(this.grphobj).mousemove(jQuery.proxy(this.mouseMove, this));
-			jQuery('#flickerfreescreen_' + this.sbox_id + ' a').click(function() {
-				ZBX_SBOX[this.sbox_id].ieMouseClick();
+			jQuery(this.grphobj).click(function() {
+				ZBX_SBOX[obj.sbox_id].ieMouseClick();
 			});
 		}
 		else {
@@ -1649,7 +1641,6 @@ var sbox = Class.create(CDebug, {
 		}
 
 		this.optimizeEvent(e);
-		deselectAll();
 
 		var posxy = getPosition(this.dom_obj);
 		if (this.mouse_event.top < posxy.top || (this.mouse_event.top > (this.dom_obj.offsetHeight + posxy.top))) {
@@ -1660,7 +1651,6 @@ var sbox = Class.create(CDebug, {
 
 		if (!this.is_active) {
 			this.optimizeEvent(e);
-			deselectAll();
 			this.createBox();
 
 			this.is_active = true;
@@ -1720,7 +1710,6 @@ var sbox = Class.create(CDebug, {
 
 		if (this.is_activeIE) {
 			this.optimizeEvent(e);
-			deselectAll();
 			this.mouseUp(e);
 			this.is_activeIE = false;
 
@@ -1735,7 +1724,6 @@ var sbox = Class.create(CDebug, {
 		}
 
 		this.optimizeEvent(e);
-		deselectAll();
 
 		var posxy = getPosition(this.dom_obj);
 		if (this.mouse_event.top < posxy.top || (this.mouse_event.top > (this.dom_obj.offsetHeight + posxy.top))) {
