@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ $fields = array(
 
 check_fields($fields);
 
-$config = get_request('config', CProfile::get('web.queue.config', 0));
+$config = getRequest('config', CProfile::get('web.queue.config', 0));
 CProfile::update('web.queue.config', $config, PROFILE_TYPE_INT);
 
 // fetch data
@@ -188,17 +188,44 @@ elseif ($config == QUEUE_DETAILS) {
 	$queueData = zbx_toHash($queueData, 'itemid');
 
 	$items = API::Item()->get(array(
-		'output' => array('itemid', 'name', 'key_'),
+		'output' => array('itemid', 'hostid', 'name', 'key_'),
 		'selectHosts' => array('name'),
 		'itemids' => array_keys($queueData),
 		'webitems' => true,
 		'preservekeys' => true
 	));
 
+	$items = CMacrosResolverHelper::resolveItemNames($items);
+
+	// get hosts for queue items
+	$hostIds = zbx_objectValues($items, 'hostid');
+	$hostIds = array_keys(array_flip($hostIds));
+
+	$hosts = API::Host()->get(array(
+		'output' => array('hostid', 'proxy_hostid'),
+		'hostids' => $hostIds,
+		'preservekeys' => true
+	));
+
+	// get proxies for those hosts
+	$proxyHostIds = array();
+	foreach ($hosts as $host) {
+		if ($host['proxy_hostid']) {
+			$proxyHostIds[$host['proxy_hostid']] = $host['proxy_hostid'];
+		}
+	}
+
+	if ($proxyHostIds) {
+		$proxies = API::Proxy()->get(array(
+			'proxyids' => $proxyHostIds,
+			'output' => array('proxyid', 'host'),
+			'preservekeys' => true
+		));
+	}
+
 	$table->setHeader(array(
 		_('Scheduled check'),
 		_('Delayed by'),
-		is_show_all_nodes() ? _('Node') : null,
 		_('Host'),
 		_('Name')
 	));
@@ -219,11 +246,12 @@ elseif ($config == QUEUE_DETAILS) {
 		$host = reset($item['hosts']);
 
 		$table->addRow(array(
-			zbx_date2str(QUEUE_NODES_DATE_FORMAT, $itemData['nextcheck']),
+			zbx_date2str(DATE_TIME_FORMAT_SECONDS, $itemData['nextcheck']),
 			zbx_date2age($itemData['nextcheck']),
-			get_node_name_by_elid($item['itemid']),
-			$host['name'],
-			itemName($item)
+			(isset($proxies[$hosts[$item['hostid']]['proxy_hostid']]))
+				? $proxies[$hosts[$item['hostid']]['proxy_hostid']]['host'].NAME_DELIMITER.$host['name']
+				: $host['name'],
+			$item['name_expanded']
 		));
 	}
 }
