@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -45,14 +45,13 @@ $fields = array(
 	'step' =>		array(T_ZBX_INT, O_OPT, P_SYS,	BETWEEN(0, 65535), null),
 	'period' =>		array(T_ZBX_INT, O_OPT, P_SYS,	null,		null),
 	'stime' =>		array(T_ZBX_STR, O_OPT, P_SYS,	null,		null),
-	'reset' =>		array(T_ZBX_STR, O_OPT, P_SYS,	IN("'reset'"), null),
+	'reset' =>		array(T_ZBX_STR, O_OPT, P_SYS,	IN('"reset"'), null),
 	'fullscreen' =>	array(T_ZBX_INT, O_OPT, P_SYS,	IN('0,1'), null),
 	// ajax
+	'filterState' => array(T_ZBX_INT, O_OPT, P_ACT,	null,		null),
 	'favobj' =>		array(T_ZBX_STR, O_OPT, P_ACT,	null,		null),
-	'favref' =>		array(T_ZBX_STR, O_OPT, P_ACT,	NOT_EMPTY,	null),
 	'favid' =>		array(T_ZBX_INT, O_OPT, P_ACT,	null,		null),
-	'favaction' =>	array(T_ZBX_STR, O_OPT, P_ACT,	IN("'add','remove','flop'"), null),
-	'favstate' =>	array(T_ZBX_INT, O_OPT, P_ACT,	NOT_EMPTY,	null)
+	'favaction' =>	array(T_ZBX_STR, O_OPT, P_ACT,	IN('"add","remove"'), null)
 );
 check_fields($fields);
 
@@ -61,8 +60,8 @@ check_fields($fields);
  */
 // validate group IDs
 $validateGroupIds = array_filter(array(
-	get_request('groupid'),
-	get_request('tr_groupid')
+	getRequest('groupid'),
+	getRequest('tr_groupid')
 ));
 if ($validateGroupIds && !API::HostGroup()->isReadable($validateGroupIds)) {
 	access_deny();
@@ -70,14 +69,14 @@ if ($validateGroupIds && !API::HostGroup()->isReadable($validateGroupIds)) {
 
 // validate host IDs
 $validateHostIds = array_filter(array(
-	get_request('hostid'),
-	get_request('tr_hostid')
+	getRequest('hostid'),
+	getRequest('tr_hostid')
 ));
 if ($validateHostIds && !API::Host()->isReadable($validateHostIds)) {
 	access_deny();
 }
 
-if (get_request('elementid')) {
+if (getRequest('elementid')) {
 	$screens = API::Screen()->get(array(
 		'screenids' => array($_REQUEST['elementid']),
 		'output' => array('screenid')
@@ -91,24 +90,25 @@ if (get_request('elementid')) {
 /*
  * Filter
  */
-if (isset($_REQUEST['favobj'])) {
-	if ($_REQUEST['favobj'] == 'filter') {
-		CProfile::update('web.screens.filter.state', $_REQUEST['favstate'], PROFILE_TYPE_INT);
-	}
+if (hasRequest('filterState')) {
+	CProfile::update('web.screens.filter.state', getRequest('filterState'), PROFILE_TYPE_INT);
+}
 
-	if ($_REQUEST['favobj'] == 'timeline') {
-		if (isset($_REQUEST['elementid']) && isset($_REQUEST['period'])) {
-			navigation_bar_calc('web.screens', $_REQUEST['elementid'], true);
-		}
+if (isset($_REQUEST['favobj'])) {
+	if (getRequest('favobj') === 'timeline' && hasRequest('elementid') && hasRequest('period')) {
+		navigation_bar_calc('web.screens', $_REQUEST['elementid'], true);
 	}
 
 	if (str_in_array($_REQUEST['favobj'], array('screenid', 'slideshowid'))) {
 		$result = false;
+
+		DBstart();
+
 		if ($_REQUEST['favaction'] == 'add') {
 			$result = CFavorite::add('web.favorite.screenids', $_REQUEST['favid'], $_REQUEST['favobj']);
 			if ($result) {
 				echo '$("addrm_fav").title = "'._('Remove from favourites').'";'."\n".
-					'$("addrm_fav").onclick = function() { rm4favorites("'.$_REQUEST['favobj'].'", "'.$_REQUEST['favid'].'", 0); }'."\n";
+					'$("addrm_fav").onclick = function() { rm4favorites("'.$_REQUEST['favobj'].'", "'.$_REQUEST['favid'].'"); }'."\n";
 			}
 		}
 		elseif ($_REQUEST['favaction'] == 'remove') {
@@ -119,22 +119,22 @@ if (isset($_REQUEST['favobj'])) {
 			}
 		}
 
+		$result = DBend($result);
+
 		if ($page['type'] == PAGE_TYPE_JS && $result) {
-			echo 'switchElementsClass("addrm_fav", "iconminus", "iconplus");';
+			echo 'switchElementClass("addrm_fav", "iconminus", "iconplus");';
 		}
 	}
 
 	// saving fixed/dynamic setting to profile
-	if ($_REQUEST['favobj'] == 'timelinefixedperiod') {
-		if (isset($_REQUEST['favid'])) {
-			CProfile::update('web.screens.timelinefixed', $_REQUEST['favid'], PROFILE_TYPE_INT);
-		}
+	if ($_REQUEST['favobj'] == 'timelinefixedperiod' && isset($_REQUEST['favid'])) {
+		CProfile::update('web.screens.timelinefixed', $_REQUEST['favid'], PROFILE_TYPE_INT);
 	}
 }
 
 if ($page['type'] == PAGE_TYPE_JS || $page['type'] == PAGE_TYPE_HTML_BLOCK) {
 	require_once dirname(__FILE__).'/include/page_footer.php';
-	exit();
+	exit;
 }
 
 /*
@@ -142,9 +142,9 @@ if ($page['type'] == PAGE_TYPE_JS || $page['type'] == PAGE_TYPE_HTML_BLOCK) {
  */
 $data = array(
 	'fullscreen' => $_REQUEST['fullscreen'],
-	'period' => get_request('period'),
-	'stime' => get_request('stime'),
-	'elementid' => get_request('elementid', false),
+	'period' => getRequest('period'),
+	'stime' => getRequest('stime'),
+	'elementid' => getRequest('elementid', false),
 
 	// whether we should use screen name to fetch a screen (if this is false, elementid is used)
 	'use_screen_name' => isset($_REQUEST['screenname'])
@@ -157,14 +157,13 @@ if (empty($data['elementid']) && !$data['use_screen_name']) {
 }
 
 $data['screens'] = API::Screen()->get(array(
-	'nodeids' => get_current_nodeid(),
 	'output' => array('screenid', 'name')
 ));
 
 // if screen name is provided it takes priority over elementid
 if ($data['use_screen_name']) {
 	$data['screens'] = zbx_toHash($data['screens'], 'name');
-	$data['elementIdentifier'] = get_request('screenname');
+	$data['elementIdentifier'] = getRequest('screenname');
 }
 else {
 	$data['screens'] = zbx_toHash($data['screens'], 'screenid');
