@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,8 +38,8 @@ require_once dirname(__FILE__).'/include/page_header.php';
 //	VAR		TYPE	OPTIONAL FLAGS	VALIDATION	EXCEPTION
 $fields = array(
 	'serviceid' =>						array(T_ZBX_INT, O_OPT, P_SYS,	DB_ID,		null),
-	'name' => 							array(T_ZBX_STR, O_OPT, null,	NOT_EMPTY, 'isset({save_service})', _('Name')),
-	'algorithm' =>						array(T_ZBX_INT, O_OPT, null,	IN('0,1,2'),'isset({save_service})'),
+	'name' => 							array(T_ZBX_STR, O_OPT, null,	NOT_EMPTY, 'isset({add}) || isset({update})', _('Name')),
+	'algorithm' =>						array(T_ZBX_INT, O_OPT, null,	IN('0,1,2'),'isset({add}) || isset({update})'),
 	'showsla' =>						array(T_ZBX_INT, O_OPT, null,	IN('0,1'),	null),
 	'goodsla' => 						array(T_ZBX_DBL, O_OPT, null,	BETWEEN(0, 100), null, _('Calculate SLA, acceptable SLA (in %)')),
 	'sortorder' => 						array(T_ZBX_INT, O_OPT, null,	BETWEEN(0, 999), null, _('Sort order (0->999)')),
@@ -61,7 +61,8 @@ $fields = array(
 	'parentid' =>						array(T_ZBX_INT, O_OPT, P_SYS,	DB_ID,		null),
 	'parentname' =>						array(T_ZBX_STR, O_OPT, null,	null,		null),
 	// actions
-	'save_service' =>					array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null),
+	'add' =>							array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null),
+	'update' =>							array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null),
 	'add_service_time' =>				array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null),
 	'delete' =>							array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,		null),
 	// others
@@ -103,24 +104,29 @@ if (!empty($_REQUEST['serviceid'])) {
 
 // delete
 if (isset($_REQUEST['delete']) && isset($_REQUEST['serviceid'])) {
-	$result = API::Service()->delete($service['serviceid']);
-	show_messages($result, _('Service deleted'), _('Cannot delete service'));
+	DBstart();
+
+	$result = API::Service()->delete(array($service['serviceid']));
+
 	if ($result) {
 		add_audit(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_IT_SERVICE, 'Name ['.$service['name'].'] id ['.$service['serviceid'].']');
 		unset($_REQUEST['form']);
 	}
 	unset($service);
+
+	$result = DBend($result);
+	show_messages($result, _('Service deleted'), _('Cannot delete service'));
 }
 
 if (isset($_REQUEST['form'])) {
-	$_REQUEST['showsla'] = get_request('showsla', 0);
+	$_REQUEST['showsla'] = getRequest('showsla', 0);
 	$result = false;
 
 	// save
-	if (isset($_REQUEST['save_service'])) {
+	if (hasRequest('add') || hasRequest('update')) {
 		DBstart();
 
-		$children = get_request('children', array());
+		$children = getRequest('children', array());
 		$dependencies = array();
 		foreach ($children as $child) {
 			$dependencies[] = array(
@@ -130,42 +136,46 @@ if (isset($_REQUEST['form'])) {
 		}
 
 		$serviceRequest = array(
-			'name' => get_request('name'),
-			'triggerid' => get_request('triggerid'),
-			'algorithm' => get_request('algorithm'),
-			'showsla' => get_request('showsla', 0),
-			'goodsla' => get_request('goodsla'),
-			'sortorder' => get_request('sortorder'),
-			'times' => get_request('times', array()),
-			'parentid' => get_request('parentid'),
+			'name' => getRequest('name'),
+			'triggerid' => getRequest('triggerid'),
+			'algorithm' => getRequest('algorithm'),
+			'showsla' => getRequest('showsla', 0),
+			'goodsla' => getRequest('goodsla'),
+			'sortorder' => getRequest('sortorder'),
+			'times' => getRequest('times', array()),
+			'parentid' => getRequest('parentid'),
 			'dependencies' => $dependencies
 		);
 
 		if (isset($service['serviceid'])) {
 			$serviceRequest['serviceid'] = $service['serviceid'];
+
 			$result = API::Service()->update($serviceRequest);
 
-			show_messages($result, _('Service updated'), _('Cannot update service'));
-			$audit_action = AUDIT_ACTION_UPDATE;
+			$messageSuccess = _('Service updated');
+			$messageFailed = _('Cannot update service');
+			$auditAction = AUDIT_ACTION_UPDATE;
 		}
 		else {
 			$result = API::Service()->create($serviceRequest);
 
-			show_messages($result, _('Service created'), _('Cannot add service'));
-			$audit_action = AUDIT_ACTION_ADD;
+			$messageSuccess = _('Service created');
+			$messageFailed = _('Cannot add service');
+			$auditAction = AUDIT_ACTION_ADD;
 		}
 
 		if ($result) {
 			$serviceid = (isset($service['serviceid'])) ? $service['serviceid'] : reset($result['serviceids']);
-			add_audit($audit_action, AUDIT_RESOURCE_IT_SERVICE, 'Name ['.$_REQUEST['name'].'] id ['.$serviceid.']');
+			add_audit($auditAction, AUDIT_RESOURCE_IT_SERVICE, 'Name ['.$_REQUEST['name'].'] id ['.$serviceid.']');
 			unset($_REQUEST['form']);
 		}
 
-		DBend($result);
+		$result = DBend($result);
+		show_messages($result, $messageSuccess, $messageFailed);
 	}
 	// validate and get service times
 	elseif (isset($_REQUEST['add_service_time']) && isset($_REQUEST['new_service_time'])) {
-		$_REQUEST['times'] = get_request('times', array());
+		$_REQUEST['times'] = getRequest('times', array());
 		$new_service_time['type'] = $_REQUEST['new_service_time']['type'];
 		$result = true;
 		if ($_REQUEST['new_service_time']['type'] == SERVICE_TIME_TYPE_ONETIME_DOWNTIME) {
@@ -262,7 +272,7 @@ if (isset($_REQUEST['pservices'])) {
 		'output' => array('serviceid', 'name', 'algorithm'),
 		'selectTrigger' => array('triggerid', 'description', 'expression'),
 		'preservekeys' => true,
-		'sortfield' => array('sortorder', 'name')
+		'sortfield' => array('name')
 	));
 
 	if (isset($service)) {
@@ -303,7 +313,7 @@ elseif (isset($_REQUEST['cservices'])) {
 		'output' => array('serviceid', 'name', 'algorithm'),
 		'selectTrigger' => array('triggerid', 'description', 'expression'),
 		'preservekeys' => true,
-		'sortfield' => array('sortorder', 'name')
+		'sortfield' => array('name')
 	));
 
 	if (isset($service)) {
@@ -341,12 +351,12 @@ elseif (isset($_REQUEST['cservices'])) {
  */
 elseif (isset($_REQUEST['form'])) {
 	$data = array();
-	$data['form'] = get_request('form');
-	$data['form_refresh'] = get_request('form_refresh', 0);
+	$data['form'] = getRequest('form');
+	$data['form_refresh'] = getRequest('form_refresh', 0);
 	$data['service'] = !empty($service) ? $service : null;
 
-	$data['times'] = get_request('times', array());
-	$data['new_service_time'] = get_request('new_service_time', array('type' => SERVICE_TIME_TYPE_UPTIME));
+	$data['times'] = getRequest('times', array());
+	$data['new_service_time'] = getRequest('new_service_time', array('type' => SERVICE_TIME_TYPE_UPTIME));
 
 	// populate the form from the object from the database
 	if (isset($data['service']['serviceid']) && !isset($_REQUEST['form_refresh'])) {
@@ -393,19 +403,21 @@ elseif (isset($_REQUEST['form'])) {
 					'soft' => $dependency['soft'],
 				);
 			}
+
+			CArrayHelper::sort($data['children'], array('name', 'serviceid'));
 		}
 	}
 	// populate the form from a submitted request
 	else {
-		$data['name'] = get_request('name', '');
-		$data['algorithm'] = get_request('algorithm', SERVICE_ALGORITHM_MAX);
-		$data['showsla'] = get_request('showsla', 0);
-		$data['goodsla'] = get_request('goodsla', SERVICE_SLA);
-		$data['sortorder'] = get_request('sortorder', 0);
-		$data['triggerid'] = get_request('triggerid', 0);
-		$data['parentid'] = get_request('parentid', 0);
-		$data['parentname'] = get_request('parentname', '');
-		$data['children'] = get_request('children', array());
+		$data['name'] = getRequest('name', '');
+		$data['algorithm'] = getRequest('algorithm', SERVICE_ALGORITHM_MAX);
+		$data['showsla'] = getRequest('showsla', 0);
+		$data['goodsla'] = getRequest('goodsla', SERVICE_SLA);
+		$data['sortorder'] = getRequest('sortorder', 0);
+		$data['triggerid'] = getRequest('triggerid', 0);
+		$data['parentid'] = getRequest('parentid', 0);
+		$data['parentname'] = getRequest('parentname', '');
+		$data['children'] = getRequest('children', array());
 	}
 
 	// get trigger
@@ -443,7 +455,6 @@ else {
 
 	// triggers
 	$triggers = zbx_objectValues($services, 'trigger');
-
 	$triggers = CMacrosResolverHelper::resolveTriggerNames($triggers);
 
 	foreach ($services as &$service) {
@@ -453,14 +464,6 @@ else {
 	}
 	unset($service);
 
-	// nodes
-	if ($data['displayNodes'] = is_array(get_current_nodeid())) {
-		foreach ($services as &$service) {
-			$service['name'] = get_node_name_by_elid($service['serviceid'], true, NAME_DELIMITER).$service['name'];
-		}
-		unset($service);
-	}
-
 	$treeData = array();
 	createServiceConfigurationTree($services, $treeData);
 	$tree = new CServiceTree('service_conf_tree', $treeData, array(
